/********************************************************************************
** Form generated from reading UI file 'commondata.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMMONDATA_H
#define UI_COMMONDATA_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_CommonData
{
public:
    QGridLayout *gridLayout;
    QFormLayout *formLayout_7;
    QLabel *label;
    KLineEdit *identity;
    QLabel *label_7;
    KLineEdit *description;
    QLabel *label_2;
    KLineEdit *version;
    QLabel *label_12;
    KLineEdit *logo;
    QLabel *label_13;
    KComboBox *language;
    QLabel *label_14;
    KLineEdit *os;
    QLabel *label_18;
    KLineEdit *copyright;
    QSpacerItem *verticalSpacer_4;
    QLabel *label_20;
    QFormLayout *formLayout_2;
    QLabel *label_8;
    KLineEdit *pub_name;
    QLabel *label_21;
    KLineEdit *pub_url;

    void setupUi(QWidget *CommonData)
    {
        if (CommonData->objectName().isEmpty())
            CommonData->setObjectName("CommonData");
        CommonData->resize(566, 318);
        gridLayout = new QGridLayout(CommonData);
        gridLayout->setObjectName("gridLayout");
        formLayout_7 = new QFormLayout();
        formLayout_7->setObjectName("formLayout_7");
        formLayout_7->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(CommonData);
        label->setObjectName("label");

        formLayout_7->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        identity = new KLineEdit(CommonData);
        identity->setObjectName("identity");

        formLayout_7->setWidget(0, QFormLayout::ItemRole::FieldRole, identity);

        label_7 = new QLabel(CommonData);
        label_7->setObjectName("label_7");

        formLayout_7->setWidget(1, QFormLayout::ItemRole::LabelRole, label_7);

        description = new KLineEdit(CommonData);
        description->setObjectName("description");
        description->setProperty("showClearButton", QVariant(true));

        formLayout_7->setWidget(1, QFormLayout::ItemRole::FieldRole, description);

        label_2 = new QLabel(CommonData);
        label_2->setObjectName("label_2");

        formLayout_7->setWidget(2, QFormLayout::ItemRole::LabelRole, label_2);

        version = new KLineEdit(CommonData);
        version->setObjectName("version");

        formLayout_7->setWidget(2, QFormLayout::ItemRole::FieldRole, version);

        label_12 = new QLabel(CommonData);
        label_12->setObjectName("label_12");

        formLayout_7->setWidget(3, QFormLayout::ItemRole::LabelRole, label_12);

        logo = new KLineEdit(CommonData);
        logo->setObjectName("logo");
        logo->setProperty("showClearButton", QVariant(true));

        formLayout_7->setWidget(3, QFormLayout::ItemRole::FieldRole, logo);

        label_13 = new QLabel(CommonData);
        label_13->setObjectName("label_13");

        formLayout_7->setWidget(4, QFormLayout::ItemRole::LabelRole, label_13);

        language = new KComboBox(CommonData);
        language->setObjectName("language");

        formLayout_7->setWidget(4, QFormLayout::ItemRole::FieldRole, language);

        label_14 = new QLabel(CommonData);
        label_14->setObjectName("label_14");

        formLayout_7->setWidget(5, QFormLayout::ItemRole::LabelRole, label_14);

        os = new KLineEdit(CommonData);
        os->setObjectName("os");
        os->setProperty("showClearButton", QVariant(true));

        formLayout_7->setWidget(5, QFormLayout::ItemRole::FieldRole, os);

        label_18 = new QLabel(CommonData);
        label_18->setObjectName("label_18");

        formLayout_7->setWidget(6, QFormLayout::ItemRole::LabelRole, label_18);

        copyright = new KLineEdit(CommonData);
        copyright->setObjectName("copyright");
        copyright->setProperty("showClearButton", QVariant(true));

        formLayout_7->setWidget(6, QFormLayout::ItemRole::FieldRole, copyright);


        gridLayout->addLayout(formLayout_7, 0, 1, 1, 1);

        verticalSpacer_4 = new QSpacerItem(40, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 1, 0, 1, 1);

        label_20 = new QLabel(CommonData);
        label_20->setObjectName("label_20");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_20->sizePolicy().hasHeightForWidth());
        label_20->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_20, 2, 0, 1, 2);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        label_8 = new QLabel(CommonData);
        label_8->setObjectName("label_8");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_8);

        pub_name = new KLineEdit(CommonData);
        pub_name->setObjectName("pub_name");
        pub_name->setProperty("showClearButton", QVariant(true));

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, pub_name);

        label_21 = new QLabel(CommonData);
        label_21->setObjectName("label_21");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_21);

        pub_url = new KLineEdit(CommonData);
        pub_url->setObjectName("pub_url");
        pub_url->setProperty("showClearButton", QVariant(true));

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, pub_url);


        gridLayout->addLayout(formLayout_2, 3, 1, 1, 1);


        retranslateUi(CommonData);

        QMetaObject::connectSlotsByName(CommonData);
    } // setupUi

    void retranslateUi(QWidget *CommonData)
    {
        label->setText(tr2i18n("Identity", nullptr));
        label_7->setText(tr2i18n("Description:", nullptr));
        label_2->setText(tr2i18n("Version:", nullptr));
        label_12->setText(tr2i18n("Logo:", nullptr));
        logo->setPlaceholderText(tr2i18n("URL to the logo", nullptr));
#if QT_CONFIG(tooltip)
        label_13->setToolTip(tr2i18n("The language of the file", nullptr));
#endif // QT_CONFIG(tooltip)
        label_13->setText(tr2i18n("Language:", nullptr));
        label_14->setText(tr2i18n("Operating systems:", nullptr));
        os->setPlaceholderText(tr2i18n("Supported OSes, separated with commas", nullptr));
        label_18->setText(tr2i18n("Copyright:", nullptr));
        label_20->setText(tr2i18n("Publisher:", nullptr));
        label_8->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        pub_name->setToolTip(tr2i18n("publisher", nullptr));
#endif // QT_CONFIG(tooltip)
        pub_name->setPlaceholderText(tr2i18n("Name of the publisher", nullptr));
        label_21->setText(tr2i18n("URL:", nullptr));
#if QT_CONFIG(tooltip)
        pub_url->setToolTip(tr2i18n("publisher", nullptr));
#endif // QT_CONFIG(tooltip)
        pub_url->setPlaceholderText(tr2i18n("URL to the publisher", nullptr));
        (void)CommonData;
    } // retranslateUi

};

namespace Ui {
    class CommonData: public Ui_CommonData {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COMMONDATA_H

