/****************************************************************************
** Meta object code from reading C++ file 'segment.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kget-26.08.0/transfer-plugins/multisegmentkio/segment.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'segment.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7SegmentE_t {};
} // unnamed namespace

template <> constexpr inline auto Segment::qt_create_metaobjectdata<qt_meta_tag_ZN7SegmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Segment",
        "data",
        "",
        "KIO::fileoffset_t",
        "offset",
        "bool&",
        "worked",
        "error",
        "Segment*",
        "segment",
        "errorText",
        "Transfer::LogLevel",
        "logLevel",
        "finishedSegment",
        "segmentNum",
        "connectionFinished",
        "statusChanged",
        "speed",
        "connectionProblem",
        "totalSize",
        "KIO::filesize_t",
        "size",
        "std::pair<int,int>",
        "segmentRange",
        "finishedDownload",
        "canResume",
        "urlChanged",
        "QUrl",
        "newUrl",
        "startTransfer",
        "slotResult",
        "KJob*",
        "job",
        "slotData",
        "KIO::Job*",
        "slotCanResume",
        "slotTotalSize",
        "slotWriteRest",
        "slotRedirection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'data'
        QtMocHelpers::SignalData<void(KIO::fileoffset_t, const QByteArray &, bool &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QByteArray, 1 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(Segment *, const QString &, Transfer::LogLevel)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'finishedSegment'
        QtMocHelpers::SignalData<void(Segment *, int, bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Signal 'finishedSegment'
        QtMocHelpers::SignalData<void(Segment *, int)>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 14 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(Segment *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'speed'
        QtMocHelpers::SignalData<void(ulong)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULong, 17 },
        }}),
        // Signal 'connectionProblem'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'totalSize'
        QtMocHelpers::SignalData<void(KIO::filesize_t, QPair<int,int>)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Signal 'finishedDownload'
        QtMocHelpers::SignalData<void(KIO::filesize_t)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'canResume'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'startTransfer'
        QtMocHelpers::SlotData<bool()>(29, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotResult'
        QtMocHelpers::SlotData<void(KJob *)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'slotData'
        QtMocHelpers::SlotData<void(KIO::Job *, const QByteArray &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 32 }, { QMetaType::QByteArray, 1 },
        }}),
        // Slot 'slotCanResume'
        QtMocHelpers::SlotData<void(KIO::Job *, KIO::filesize_t)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 32 }, { 0x80000000 | 20, 2 },
        }}),
        // Slot 'slotTotalSize'
        QtMocHelpers::SlotData<void(KJob *, qulonglong)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 32 }, { QMetaType::ULongLong, 21 },
        }}),
        // Slot 'slotWriteRest'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRedirection'
        QtMocHelpers::SlotData<void(KIO::Job *, const QUrl &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 2 }, { 0x80000000 | 27, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Segment, qt_meta_tag_ZN7SegmentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Segment::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7SegmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7SegmentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7SegmentE_t>.metaTypes,
    nullptr
} };

void Segment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Segment *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->data((*reinterpret_cast<std::add_pointer_t<KIO::fileoffset_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3]))); break;
        case 1: _t->error((*reinterpret_cast<std::add_pointer_t<Segment*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Transfer::LogLevel>>(_a[3]))); break;
        case 2: _t->finishedSegment((*reinterpret_cast<std::add_pointer_t<Segment*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 3: _t->finishedSegment((*reinterpret_cast<std::add_pointer_t<Segment*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<Segment*>>(_a[1]))); break;
        case 5: _t->speed((*reinterpret_cast<std::add_pointer_t<ulong>>(_a[1]))); break;
        case 6: _t->connectionProblem(); break;
        case 7: _t->totalSize((*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[2]))); break;
        case 8: _t->finishedDownload((*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[1]))); break;
        case 9: _t->canResume(); break;
        case 10: _t->urlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 11: { bool _r = _t->startTransfer();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->slotResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 13: _t->slotData((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 14: _t->slotCanResume((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[2]))); break;
        case 15: _t->slotTotalSize((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 16: _t->slotWriteRest(); break;
        case 17: _t->slotRedirection((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Segment* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Segment* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Segment* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Segment* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Segment::*)(KIO::fileoffset_t , const QByteArray & , bool & )>(_a, &Segment::data, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Segment::*)(Segment * , const QString & , Transfer::LogLevel )>(_a, &Segment::error, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Segment::*)(Segment * , int , bool )>(_a, &Segment::finishedSegment, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Segment::*)(Segment * )>(_a, &Segment::statusChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Segment::*)(ulong )>(_a, &Segment::speed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Segment::*)()>(_a, &Segment::connectionProblem, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Segment::*)(KIO::filesize_t , QPair<int,int> )>(_a, &Segment::totalSize, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Segment::*)(KIO::filesize_t )>(_a, &Segment::finishedDownload, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Segment::*)()>(_a, &Segment::canResume, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Segment::*)(const QUrl & )>(_a, &Segment::urlChanged, 10))
            return;
    }
}

const QMetaObject *Segment::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Segment::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7SegmentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Segment::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Segment::data(KIO::fileoffset_t _t1, const QByteArray & _t2, bool & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void Segment::error(Segment * _t1, const QString & _t2, Transfer::LogLevel _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Segment::finishedSegment(Segment * _t1, int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void Segment::statusChanged(Segment * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Segment::speed(ulong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Segment::connectionProblem()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Segment::totalSize(KIO::filesize_t _t1, QPair<int,int> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Segment::finishedDownload(KIO::filesize_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Segment::canResume()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Segment::urlChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
