/********************************************************************************
** Form generated from reading UI file 'groupsettingsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GROUPSETTINGSDIALOG_H
#define UI_GROUPSETTINGSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "ktitlewidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_GroupSettingsDialog
{
public:
    QVBoxLayout *verticalLayout;
    KTitleWidget *ktitlewidget;
    QFormLayout *formLayout;
    QLabel *label;
    KUrlRequester *defaultFolderRequester;
    QLabel *label_2;
    KLineEdit *regExpEdit;
    QSpinBox *downloadBox;
    QSpinBox *uploadBox;
    QLabel *label_3;
    QLabel *label_4;
    QWidget *nepomukWidget;
    QHBoxLayout *horizontalLayout;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *GroupSettingsDialog)
    {
        if (GroupSettingsDialog->objectName().isEmpty())
            GroupSettingsDialog->setObjectName("GroupSettingsDialog");
        GroupSettingsDialog->resize(457, 211);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(GroupSettingsDialog->sizePolicy().hasHeightForWidth());
        GroupSettingsDialog->setSizePolicy(sizePolicy);
        GroupSettingsDialog->setLayoutDirection(Qt::LeftToRight);
        verticalLayout = new QVBoxLayout(GroupSettingsDialog);
        verticalLayout->setObjectName("verticalLayout");
        ktitlewidget = new KTitleWidget(GroupSettingsDialog);
        ktitlewidget->setObjectName("ktitlewidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(ktitlewidget->sizePolicy().hasHeightForWidth());
        ktitlewidget->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(ktitlewidget);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(GroupSettingsDialog);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        defaultFolderRequester = new KUrlRequester(GroupSettingsDialog);
        defaultFolderRequester->setObjectName("defaultFolderRequester");
        defaultFolderRequester->setEnabled(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, defaultFolderRequester);

        label_2 = new QLabel(GroupSettingsDialog);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        regExpEdit = new KLineEdit(GroupSettingsDialog);
        regExpEdit->setObjectName("regExpEdit");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, regExpEdit);

        downloadBox = new QSpinBox(GroupSettingsDialog);
        downloadBox->setObjectName("downloadBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(downloadBox->sizePolicy().hasHeightForWidth());
        downloadBox->setSizePolicy(sizePolicy2);
        downloadBox->setMaximum(10000);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, downloadBox);

        uploadBox = new QSpinBox(GroupSettingsDialog);
        uploadBox->setObjectName("uploadBox");
        sizePolicy2.setHeightForWidth(uploadBox->sizePolicy().hasHeightForWidth());
        uploadBox->setSizePolicy(sizePolicy2);
        uploadBox->setMaximum(10000);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, uploadBox);

        label_3 = new QLabel(GroupSettingsDialog);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        label_4 = new QLabel(GroupSettingsDialog);
        label_4->setObjectName("label_4");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_4);


        verticalLayout->addLayout(formLayout);

        nepomukWidget = new QWidget(GroupSettingsDialog);
        nepomukWidget->setObjectName("nepomukWidget");
        sizePolicy.setHeightForWidth(nepomukWidget->sizePolicy().hasHeightForWidth());
        nepomukWidget->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(nepomukWidget);
        horizontalLayout->setObjectName("horizontalLayout");

        verticalLayout->addWidget(nepomukWidget);

        buttonBox = new QDialogButtonBox(GroupSettingsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(defaultFolderRequester);
        label_2->setBuddy(regExpEdit);
        label_3->setBuddy(downloadBox);
        label_4->setBuddy(uploadBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(GroupSettingsDialog);

        QMetaObject::connectSlotsByName(GroupSettingsDialog);
    } // setupUi

    void retranslateUi(QWidget *GroupSettingsDialog)
    {
        ktitlewidget->setProperty("text", QVariant(tr2i18n("Group Settings", nullptr)));
        label->setText(tr2i18n("Defau&lt folder:", nullptr));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("Moves all transfers with the regular expression to this group", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Re&gular expression:", nullptr));
        regExpEdit->setProperty("placeholderText", QVariant(tr2i18n("*movies*", nullptr)));
        downloadBox->setSpecialValueText(tr2i18n("Not set", "No value has been set"));
        downloadBox->setSuffix(tr2i18n(" KiB/s", nullptr));
        uploadBox->setSpecialValueText(tr2i18n("Not set", "No value has been set"));
        uploadBox->setSuffix(tr2i18n(" KiB/s", nullptr));
        label_3->setText(tr2i18n("Ma&ximum download speed:", nullptr));
        label_4->setText(tr2i18n("Maximum &upload speed:", nullptr));
        (void)GroupSettingsDialog;
    } // retranslateUi

};

namespace Ui {
    class GroupSettingsDialog: public Ui_GroupSettingsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GROUPSETTINGSDIALOG_H

