/********************************************************************************
** Form generated from reading UI file 'verificationadddlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VERIFICATIONADDDLG_H
#define UI_VERIFICATIONADDDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <kcombobox.h>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_VerificationAddDlg
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label;
    QLabel *label_2;
    KLineEdit *newHash;
    KComboBox *hashTypes;
    QDialogButtonBox *buttonBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *VerificationAddDlg)
    {
        if (VerificationAddDlg->objectName().isEmpty())
            VerificationAddDlg->setObjectName("VerificationAddDlg");
        VerificationAddDlg->resize(297, 119);
        verticalLayout = new QVBoxLayout(VerificationAddDlg);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(VerificationAddDlg);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        label_2 = new QLabel(VerificationAddDlg);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        newHash = new KLineEdit(VerificationAddDlg);
        newHash->setObjectName("newHash");
        newHash->setProperty("showClearButton", QVariant(true));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, newHash);

        hashTypes = new KComboBox(VerificationAddDlg);
        hashTypes->setObjectName("hashTypes");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, hashTypes);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(VerificationAddDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        QWidget::setTabOrder(hashTypes, newHash);

        retranslateUi(VerificationAddDlg);

        QMetaObject::connectSlotsByName(VerificationAddDlg);
    } // setupUi

    void retranslateUi(QWidget *VerificationAddDlg)
    {
        label->setText(tr2i18n("Hash type:", "hash type as in md5t, sha1 etc."));
        label_2->setText(tr2i18n("Hash:", "hash as a hash of type md5, sha1 etc."));
        newHash->setProperty("placeholderText", QVariant(tr2i18n("Enter a hash key", nullptr)));
        (void)VerificationAddDlg;
    } // retranslateUi

};

namespace Ui {
    class VerificationAddDlg: public Ui_VerificationAddDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VERIFICATIONADDDLG_H

