/********************************************************************************
** Form generated from reading UI file 'mirroradddlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MIRRORADDDLG_H
#define UI_MIRRORADDDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KLineEdit"

QT_BEGIN_NAMESPACE

class Ui_MirrorAddDlg
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *labelMirror;
    QLabel *labelConnections;
    KLineEdit *url;
    QSpinBox *numConnections;
    QLabel *labelPriority;
    QSpinBox *priority;
    QLabel *labelLocation;
    QComboBox *location;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *MirrorAddDlg)
    {
        if (MirrorAddDlg->objectName().isEmpty())
            MirrorAddDlg->setObjectName("MirrorAddDlg");
        MirrorAddDlg->resize(481, 187);
        verticalLayout = new QVBoxLayout(MirrorAddDlg);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        labelMirror = new QLabel(MirrorAddDlg);
        labelMirror->setObjectName("labelMirror");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelMirror);

        labelConnections = new QLabel(MirrorAddDlg);
        labelConnections->setObjectName("labelConnections");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, labelConnections);

        url = new KLineEdit(MirrorAddDlg);
        url->setObjectName("url");
        url->setProperty("showClearButton", QVariant(true));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, url);

        numConnections = new QSpinBox(MirrorAddDlg);
        numConnections->setObjectName("numConnections");
        numConnections->setMinimum(1);
        numConnections->setMaximum(20);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, numConnections);

        labelPriority = new QLabel(MirrorAddDlg);
        labelPriority->setObjectName("labelPriority");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, labelPriority);

        priority = new QSpinBox(MirrorAddDlg);
        priority->setObjectName("priority");
        priority->setValue(0);
        priority->setMinimum(0);
        priority->setMaximum(999999);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, priority);

        labelLocation = new QLabel(MirrorAddDlg);
        labelLocation->setObjectName("labelLocation");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, labelLocation);

        location = new QComboBox(MirrorAddDlg);
        location->setObjectName("location");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, location);


        verticalLayout->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(MirrorAddDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Yes);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(MirrorAddDlg);

        QMetaObject::connectSlotsByName(MirrorAddDlg);
    } // setupUi

    void retranslateUi(QWidget *MirrorAddDlg)
    {
        labelMirror->setText(tr2i18n("Mirror:", nullptr));
        labelConnections->setText(tr2i18n("Number of connections:", nullptr));
        url->setProperty("placeholderText", QVariant(tr2i18n("Enter a URL", nullptr)));
        labelPriority->setText(tr2i18n("Priority:", nullptr));
#if QT_CONFIG(tooltip)
        priority->setToolTip(tr2i18n("Optional: The priority of the mirror, 1 highest 999999 lowest.", nullptr));
#endif // QT_CONFIG(tooltip)
        priority->setSpecialValueText(tr2i18n("not specified", nullptr));
        labelLocation->setText(tr2i18n("Location:", nullptr));
        (void)MirrorAddDlg;
    } // retranslateUi

};

namespace Ui {
    class MirrorAddDlg: public Ui_MirrorAddDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MIRRORADDDLG_H

