// This file is generated by kconfig_compiler_kf6 from kget.kcfg.
// All changes you do to this file will be lost.

#include "settings.h"

#include <qglobal.h>
#include <QFile>

class SettingsHelper
{
  public:
    SettingsHelper() noexcept : q(nullptr) {}
    ~SettingsHelper() noexcept { delete q; q = nullptr; }
    SettingsHelper(const SettingsHelper&) = delete;
    SettingsHelper& operator=(const SettingsHelper&) = delete;
    Settings *q;
};
Q_GLOBAL_STATIC(SettingsHelper, s_globalSettings)
Settings *Settings::self()
{
  if (!s_globalSettings()->q) {
    new Settings;
    s_globalSettings()->q->read();
  }

  return s_globalSettings()->q;
}

Settings::Settings( )
  : KConfigSkeleton( QStringLiteral( "kgetrc" ) )
{
  Q_ASSERT(!s_globalSettings()->q);
  s_globalSettings()->q = this;
  setCurrentGroup( QStringLiteral( "Appearance" ) );

  KConfigSkeleton::ItemString  *itemHeaderState;
  itemHeaderState = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "HeaderState" ), mHeaderState );
  addItem( itemHeaderState, QStringLiteral( "HeaderState" ) );
  KConfigSkeleton::ItemString  *itemTransferSettingsHeaderState;
  itemTransferSettingsHeaderState = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "TransferSettingsHeaderState" ), mTransferSettingsHeaderState );
  addItem( itemTransferSettingsHeaderState, QStringLiteral( "TransferSettingsHeaderState" ) );
  KConfigSkeleton::ItemString  *itemVerificationHeaderState;
  itemVerificationHeaderState = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "VerificationHeaderState" ), mVerificationHeaderState );
  addItem( itemVerificationHeaderState, QStringLiteral( "VerificationHeaderState" ) );
  KConfigSkeleton::ItemString  *itemAutoPasteHeaderState;
  itemAutoPasteHeaderState = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AutoPasteHeaderState" ), mAutoPasteHeaderState );
  addItem( itemAutoPasteHeaderState, QStringLiteral( "AutoPasteHeaderState" ) );
  KConfigSkeleton::ItemBool  *itemShowMain;
  itemShowMain = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowMain" ), mShowMain, true );
  addItem( itemShowMain, QStringLiteral( "ShowMain" ) );
  KConfigSkeleton::ItemBool  *itemShowIndividual;
  itemShowIndividual = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowIndividual" ), mShowIndividual, false );
  addItem( itemShowIndividual, QStringLiteral( "ShowIndividual" ) );
  KConfigSkeleton::ItemBool  *itemDockifyIndividual;
  itemDockifyIndividual = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DockifyIndividual" ), mDockifyIndividual, false );
  addItem( itemDockifyIndividual, QStringLiteral( "DockifyIndividual" ) );
  KConfigSkeleton::ItemBool  *itemShowDropTarget;
  itemShowDropTarget = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowDropTarget" ), mShowDropTarget, false );
  addItem( itemShowDropTarget, QStringLiteral( "ShowDropTarget" ) );
  KConfigSkeleton::ItemBool  *itemAnimateDropTarget;
  itemAnimateDropTarget = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnimateDropTarget" ), mAnimateDropTarget, true );
  addItem( itemAnimateDropTarget, QStringLiteral( "AnimateDropTarget" ) );

  setCurrentGroup( QStringLiteral( "Advanced" ) );

  KConfigSkeleton::ItemBool  *itemKonquerorIntegration;
  itemKonquerorIntegration = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "KonquerorIntegration" ), mKonquerorIntegration, false );
  addItem( itemKonquerorIntegration, QStringLiteral( "KonquerorIntegration" ) );
  KConfigSkeleton::ItemBool  *itemAutoPaste;
  itemAutoPaste = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoPaste" ), mAutoPaste, false );
  addItem( itemAutoPaste, QStringLiteral( "AutoPaste" ) );
  KConfigSkeleton::ItemBool  *itemAutoPasteCaseSensitive;
  itemAutoPasteCaseSensitive = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoPasteCaseSensitive" ), mAutoPasteCaseSensitive, false );
  addItem( itemAutoPasteCaseSensitive, QStringLiteral( "AutoPasteCaseSensitive" ) );
  QStringList defaultAutoPastePatterns;
  defaultAutoPastePatterns.append( QString::fromUtf8( "*" ) );

  KConfigSkeleton::ItemStringList  *itemAutoPastePatterns;
  itemAutoPastePatterns = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "AutoPastePatterns" ), mAutoPastePatterns, defaultAutoPastePatterns );
  addItem( itemAutoPastePatterns, QStringLiteral( "AutoPastePatterns" ) );
  QList<int> defaultAutoPasteTypes;
  defaultAutoPasteTypes.append( 0 );

  KConfigSkeleton::ItemIntList  *itemAutoPasteTypes;
  itemAutoPasteTypes = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "AutoPasteTypes" ), mAutoPasteTypes, defaultAutoPasteTypes );
  addItem( itemAutoPasteTypes, QStringLiteral( "AutoPasteTypes" ) );
  QList<int> defaultAutoPastePatternSyntaxes;
  defaultAutoPastePatternSyntaxes.append( 0 );

  KConfigSkeleton::ItemIntList  *itemAutoPastePatternSyntaxes;
  itemAutoPastePatternSyntaxes = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "AutoPastePatternSyntaxes" ), mAutoPastePatternSyntaxes, defaultAutoPastePatternSyntaxes );
  addItem( itemAutoPastePatternSyntaxes, QStringLiteral( "AutoPastePatternSyntaxes" ) );
  KConfigSkeleton::ItemBool  *itemTimedDownload;
  itemTimedDownload = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TimedDownload" ), mTimedDownload, false );
  addItem( itemTimedDownload, QStringLiteral( "TimedDownload" ) );
  KConfigSkeleton::ItemDateTime  *itemTimedDownloadDateTime;
  itemTimedDownloadDateTime = new KConfigSkeleton::ItemDateTime( currentGroup(), QStringLiteral( "TimedDownloadDateTime" ), mTimedDownloadDateTime, QDateTime::currentDateTime() );
  addItem( itemTimedDownloadDateTime, QStringLiteral( "TimedDownloadDateTime" ) );
  KConfigSkeleton::ItemBool  *itemTimedDisconnect;
  itemTimedDisconnect = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TimedDisconnect" ), mTimedDisconnect, false );
  addItem( itemTimedDisconnect, QStringLiteral( "TimedDisconnect" ) );
  KConfigSkeleton::ItemDateTime  *itemTimedDisconnectDateTime;
  itemTimedDisconnectDateTime = new KConfigSkeleton::ItemDateTime( currentGroup(), QStringLiteral( "TimedDisconnectDateTime" ), mTimedDisconnectDateTime, QDateTime::currentDateTime() );
  addItem( itemTimedDisconnectDateTime, QStringLiteral( "TimedDisconnectDateTime" ) );
  KConfigSkeleton::ItemBool  *itemAutomaticDeletionEnabled;
  itemAutomaticDeletionEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutomaticDeletionEnabled" ), mAutomaticDeletionEnabled, false );
  addItem( itemAutomaticDeletionEnabled, QStringLiteral( "AutomaticDeletionEnabled" ) );
  KConfigSkeleton::ItemInt  *itemExpiryTimeType;
  itemExpiryTimeType = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ExpiryTimeType" ), mExpiryTimeType, 0 );
  addItem( itemExpiryTimeType, QStringLiteral( "ExpiryTimeType" ) );
  KConfigSkeleton::ItemInt  *itemExpiryTimeValue;
  itemExpiryTimeValue = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ExpiryTimeValue" ), mExpiryTimeValue, 0 );
  addItem( itemExpiryTimeValue, QStringLiteral( "ExpiryTimeValue" ) );
  KConfigSkeleton::ItemBool  *itemEnableSystemTray;
  itemEnableSystemTray = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnableSystemTray" ), mEnableSystemTray, true );
  addItem( itemEnableSystemTray, QStringLiteral( "EnableSystemTray" ) );
  KConfigSkeleton::ItemBool  *itemAfterFinishActionEnabled;
  itemAfterFinishActionEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AfterFinishActionEnabled" ), mAfterFinishActionEnabled, false );
  addItem( itemAfterFinishActionEnabled, QStringLiteral( "AfterFinishActionEnabled" ) );
  KConfigSkeleton::ItemInt  *itemAfterFinishAction;
  itemAfterFinishAction = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "AfterFinishAction" ), mAfterFinishAction, 0 );
  addItem( itemAfterFinishAction, QStringLiteral( "AfterFinishAction" ) );
  KConfigSkeleton::ItemBool  *itemEnableKUIServerIntegration;
  itemEnableKUIServerIntegration = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnableKUIServerIntegration" ), mEnableKUIServerIntegration, false );
  addItem( itemEnableKUIServerIntegration, QStringLiteral( "EnableKUIServerIntegration" ) );
  KConfigSkeleton::ItemBool  *itemExportSingleTransfer;
  itemExportSingleTransfer = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ExportSingleTransfer" ), mExportSingleTransfer, true );
  addItem( itemExportSingleTransfer, QStringLiteral( "ExportSingleTransfer" ) );
  KConfigSkeleton::ItemBool  *itemExportGlobalJob;
  itemExportGlobalJob = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ExportGlobalJob" ), mExportGlobalJob, false );
  addItem( itemExportGlobalJob, QStringLiteral( "ExportGlobalJob" ) );
  KConfigSkeleton::ItemInt  *itemHistoryBackend;
  itemHistoryBackend = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "HistoryBackend" ), mHistoryBackend, 1 );
  addItem( itemHistoryBackend, QStringLiteral( "HistoryBackend" ) );
  KConfigSkeleton::ItemInt  *itemStartupAction;
  itemStartupAction = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "StartupAction" ), mStartupAction, 0 );
  addItem( itemStartupAction, QStringLiteral( "StartupAction" ) );
  KConfigSkeleton::ItemBool  *itemFilesAlwaysAsk;
  itemFilesAlwaysAsk = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FilesAlwaysAsk" ), mFilesAlwaysAsk, true );
  addItem( itemFilesAlwaysAsk, QStringLiteral( "FilesAlwaysAsk" ) );
  KConfigSkeleton::ItemBool  *itemFilesAutomaticRename;
  itemFilesAutomaticRename = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FilesAutomaticRename" ), mFilesAutomaticRename, false );
  addItem( itemFilesAutomaticRename, QStringLiteral( "FilesAutomaticRename" ) );
  KConfigSkeleton::ItemBool  *itemFilesOverwrite;
  itemFilesOverwrite = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FilesOverwrite" ), mFilesOverwrite, false );
  addItem( itemFilesOverwrite, QStringLiteral( "FilesOverwrite" ) );

  setCurrentGroup( QStringLiteral( "Network" ) );

  KConfigSkeleton::ItemInt  *itemMaxConnections;
  itemMaxConnections = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "MaxConnections" ), mMaxConnections, 2 );
  addItem( itemMaxConnections, QStringLiteral( "MaxConnections" ) );
  KConfigSkeleton::ItemBool  *itemSpeedLimit;
  itemSpeedLimit = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SpeedLimit" ), mSpeedLimit, false );
  addItem( itemSpeedLimit, QStringLiteral( "SpeedLimit" ) );
  KConfigSkeleton::ItemInt  *itemTransferSpeedLimit;
  itemTransferSpeedLimit = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "TransferSpeedLimit" ), mTransferSpeedLimit, 20 );
  addItem( itemTransferSpeedLimit, QStringLiteral( "TransferSpeedLimit" ) );
  KConfigSkeleton::ItemInt  *itemGlobalDownloadLimit;
  itemGlobalDownloadLimit = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "GlobalDownloadLimit" ), mGlobalDownloadLimit, 0 );
  addItem( itemGlobalDownloadLimit, QStringLiteral( "GlobalDownloadLimit" ) );
  KConfigSkeleton::ItemInt  *itemGlobalUploadLimit;
  itemGlobalUploadLimit = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "GlobalUploadLimit" ), mGlobalUploadLimit, 0 );
  addItem( itemGlobalUploadLimit, QStringLiteral( "GlobalUploadLimit" ) );
  KConfigSkeleton::ItemBool  *itemReconnectOnBroken;
  itemReconnectOnBroken = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ReconnectOnBroken" ), mReconnectOnBroken, true );
  addItem( itemReconnectOnBroken, QStringLiteral( "ReconnectOnBroken" ) );
  KConfigSkeleton::ItemInt  *itemReconnectRetries;
  itemReconnectRetries = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ReconnectRetries" ), mReconnectRetries, 5 );
  addItem( itemReconnectRetries, QStringLiteral( "ReconnectRetries" ) );
  KConfigSkeleton::ItemInt  *itemReconnectDelay;
  itemReconnectDelay = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ReconnectDelay" ), mReconnectDelay, 60 );
  addItem( itemReconnectDelay, QStringLiteral( "ReconnectDelay" ) );

  setCurrentGroup( QStringLiteral( "Webinterface" ) );

  KConfigSkeleton::ItemBool  *itemWebinterfaceEnabled;
  itemWebinterfaceEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "WebinterfaceEnabled" ), mWebinterfaceEnabled, false );
  addItem( itemWebinterfaceEnabled, QStringLiteral( "WebinterfaceEnabled" ) );
  KConfigSkeleton::ItemInt  *itemWebinterfacePort;
  itemWebinterfacePort = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "WebinterfacePort" ), mWebinterfacePort, 8080 );
  addItem( itemWebinterfacePort, QStringLiteral( "WebinterfacePort" ) );
  KConfigSkeleton::ItemString  *itemWebinterfaceUser;
  itemWebinterfaceUser = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "WebinterfaceUser" ), mWebinterfaceUser, QStringLiteral( "admin" ) );
  addItem( itemWebinterfaceUser, QStringLiteral( "WebinterfaceUser" ) );

  setCurrentGroup( QStringLiteral( "Groups" ) );

  KConfigSkeleton::ItemBool  *itemDirectoriesAsSuggestion;
  itemDirectoriesAsSuggestion = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DirectoriesAsSuggestion" ), mDirectoriesAsSuggestion, false );
  addItem( itemDirectoriesAsSuggestion, QStringLiteral( "DirectoriesAsSuggestion" ) );
  KConfigSkeleton::ItemBool  *itemAskForDestination;
  itemAskForDestination = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AskForDestination" ), mAskForDestination, true );
  addItem( itemAskForDestination, QStringLiteral( "AskForDestination" ) );

  setCurrentGroup( QStringLiteral( "Internal" ) );

  KConfigSkeleton::ItemPoint  *itemMainPosition;
  itemMainPosition = new KConfigSkeleton::ItemPoint( currentGroup(), QStringLiteral( "MainPosition" ), mMainPosition );
  addItem( itemMainPosition, QStringLiteral( "MainPosition" ) );
  KConfigSkeleton::ItemInt  *itemMainState;
  itemMainState = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "MainState" ), mMainState, 0 );
  addItem( itemMainState, QStringLiteral( "MainState" ) );
  KConfigSkeleton::ItemPoint  *itemDropPosition;
  itemDropPosition = new KConfigSkeleton::ItemPoint( currentGroup(), QStringLiteral( "DropPosition" ), mDropPosition, QPoint(-1, -1) );
  addItem( itemDropPosition, QStringLiteral( "DropPosition" ) );
  KConfigSkeleton::ItemBool  *itemDropSticky;
  itemDropSticky = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DropSticky" ), mDropSticky, 0 );
  addItem( itemDropSticky, QStringLiteral( "DropSticky" ) );
  KConfigSkeleton::ItemBool  *itemFirstRun;
  itemFirstRun = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FirstRun" ), mFirstRun, true );
  addItem( itemFirstRun, QStringLiteral( "FirstRun" ) );
  KConfigSkeleton::ItemPath  *itemLastDirectory;
  itemLastDirectory = new KConfigSkeleton::ItemPath( currentGroup(), QStringLiteral( "LastDirectory" ), mLastDirectory, QStandardPaths::writableLocation(QStandardPaths::DownloadLocation) );
  addItem( itemLastDirectory, QStringLiteral( "LastDirectory" ) );
  KConfigSkeleton::ItemString  *itemLastGroup;
  itemLastGroup = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LastGroup" ), mLastGroup );
  addItem( itemLastGroup, QStringLiteral( "LastGroup" ) );
  KConfigSkeleton::ItemInt  *itemLinkViewFilterPatternSyntax;
  itemLinkViewFilterPatternSyntax = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "LinkViewFilterPatternSyntax" ), mLinkViewFilterPatternSyntax, 0 );
  addItem( itemLinkViewFilterPatternSyntax, QStringLiteral( "LinkViewFilterPatternSyntax" ) );

  setCurrentGroup( QStringLiteral( "Geometry" ) );

  QList<int> defaultHistoryColumnWidths;

  KConfigSkeleton::ItemIntList  *itemHistoryColumnWidths;
  itemHistoryColumnWidths = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "HistoryColumnWidths" ), mHistoryColumnWidths, defaultHistoryColumnWidths );
  addItem( itemHistoryColumnWidths, QStringLiteral( "HistoryColumnWidths" ) );

  setCurrentGroup( QStringLiteral( "Verification" ) );

  KConfigSkeleton::ItemBool  *itemChecksumAutomaticVerification;
  itemChecksumAutomaticVerification = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ChecksumAutomaticVerification" ), mChecksumAutomaticVerification, 1 );
  addItem( itemChecksumAutomaticVerification, QStringLiteral( "ChecksumAutomaticVerification" ) );
  KConfigSkeleton::ItemInt  *itemChecksumStrength;
  itemChecksumStrength = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ChecksumStrength" ), mChecksumStrength, 1 );
  addItem( itemChecksumStrength, QStringLiteral( "ChecksumStrength" ) );
  KConfigSkeleton::ItemBool  *itemSignatureAutomaticVerification;
  itemSignatureAutomaticVerification = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SignatureAutomaticVerification" ), mSignatureAutomaticVerification, 1 );
  addItem( itemSignatureAutomaticVerification, QStringLiteral( "SignatureAutomaticVerification" ) );
  KConfigSkeleton::ItemBool  *itemSignatureAutomaticDownloading;
  itemSignatureAutomaticDownloading = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SignatureAutomaticDownloading" ), mSignatureAutomaticDownloading, 1 );
  addItem( itemSignatureAutomaticDownloading, QStringLiteral( "SignatureAutomaticDownloading" ) );
  QStringList defaultSignatureKeyServers;
  defaultSignatureKeyServers.append( QString::fromUtf8( "http://keys.gnupg.net" ) );
  defaultSignatureKeyServers.append( QString::fromUtf8( "http://stinkfoot.org" ) );
  defaultSignatureKeyServers.append( QString::fromUtf8( "http://pgp.mit.edu" ) );
  defaultSignatureKeyServers.append( QString::fromUtf8( "http://pgp.surfnet.nl" ) );
  defaultSignatureKeyServers.append( QString::fromUtf8( "http://keyserver.gingerbear.net" ) );

  KConfigSkeleton::ItemStringList  *itemSignatureKeyServers;
  itemSignatureKeyServers = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "SignatureKeyServers" ), mSignatureKeyServers, defaultSignatureKeyServers );
  addItem( itemSignatureKeyServers, QStringLiteral( "SignatureKeyServers" ) );
}

Settings::~Settings()
{
  if (s_globalSettings.exists() && !s_globalSettings.isDestroyed()) {
    s_globalSettings()->q = nullptr;
  }
}

