/********************************************************************************
** Form generated from reading UI file 'fileselection.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILESELECTION_H
#define UI_FILESELECTION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktitlewidget.h"

QT_BEGIN_NAMESPACE

class Ui_FileSelection
{
public:
    QVBoxLayout *verticalLayout;
    KTitleWidget *ktitlewidget;
    QTreeView *treeView;

    void setupUi(QWidget *FileSelection)
    {
        if (FileSelection->objectName().isEmpty())
            FileSelection->setObjectName("FileSelection");
        FileSelection->resize(400, 300);
        verticalLayout = new QVBoxLayout(FileSelection);
        verticalLayout->setObjectName("verticalLayout");
        ktitlewidget = new KTitleWidget(FileSelection);
        ktitlewidget->setObjectName("ktitlewidget");

        verticalLayout->addWidget(ktitlewidget);

        treeView = new QTreeView(FileSelection);
        treeView->setObjectName("treeView");
        treeView->setUniformRowHeights(true);
        treeView->setSortingEnabled(true);
        treeView->header()->setDefaultSectionSize(150);

        verticalLayout->addWidget(treeView);


        retranslateUi(FileSelection);

        QMetaObject::connectSlotsByName(FileSelection);
    } // setupUi

    void retranslateUi(QWidget *FileSelection)
    {
        ktitlewidget->setText(tr2i18n("Select the files you want to be downloaded.", nullptr));
        (void)FileSelection;
    } // retranslateUi

};

namespace Ui {
    class FileSelection: public Ui_FileSelection {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILESELECTION_H

