/********************************************************************************
** Form generated from reading UI file 'verificationpreferences.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VERIFICATIONPREFERENCES_H
#define UI_VERIFICATIONPREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "keditlistwidget.h"

QT_BEGIN_NAMESPACE

class Ui_VerificationPreferences
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *kcfg_ChecksumAutomaticVerification;
    QFormLayout *formLayout;
    QLabel *label_3;
    QGroupBox *kcfg_ChecksumStrength;
    QVBoxLayout *verticalLayout_5;
    QRadioButton *radioButton_4;
    QRadioButton *radioButton_5;
    QRadioButton *radioButton_6;
    QGroupBox *signatureGroup;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *kcfg_SignatureAutomaticVerification;
    QCheckBox *kcfg_SignatureAutomaticDownloading;
    QSpacerItem *verticalSpacer;
    QLabel *label;
    KEditListWidget *keyservers;
    QButtonGroup *buttonGroup;

    void setupUi(QWidget *VerificationPreferences)
    {
        if (VerificationPreferences->objectName().isEmpty())
            VerificationPreferences->setObjectName("VerificationPreferences");
        VerificationPreferences->resize(400, 438);
        verticalLayout = new QVBoxLayout(VerificationPreferences);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_ChecksumAutomaticVerification = new QGroupBox(VerificationPreferences);
        kcfg_ChecksumAutomaticVerification->setObjectName("kcfg_ChecksumAutomaticVerification");
        kcfg_ChecksumAutomaticVerification->setFlat(false);
        kcfg_ChecksumAutomaticVerification->setCheckable(true);
        formLayout = new QFormLayout(kcfg_ChecksumAutomaticVerification);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_3 = new QLabel(kcfg_ChecksumAutomaticVerification);
        label_3->setObjectName("label_3");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_ChecksumStrength = new QGroupBox(kcfg_ChecksumAutomaticVerification);
        kcfg_ChecksumStrength->setObjectName("kcfg_ChecksumStrength");
        kcfg_ChecksumStrength->setFlat(true);
        verticalLayout_5 = new QVBoxLayout(kcfg_ChecksumStrength);
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        verticalLayout_5->setObjectName("verticalLayout_5");
        radioButton_4 = new QRadioButton(kcfg_ChecksumStrength);
        buttonGroup = new QButtonGroup(VerificationPreferences);
        buttonGroup->setObjectName("buttonGroup");
        buttonGroup->addButton(radioButton_4);
        radioButton_4->setObjectName("radioButton_4");

        verticalLayout_5->addWidget(radioButton_4);

        radioButton_5 = new QRadioButton(kcfg_ChecksumStrength);
        buttonGroup->addButton(radioButton_5);
        radioButton_5->setObjectName("radioButton_5");

        verticalLayout_5->addWidget(radioButton_5);

        radioButton_6 = new QRadioButton(kcfg_ChecksumStrength);
        buttonGroup->addButton(radioButton_6);
        radioButton_6->setObjectName("radioButton_6");

        verticalLayout_5->addWidget(radioButton_6);


        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_ChecksumStrength);


        verticalLayout->addWidget(kcfg_ChecksumAutomaticVerification);

        signatureGroup = new QGroupBox(VerificationPreferences);
        signatureGroup->setObjectName("signatureGroup");
        verticalLayout_4 = new QVBoxLayout(signatureGroup);
        verticalLayout_4->setObjectName("verticalLayout_4");
        kcfg_SignatureAutomaticVerification = new QCheckBox(signatureGroup);
        kcfg_SignatureAutomaticVerification->setObjectName("kcfg_SignatureAutomaticVerification");

        verticalLayout_4->addWidget(kcfg_SignatureAutomaticVerification);

        kcfg_SignatureAutomaticDownloading = new QCheckBox(signatureGroup);
        kcfg_SignatureAutomaticDownloading->setObjectName("kcfg_SignatureAutomaticDownloading");

        verticalLayout_4->addWidget(kcfg_SignatureAutomaticDownloading);

        verticalSpacer = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_4->addItem(verticalSpacer);

        label = new QLabel(signatureGroup);
        label->setObjectName("label");

        verticalLayout_4->addWidget(label);

        keyservers = new KEditListWidget(signatureGroup);
        keyservers->setObjectName("keyservers");

        verticalLayout_4->addWidget(keyservers);


        verticalLayout->addWidget(signatureGroup);


        retranslateUi(VerificationPreferences);

        QMetaObject::connectSlotsByName(VerificationPreferences);
    } // setupUi

    void retranslateUi(QWidget *VerificationPreferences)
    {
        kcfg_ChecksumAutomaticVerification->setTitle(tr2i18n("Automatic checksums verification", nullptr));
        label_3->setText(tr2i18n("Used checksum:", nullptr));
        kcfg_ChecksumStrength->setTitle(QString());
        radioButton_4->setText(tr2i18n("Weak (fastest)", nullptr));
        radioButton_5->setText(tr2i18n("Strong (recommended)", nullptr));
        radioButton_6->setText(tr2i18n("Strongest (slowest)", nullptr));
        signatureGroup->setTitle(tr2i18n("Signature", nullptr));
        kcfg_SignatureAutomaticVerification->setText(tr2i18n("Automatic verification", nullptr));
        kcfg_SignatureAutomaticDownloading->setText(tr2i18n("Automatic downloading of missing keys", nullptr));
        label->setText(tr2i18n("Keyservers:", nullptr));
        (void)VerificationPreferences;
    } // retranslateUi

};

namespace Ui {
    class VerificationPreferences: public Ui_VerificationPreferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VERIFICATIONPREFERENCES_H

