/****************************************************************************
** Meta object code from reading C++ file 'datasourcefactory.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kget-26.08.0/core/datasourcefactory.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'datasourcefactory.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17DataSourceFactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto DataSourceFactory::qt_create_metaobjectdata<qt_meta_tag_ZN17DataSourceFactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DataSourceFactory",
        "capabilitiesChanged",
        "",
        "dataSourceFactoryChange",
        "Transfer::ChangesFlags",
        "change",
        "log",
        "message",
        "Transfer::LogLevel",
        "logLevel",
        "save",
        "QDomElement",
        "element",
        "load",
        "const QDomElement*",
        "e",
        "slotUpdateCapabilities",
        "slotRemovedFile",
        "findFileSize",
        "slotFoundFileSize",
        "TransferDataSource*",
        "source",
        "KIO::filesize_t",
        "fileSize",
        "std::pair<int,int>",
        "segmentRange",
        "assignSegments",
        "brokenSegments",
        "finishedSegment",
        "segmentNumber",
        "connectionFinished",
        "broken",
        "TransferDataSource::Error",
        "error",
        "slotFreeSegments",
        "slotWriteData",
        "KIO::fileoffset_t",
        "offset",
        "data",
        "bool&",
        "worked",
        "slotOffset",
        "KIO::Job*",
        "job",
        "slotDataWritten",
        "slotPercent",
        "KJob*",
        "percent",
        "slotOpen",
        "speedChanged",
        "startMove",
        "slotPutJobDestroyed",
        "newDestResult",
        "slotRepair",
        "QList<KIO::fileoffset_t>",
        "offsets",
        "length",
        "slotFinishedDownload",
        "size",
        "slotUrlChanged",
        "QUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'capabilitiesChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataSourceFactoryChange'
        QtMocHelpers::SignalData<void(Transfer::ChangesFlags)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'log'
        QtMocHelpers::SignalData<void(const QString &, Transfer::LogLevel)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void(const QDomElement &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void(const QDomElement *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slotUpdateCapabilities'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemovedFile'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'findFileSize'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFoundFileSize'
        QtMocHelpers::SlotData<void(TransferDataSource *, KIO::filesize_t, const QPair<int,int> &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'assignSegments'
        QtMocHelpers::SlotData<void(TransferDataSource *)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'brokenSegments'
        QtMocHelpers::SlotData<void(TransferDataSource *, const QPair<int,int> &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'finishedSegment'
        QtMocHelpers::SlotData<void(TransferDataSource *, int, bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { QMetaType::Int, 29 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'finishedSegment'
        QtMocHelpers::SlotData<void(TransferDataSource *, int)>(28, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'broken'
        QtMocHelpers::SlotData<void(TransferDataSource *, TransferDataSource::Error)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 32, 33 },
        }}),
        // Slot 'slotFreeSegments'
        QtMocHelpers::SlotData<void(TransferDataSource *, QPair<int,int>)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'slotWriteData'
        QtMocHelpers::SlotData<void(KIO::fileoffset_t, const QByteArray &, bool &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { QMetaType::QByteArray, 38 }, { 0x80000000 | 39, 40 },
        }}),
        // Slot 'slotOffset'
        QtMocHelpers::SlotData<void(KIO::Job *, KIO::filesize_t)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 43 }, { 0x80000000 | 22, 37 },
        }}),
        // Slot 'slotDataWritten'
        QtMocHelpers::SlotData<void(KIO::Job *, KIO::filesize_t)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 43 }, { 0x80000000 | 22, 37 },
        }}),
        // Slot 'slotPercent'
        QtMocHelpers::SlotData<void(KJob *, ulong)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 43 }, { QMetaType::ULong, 47 },
        }}),
        // Slot 'slotOpen'
        QtMocHelpers::SlotData<void(KIO::Job *)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'speedChanged'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startMove'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPutJobDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 43 },
        }}),
        // Slot 'newDestResult'
        QtMocHelpers::SlotData<void(KJob *)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 43 },
        }}),
        // Slot 'slotRepair'
        QtMocHelpers::SlotData<void(const QList<KIO::fileoffset_t> &, KIO::filesize_t)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 54, 55 }, { 0x80000000 | 22, 56 },
        }}),
        // Slot 'slotFinishedDownload'
        QtMocHelpers::SlotData<void(TransferDataSource *, KIO::filesize_t)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 22, 58 },
        }}),
        // Slot 'slotUrlChanged'
        QtMocHelpers::SlotData<void(const QUrl &, const QUrl &)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 60, 2 }, { 0x80000000 | 60, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DataSourceFactory, qt_meta_tag_ZN17DataSourceFactoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DataSourceFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DataSourceFactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DataSourceFactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DataSourceFactoryE_t>.metaTypes,
    nullptr
} };

void DataSourceFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataSourceFactory *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->capabilitiesChanged(); break;
        case 1: _t->dataSourceFactoryChange((*reinterpret_cast<std::add_pointer_t<Transfer::ChangesFlags>>(_a[1]))); break;
        case 2: _t->log((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Transfer::LogLevel>>(_a[2]))); break;
        case 3: _t->save((*reinterpret_cast<std::add_pointer_t<QDomElement>>(_a[1]))); break;
        case 4: _t->load((*reinterpret_cast<std::add_pointer_t<const QDomElement*>>(_a[1]))); break;
        case 5: _t->slotUpdateCapabilities(); break;
        case 6: _t->slotRemovedFile(); break;
        case 7: _t->findFileSize(); break;
        case 8: _t->slotFoundFileSize((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[3]))); break;
        case 9: _t->assignSegments((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1]))); break;
        case 10: _t->brokenSegments((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[2]))); break;
        case 11: _t->finishedSegment((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 12: _t->finishedSegment((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 13: _t->broken((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TransferDataSource::Error>>(_a[2]))); break;
        case 14: _t->slotFreeSegments((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[2]))); break;
        case 15: _t->slotWriteData((*reinterpret_cast<std::add_pointer_t<KIO::fileoffset_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3]))); break;
        case 16: _t->slotOffset((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[2]))); break;
        case 17: _t->slotDataWritten((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[2]))); break;
        case 18: _t->slotPercent((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2]))); break;
        case 19: _t->slotOpen((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1]))); break;
        case 20: _t->speedChanged(); break;
        case 21: _t->startMove(); break;
        case 22: _t->slotPutJobDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 23: _t->newDestResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 24: _t->slotRepair((*reinterpret_cast<std::add_pointer_t<QList<KIO::fileoffset_t>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[2]))); break;
        case 25: _t->slotFinishedDownload((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[2]))); break;
        case 26: _t->slotUrlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DataSourceFactory::*)()>(_a, &DataSourceFactory::capabilitiesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataSourceFactory::*)(Transfer::ChangesFlags )>(_a, &DataSourceFactory::dataSourceFactoryChange, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataSourceFactory::*)(const QString & , Transfer::LogLevel )>(_a, &DataSourceFactory::log, 2))
            return;
    }
}

const QMetaObject *DataSourceFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DataSourceFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DataSourceFactoryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DataSourceFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void DataSourceFactory::capabilitiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DataSourceFactory::dataSourceFactoryChange(Transfer::ChangesFlags _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DataSourceFactory::log(const QString & _t1, Transfer::LogLevel _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
