/****************************************************************************
** Meta object code from reading C++ file 'transferdatasource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kget-26.08.0/core/transferdatasource.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transferdatasource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18TransferDataSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto TransferDataSource::qt_create_metaobjectdata<qt_meta_tag_ZN18TransferDataSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransferDataSource",
        "foundFileSize",
        "",
        "TransferDataSource*",
        "source",
        "KIO::filesize_t",
        "fileSize",
        "std::pair<int,int>",
        "segmentRange",
        "capabilitiesChanged",
        "finishedDownload",
        "data",
        "KIO::fileoffset_t",
        "offset",
        "bool&",
        "worked",
        "QList<QUrl>",
        "type",
        "checksum",
        "finished",
        "finishedSegment",
        "segmentNumber",
        "connectionFinished",
        "broken",
        "TransferDataSource::Error",
        "error",
        "brokenSegments",
        "speed",
        "freeSegments",
        "log",
        "message",
        "Transfer::LogLevel",
        "logLevel",
        "urlChanged",
        "QUrl",
        "old",
        "newUrl",
        "slotSpeed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'foundFileSize'
        QtMocHelpers::SignalData<void(TransferDataSource *, KIO::filesize_t, const QPair<int,int> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'capabilitiesChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finishedDownload'
        QtMocHelpers::SignalData<void(TransferDataSource *, KIO::filesize_t)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'data'
        QtMocHelpers::SignalData<void(KIO::fileoffset_t, const QByteArray &, bool &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::QByteArray, 11 }, { 0x80000000 | 14, 15 },
        }}),
        // Signal 'data'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 11 },
        }}),
        // Signal 'data'
        QtMocHelpers::SignalData<void(const QString, const QString)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finishedSegment'
        QtMocHelpers::SignalData<void(TransferDataSource *, int, bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Signal 'finishedSegment'
        QtMocHelpers::SignalData<void(TransferDataSource *, int)>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 21 },
        }}),
        // Signal 'broken'
        QtMocHelpers::SignalData<void(TransferDataSource *, TransferDataSource::Error)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 24, 25 },
        }}),
        // Signal 'brokenSegments'
        QtMocHelpers::SignalData<void(TransferDataSource *, QPair<int,int>)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'speed'
        QtMocHelpers::SignalData<void(ulong)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULong, 27 },
        }}),
        // Signal 'freeSegments'
        QtMocHelpers::SignalData<void(TransferDataSource *, QPair<int,int>)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'log'
        QtMocHelpers::SignalData<void(const QString &, Transfer::LogLevel)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { 0x80000000 | 31, 32 },
        }}),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void(const QUrl &, const QUrl &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { 0x80000000 | 34, 36 },
        }}),
        // Slot 'slotSpeed'
        QtMocHelpers::SlotData<void(ulong)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULong, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransferDataSource, qt_meta_tag_ZN18TransferDataSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransferDataSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TransferDataSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TransferDataSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18TransferDataSourceE_t>.metaTypes,
    nullptr
} };

void TransferDataSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransferDataSource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->foundFileSize((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[3]))); break;
        case 1: _t->capabilitiesChanged(); break;
        case 2: _t->finishedDownload((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[2]))); break;
        case 3: _t->data((*reinterpret_cast<std::add_pointer_t<KIO::fileoffset_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3]))); break;
        case 4: _t->data((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 5: _t->data((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->finished(); break;
        case 7: _t->finishedSegment((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 8: _t->finishedSegment((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->broken((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TransferDataSource::Error>>(_a[2]))); break;
        case 10: _t->brokenSegments((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[2]))); break;
        case 11: _t->speed((*reinterpret_cast<std::add_pointer_t<ulong>>(_a[1]))); break;
        case 12: _t->freeSegments((*reinterpret_cast<std::add_pointer_t<TransferDataSource*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[2]))); break;
        case 13: _t->log((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Transfer::LogLevel>>(_a[2]))); break;
        case 14: _t->urlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 15: _t->slotSpeed((*reinterpret_cast<std::add_pointer_t<ulong>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferDataSource* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)(TransferDataSource * , KIO::filesize_t , const QPair<int,int> & )>(_a, &TransferDataSource::foundFileSize, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)()>(_a, &TransferDataSource::capabilitiesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)(TransferDataSource * , KIO::filesize_t )>(_a, &TransferDataSource::finishedDownload, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)(KIO::fileoffset_t , const QByteArray & , bool & )>(_a, &TransferDataSource::data, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)(const QList<QUrl> & )>(_a, &TransferDataSource::data, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)(const QString , const QString )>(_a, &TransferDataSource::data, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)()>(_a, &TransferDataSource::finished, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)(TransferDataSource * , int , bool )>(_a, &TransferDataSource::finishedSegment, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)(TransferDataSource * , TransferDataSource::Error )>(_a, &TransferDataSource::broken, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)(TransferDataSource * , QPair<int,int> )>(_a, &TransferDataSource::brokenSegments, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)(ulong )>(_a, &TransferDataSource::speed, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)(TransferDataSource * , QPair<int,int> )>(_a, &TransferDataSource::freeSegments, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)(const QString & , Transfer::LogLevel )>(_a, &TransferDataSource::log, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferDataSource::*)(const QUrl & , const QUrl & )>(_a, &TransferDataSource::urlChanged, 14))
            return;
    }
}

const QMetaObject *TransferDataSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransferDataSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TransferDataSourceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TransferDataSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void TransferDataSource::foundFileSize(TransferDataSource * _t1, KIO::filesize_t _t2, const QPair<int,int> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void TransferDataSource::capabilitiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TransferDataSource::finishedDownload(TransferDataSource * _t1, KIO::filesize_t _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void TransferDataSource::data(KIO::fileoffset_t _t1, const QByteArray & _t2, bool & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void TransferDataSource::data(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void TransferDataSource::data(const QString _t1, const QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void TransferDataSource::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void TransferDataSource::finishedSegment(TransferDataSource * _t1, int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void TransferDataSource::broken(TransferDataSource * _t1, TransferDataSource::Error _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void TransferDataSource::brokenSegments(TransferDataSource * _t1, QPair<int,int> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void TransferDataSource::speed(ulong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void TransferDataSource::freeSegments(TransferDataSource * _t1, QPair<int,int> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void TransferDataSource::log(const QString & _t1, Transfer::LogLevel _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void TransferDataSource::urlChanged(const QUrl & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}
QT_WARNING_POP
