/********************************************************************************
** Form generated from reading UI file 'dlgwebinterface.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DLGWEBINTERFACE_H
#define UI_DLGWEBINTERFACE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "kpasswordlineedit.h"

QT_BEGIN_NAMESPACE

class Ui_DlgWebinterface
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *kcfg_WebinterfaceEnabled;
    QFormLayout *formLayout;
    QLabel *portLabel;
    QSpinBox *kcfg_WebinterfacePort;
    QLabel *userLabel;
    KLineEdit *kcfg_WebinterfaceUser;
    QLabel *passwordLabel;
    KPasswordLineEdit *webinterfacePwd;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *DlgWebinterface)
    {
        if (DlgWebinterface->objectName().isEmpty())
            DlgWebinterface->setObjectName("DlgWebinterface");
        DlgWebinterface->resize(400, 389);
        verticalLayout = new QVBoxLayout(DlgWebinterface);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        kcfg_WebinterfaceEnabled = new QGroupBox(DlgWebinterface);
        kcfg_WebinterfaceEnabled->setObjectName("kcfg_WebinterfaceEnabled");
        kcfg_WebinterfaceEnabled->setCheckable(true);
        kcfg_WebinterfaceEnabled->setChecked(false);
        formLayout = new QFormLayout(kcfg_WebinterfaceEnabled);
        formLayout->setObjectName("formLayout");
        portLabel = new QLabel(kcfg_WebinterfaceEnabled);
        portLabel->setObjectName("portLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, portLabel);

        kcfg_WebinterfacePort = new QSpinBox(kcfg_WebinterfaceEnabled);
        kcfg_WebinterfacePort->setObjectName("kcfg_WebinterfacePort");
        kcfg_WebinterfacePort->setMaximum(100000);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_WebinterfacePort);

        userLabel = new QLabel(kcfg_WebinterfaceEnabled);
        userLabel->setObjectName("userLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, userLabel);

        kcfg_WebinterfaceUser = new KLineEdit(kcfg_WebinterfaceEnabled);
        kcfg_WebinterfaceUser->setObjectName("kcfg_WebinterfaceUser");
        kcfg_WebinterfaceUser->setProperty("showClearButton", QVariant(true));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_WebinterfaceUser);

        passwordLabel = new QLabel(kcfg_WebinterfaceEnabled);
        passwordLabel->setObjectName("passwordLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, passwordLabel);

        webinterfacePwd = new KPasswordLineEdit(kcfg_WebinterfaceEnabled);
        webinterfacePwd->setObjectName("webinterfacePwd");
        webinterfacePwd->setClearButtonEnabled(true);
        webinterfacePwd->setEchoMode(QLineEdit::Password);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, webinterfacePwd);


        verticalLayout->addWidget(kcfg_WebinterfaceEnabled);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);


        retranslateUi(DlgWebinterface);

        QMetaObject::connectSlotsByName(DlgWebinterface);
    } // setupUi

    void retranslateUi(QWidget *DlgWebinterface)
    {
        kcfg_WebinterfaceEnabled->setTitle(tr2i18n("Enable Web Interface", nullptr));
        portLabel->setText(tr2i18n("Port:", nullptr));
        userLabel->setText(tr2i18n("User:", nullptr));
        passwordLabel->setText(tr2i18n("Password:", nullptr));
        (void)DlgWebinterface;
    } // retranslateUi

};

namespace Ui {
    class DlgWebinterface: public Ui_DlgWebinterface {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DLGWEBINTERFACE_H

