/********************************************************************************
** Form generated from reading UI file 'scandlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCANDLG_H
#define UI_SCANDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ScanDlgBase
{
public:
    QGridLayout *gridLayout;
    QLabel *torrent_label;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    QLabel *textLabel2;
    QLabel *textLabel3;
    QLabel *label;
    QLabel *label_2;
    QVBoxLayout *vboxLayout1;
    QLabel *chunks_found;
    QLabel *chunks_failed;
    QLabel *chunks_not_downloaded;
    QLabel *chunks_downloaded;
    QProgressBar *progress;
    QFrame *line1;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem;
    QPushButton *cancel;

    void setupUi(QWidget *ScanDlgBase)
    {
        if (ScanDlgBase->objectName().isEmpty())
            ScanDlgBase->setObjectName("ScanDlgBase");
        ScanDlgBase->resize(402, 221);
        gridLayout = new QGridLayout(ScanDlgBase);
        gridLayout->setObjectName("gridLayout");
        torrent_label = new QLabel(ScanDlgBase);
        torrent_label->setObjectName("torrent_label");
        torrent_label->setWordWrap(false);

        gridLayout->addWidget(torrent_label, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        textLabel2 = new QLabel(ScanDlgBase);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        vboxLayout->addWidget(textLabel2);

        textLabel3 = new QLabel(ScanDlgBase);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setWordWrap(false);

        vboxLayout->addWidget(textLabel3);

        label = new QLabel(ScanDlgBase);
        label->setObjectName("label");

        vboxLayout->addWidget(label);

        label_2 = new QLabel(ScanDlgBase);
        label_2->setObjectName("label_2");

        vboxLayout->addWidget(label_2);


        hboxLayout->addLayout(vboxLayout);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        chunks_found = new QLabel(ScanDlgBase);
        chunks_found->setObjectName("chunks_found");
        chunks_found->setMinimumSize(QSize(100, 0));
        chunks_found->setFrameShape(QFrame::Box);
        chunks_found->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        chunks_found->setWordWrap(false);

        vboxLayout1->addWidget(chunks_found);

        chunks_failed = new QLabel(ScanDlgBase);
        chunks_failed->setObjectName("chunks_failed");
        chunks_failed->setMinimumSize(QSize(100, 0));
        chunks_failed->setFrameShape(QFrame::Box);
        chunks_failed->setFrameShadow(QFrame::Plain);
        chunks_failed->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        chunks_failed->setWordWrap(false);

        vboxLayout1->addWidget(chunks_failed);

        chunks_not_downloaded = new QLabel(ScanDlgBase);
        chunks_not_downloaded->setObjectName("chunks_not_downloaded");
        chunks_not_downloaded->setMinimumSize(QSize(100, 0));
        chunks_not_downloaded->setFrameShape(QFrame::Box);
        chunks_not_downloaded->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout1->addWidget(chunks_not_downloaded);

        chunks_downloaded = new QLabel(ScanDlgBase);
        chunks_downloaded->setObjectName("chunks_downloaded");
        chunks_downloaded->setFrameShape(QFrame::Box);
        chunks_downloaded->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        vboxLayout1->addWidget(chunks_downloaded);


        hboxLayout->addLayout(vboxLayout1);


        gridLayout->addLayout(hboxLayout, 1, 0, 1, 1);

        progress = new QProgressBar(ScanDlgBase);
        progress->setObjectName("progress");
        progress->setValue(24);

        gridLayout->addWidget(progress, 2, 0, 1, 1);

        line1 = new QFrame(ScanDlgBase);
        line1->setObjectName("line1");
        line1->setFrameShape(QFrame::HLine);
        line1->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(line1, 3, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);

        cancel = new QPushButton(ScanDlgBase);
        cancel->setObjectName("cancel");

        hboxLayout1->addWidget(cancel);


        gridLayout->addLayout(hboxLayout1, 4, 0, 1, 1);


        retranslateUi(ScanDlgBase);

        QMetaObject::connectSlotsByName(ScanDlgBase);
    } // setupUi

    void retranslateUi(QWidget *ScanDlgBase)
    {
        torrent_label->setText(tr2i18n("Scanning data of torrent:", nullptr));
        textLabel2->setText(tr2i18n("Number of chunks found:", nullptr));
        textLabel3->setText(tr2i18n("Number of chunks failed:", nullptr));
        label->setText(tr2i18n("Number of chunks not downloaded:", nullptr));
        label_2->setText(tr2i18n("Number of chunks downloaded:", nullptr));
        chunks_found->setText(tr2i18n("0", nullptr));
        chunks_failed->setText(tr2i18n("0", nullptr));
        chunks_not_downloaded->setText(tr2i18n("0", nullptr));
        chunks_downloaded->setText(tr2i18n("0", nullptr));
        progress->setFormat(tr2i18n("%p%", nullptr));
        cancel->setText(tr2i18n("Cancel", nullptr));
        (void)ScanDlgBase;
    } // retranslateUi

};

namespace Ui {
    class ScanDlgBase: public Ui_ScanDlgBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCANDLG_H

