/********************************************************************************
** Form generated from reading UI file 'signaturedlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SIGNATUREDLG_H
#define UI_SIGNATUREDLG_H

#include <KMessageWidget>
#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SignatureDlg
{
public:
    QVBoxLayout *verticalLayout_2;
    KMessageWidget *information;
    QGroupBox *sigGroup;
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label_8;
    QHBoxLayout *horizontalLayout_4;
    QLabel *verificationIcon;
    QLabel *verified;
    QSpacerItem *horizontalSpacer;
    QLabel *binaryLabel;
    QLabel *asciiLabel;
    QTextEdit *signature;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *loadSignature;
    QPushButton *verify;
    QGroupBox *keyGroup;
    QFormLayout *formLayout_2;
    QLabel *label;
    QLabel *issuer;
    QLabel *label_2;
    QLabel *email;
    QLabel *label_9;
    QLabel *comment;
    QLabel *label_3;
    QLabel *creation;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_3;
    QLabel *expirationIcon;
    QLabel *expiration;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout;
    QLabel *trustIcon;
    QLabel *trust;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_6;
    QLabel *fingerprint;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *SignatureDlg)
    {
        if (SignatureDlg->objectName().isEmpty())
            SignatureDlg->setObjectName("SignatureDlg");
        SignatureDlg->resize(400, 492);
        verticalLayout_2 = new QVBoxLayout(SignatureDlg);
        verticalLayout_2->setObjectName("verticalLayout_2");
        information = new KMessageWidget(SignatureDlg);
        information->setObjectName("information");

        verticalLayout_2->addWidget(information);

        sigGroup = new QGroupBox(SignatureDlg);
        sigGroup->setObjectName("sigGroup");
        verticalLayout = new QVBoxLayout(sigGroup);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label_8 = new QLabel(sigGroup);
        label_8->setObjectName("label_8");
        QFont font;
        font.setBold(true);
        label_8->setFont(font);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_8);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        verificationIcon = new QLabel(sigGroup);
        verificationIcon->setObjectName("verificationIcon");

        horizontalLayout_4->addWidget(verificationIcon);

        verified = new QLabel(sigGroup);
        verified->setObjectName("verified");
        verified->setFont(font);

        horizontalLayout_4->addWidget(verified);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_4);


        verticalLayout->addLayout(formLayout);

        binaryLabel = new QLabel(sigGroup);
        binaryLabel->setObjectName("binaryLabel");

        verticalLayout->addWidget(binaryLabel);

        asciiLabel = new QLabel(sigGroup);
        asciiLabel->setObjectName("asciiLabel");

        verticalLayout->addWidget(asciiLabel);

        signature = new QTextEdit(sigGroup);
        signature->setObjectName("signature");

        verticalLayout->addWidget(signature);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_2);

        loadSignature = new QPushButton(sigGroup);
        loadSignature->setObjectName("loadSignature");

        horizontalLayout_5->addWidget(loadSignature);

        verify = new QPushButton(sigGroup);
        verify->setObjectName("verify");

        horizontalLayout_5->addWidget(verify);


        verticalLayout->addLayout(horizontalLayout_5);


        verticalLayout_2->addWidget(sigGroup);

        keyGroup = new QGroupBox(SignatureDlg);
        keyGroup->setObjectName("keyGroup");
        formLayout_2 = new QFormLayout(keyGroup);
        formLayout_2->setObjectName("formLayout_2");
        label = new QLabel(keyGroup);
        label->setObjectName("label");
        label->setFont(font);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        issuer = new QLabel(keyGroup);
        issuer->setObjectName("issuer");
        issuer->setFont(font);
        issuer->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, issuer);

        label_2 = new QLabel(keyGroup);
        label_2->setObjectName("label_2");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        email = new QLabel(keyGroup);
        email->setObjectName("email");
        email->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, email);

        label_9 = new QLabel(keyGroup);
        label_9->setObjectName("label_9");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_9);

        comment = new QLabel(keyGroup);
        comment->setObjectName("comment");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, comment);

        label_3 = new QLabel(keyGroup);
        label_3->setObjectName("label_3");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_3);

        creation = new QLabel(keyGroup);
        creation->setObjectName("creation");
        creation->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, creation);

        label_4 = new QLabel(keyGroup);
        label_4->setObjectName("label_4");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, label_4);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        expirationIcon = new QLabel(keyGroup);
        expirationIcon->setObjectName("expirationIcon");

        horizontalLayout_3->addWidget(expirationIcon);

        expiration = new QLabel(keyGroup);
        expiration->setObjectName("expiration");
        expiration->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        horizontalLayout_3->addWidget(expiration);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        formLayout_2->setLayout(4, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);

        label_5 = new QLabel(keyGroup);
        label_5->setObjectName("label_5");

        formLayout_2->setWidget(5, QFormLayout::ItemRole::LabelRole, label_5);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        trustIcon = new QLabel(keyGroup);
        trustIcon->setObjectName("trustIcon");

        horizontalLayout->addWidget(trustIcon);

        trust = new QLabel(keyGroup);
        trust->setObjectName("trust");
        trust->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        horizontalLayout->addWidget(trust);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_4);


        formLayout_2->setLayout(5, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_6 = new QLabel(keyGroup);
        label_6->setObjectName("label_6");

        formLayout_2->setWidget(6, QFormLayout::ItemRole::LabelRole, label_6);

        fingerprint = new QLabel(keyGroup);
        fingerprint->setObjectName("fingerprint");
        fingerprint->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_2->setWidget(6, QFormLayout::ItemRole::FieldRole, fingerprint);


        verticalLayout_2->addWidget(keyGroup);

        buttonBox = new QDialogButtonBox(SignatureDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(SignatureDlg);

        QMetaObject::connectSlotsByName(SignatureDlg);
    } // setupUi

    void retranslateUi(QWidget *SignatureDlg)
    {
        sigGroup->setTitle(tr2i18n("Signature", nullptr));
        label_8->setText(tr2i18n("Verification:", nullptr));
        verificationIcon->setText(QString());
        verified->setText(QString());
        binaryLabel->setText(tr2i18n("Has binary PGP signature.", nullptr));
        asciiLabel->setText(tr2i18n("Ascii PGP signature:", nullptr));
        loadSignature->setText(tr2i18n("Load Signature", nullptr));
        verify->setText(tr2i18n("Verify", nullptr));
        keyGroup->setTitle(tr2i18n("Key", nullptr));
        label->setText(tr2i18n("Issuer:", nullptr));
        issuer->setText(QString());
        label_2->setText(tr2i18n("E-Mail:", nullptr));
        email->setText(QString());
        label_9->setText(tr2i18n("Comment:", nullptr));
        comment->setText(QString());
        label_3->setText(tr2i18n("Creation:", nullptr));
        creation->setText(QString());
        label_4->setText(tr2i18n("Expiration:", nullptr));
        expirationIcon->setText(QString());
        expiration->setText(QString());
        label_5->setText(tr2i18n("Trust:", nullptr));
        trustIcon->setText(QString());
        trust->setText(QString());
        label_6->setText(tr2i18n("Fingerprint:", nullptr));
        fingerprint->setText(QString());
        (void)SignatureDlg;
    } // retranslateUi

};

namespace Ui {
    class SignatureDlg: public Ui_SignatureDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SIGNATUREDLG_H

