/********************************************************************************
** Form generated from reading UI file 'webseedstab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WEBSEEDSTAB_H
#define UI_WEBSEEDSTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klineedit.h>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WebSeedsTab
{
public:
    QGridLayout *gridLayout;
    KLineEdit *m_webseed;
    QPushButton *m_add;
    QTreeView *m_webseed_list;
    QVBoxLayout *vboxLayout;
    QPushButton *m_remove;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *WebSeedsTab)
    {
        if (WebSeedsTab->objectName().isEmpty())
            WebSeedsTab->setObjectName("WebSeedsTab");
        WebSeedsTab->resize(482, 300);
        gridLayout = new QGridLayout(WebSeedsTab);
        gridLayout->setObjectName("gridLayout");
        m_webseed = new KLineEdit(WebSeedsTab);
        m_webseed->setObjectName("m_webseed");

        gridLayout->addWidget(m_webseed, 0, 0, 1, 1);

        m_add = new QPushButton(WebSeedsTab);
        m_add->setObjectName("m_add");

        gridLayout->addWidget(m_add, 0, 1, 1, 1);

        m_webseed_list = new QTreeView(WebSeedsTab);
        m_webseed_list->setObjectName("m_webseed_list");
        m_webseed_list->setRootIsDecorated(false);
        m_webseed_list->setSortingEnabled(true);
        m_webseed_list->setAllColumnsShowFocus(true);

        gridLayout->addWidget(m_webseed_list, 1, 0, 1, 1);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        m_remove = new QPushButton(WebSeedsTab);
        m_remove->setObjectName("m_remove");

        vboxLayout->addWidget(m_remove);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        gridLayout->addLayout(vboxLayout, 1, 1, 1, 1);


        retranslateUi(WebSeedsTab);

        QMetaObject::connectSlotsByName(WebSeedsTab);
    } // setupUi

    void retranslateUi(QWidget *WebSeedsTab)
    {
#if QT_CONFIG(tooltip)
        m_webseed->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Bitstream Vera Sans'; font-size:8pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Webseed to add to the torrent.</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Note: </span>Only http webseeds are supported.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        m_add->setText(tr2i18n("Add Webseed", nullptr));
        m_remove->setText(tr2i18n("Remove Webseed", nullptr));
        (void)WebSeedsTab;
    } // retranslateUi

};

namespace Ui {
    class WebSeedsTab: public Ui_WebSeedsTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WEBSEEDSTAB_H

