// This file is generated by kconfig_compiler_kf6 from kget_mirrorsearchfactory.kcfg.
// All changes you do to this file will be lost.
#ifndef MIRRORSEARCHSETTINGS_H
#define MIRRORSEARCHSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class MirrorSearchSettings : public KConfigSkeleton
{
  public:

    static MirrorSearchSettings *self();
    ~MirrorSearchSettings() override;

    /**
      Set UseSearchEngines
    */
    static
    void setUseSearchEngines( bool v )
    {
      if (!self()->isUseSearchEnginesImmutable())
        self()->mUseSearchEngines = v;
    }

    /**
      Get UseSearchEngines
    */
    static
    bool useSearchEngines()
    {
      return self()->mUseSearchEngines;
    }

    /**
      Is UseSearchEngines Immutable
    */
    static
    bool isUseSearchEnginesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "UseSearchEngines" ) );
    }

    /**
      Set List of the available search engines
    */
    static
    void setSearchEnginesNameList( const QStringList & v )
    {
      if (!self()->isSearchEnginesNameListImmutable())
        self()->mSearchEnginesNameList = v;
    }

    /**
      Get List of the available search engines
    */
    static
    QStringList searchEnginesNameList()
    {
      return self()->mSearchEnginesNameList;
    }

    /**
      Is List of the available search engines Immutable
    */
    static
    bool isSearchEnginesNameListImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SearchEnginesNameList" ) );
    }

    /**
      Set List of the available search engine URLs
    */
    static
    void setSearchEnginesUrlList( const QStringList & v )
    {
      if (!self()->isSearchEnginesUrlListImmutable())
        self()->mSearchEnginesUrlList = v;
    }

    /**
      Get List of the available search engine URLs
    */
    static
    QStringList searchEnginesUrlList()
    {
      return self()->mSearchEnginesUrlList;
    }

    /**
      Is List of the available search engine URLs Immutable
    */
    static
    bool isSearchEnginesUrlListImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SearchEnginesUrlList" ) );
    }

  protected:
    MirrorSearchSettings();
    friend class MirrorSearchSettingsHelper;


    // SearchEngines
    bool mUseSearchEngines;
    QStringList mSearchEnginesNameList;
    QStringList mSearchEnginesUrlList;
};

#endif

