/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Shutdown.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef PLASMASHUDOWN_INTERFACE_H
#define PLASMASHUDOWN_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.Shutdown
 */
class OrgKdeShutdownInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.Shutdown"; }

public:
    OrgKdeShutdownInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeShutdownInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> logout()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("logout"), argumentList);
    }

    inline QDBusPendingReply<> logoutAndReboot()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("logoutAndReboot"), argumentList);
    }

    inline QDBusPendingReply<> logoutAndShutdown()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("logoutAndShutdown"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    using Shutdown = ::OrgKdeShutdownInterface;
  }
}

#endif
