/********************************************************************************
** Form generated from reading UI file 'verificationdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VERIFICATIONDIALOG_H
#define UI_VERIFICATIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_VerificationDialog
{
public:
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout_2;
    QTreeView *usedHashes;
    QWidget *verifying;
    QHBoxLayout *horizontalLayout;
    QLabel *label_4;
    QProgressBar *progressBar;
    QVBoxLayout *verticalLayout;
    QPushButton *add;
    QPushButton *remove;
    QPushButton *verify;
    QSpacerItem *verticalSpacer;
    QPushButton *closeButton;

    void setupUi(QWidget *VerificationDialog)
    {
        if (VerificationDialog->objectName().isEmpty())
            VerificationDialog->setObjectName("VerificationDialog");
        VerificationDialog->resize(500, 300);
        horizontalLayout_2 = new QHBoxLayout(VerificationDialog);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        usedHashes = new QTreeView(VerificationDialog);
        usedHashes->setObjectName("usedHashes");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(usedHashes->sizePolicy().hasHeightForWidth());
        usedHashes->setSizePolicy(sizePolicy);
        usedHashes->setSelectionMode(QAbstractItemView::ExtendedSelection);
        usedHashes->setRootIsDecorated(false);
        usedHashes->setUniformRowHeights(true);
        usedHashes->setItemsExpandable(false);
        usedHashes->setSortingEnabled(true);

        verticalLayout_2->addWidget(usedHashes);

        verifying = new QWidget(VerificationDialog);
        verifying->setObjectName("verifying");
        horizontalLayout = new QHBoxLayout(verifying);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        label_4 = new QLabel(verifying);
        label_4->setObjectName("label_4");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(label_4);

        progressBar = new QProgressBar(verifying);
        progressBar->setObjectName("progressBar");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(progressBar->sizePolicy().hasHeightForWidth());
        progressBar->setSizePolicy(sizePolicy2);
        progressBar->setValue(1);

        horizontalLayout->addWidget(progressBar);


        verticalLayout_2->addWidget(verifying);


        horizontalLayout_2->addLayout(verticalLayout_2);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        add = new QPushButton(VerificationDialog);
        add->setObjectName("add");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(add->sizePolicy().hasHeightForWidth());
        add->setSizePolicy(sizePolicy3);

        verticalLayout->addWidget(add);

        remove = new QPushButton(VerificationDialog);
        remove->setObjectName("remove");
        sizePolicy3.setHeightForWidth(remove->sizePolicy().hasHeightForWidth());
        remove->setSizePolicy(sizePolicy3);

        verticalLayout->addWidget(remove);

        verify = new QPushButton(VerificationDialog);
        verify->setObjectName("verify");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(verify->sizePolicy().hasHeightForWidth());
        verify->setSizePolicy(sizePolicy4);

        verticalLayout->addWidget(verify);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        closeButton = new QPushButton(VerificationDialog);
        closeButton->setObjectName("closeButton");
        sizePolicy3.setHeightForWidth(closeButton->sizePolicy().hasHeightForWidth());
        closeButton->setSizePolicy(sizePolicy3);

        verticalLayout->addWidget(closeButton);


        horizontalLayout_2->addLayout(verticalLayout);


        retranslateUi(VerificationDialog);

        QMetaObject::connectSlotsByName(VerificationDialog);
    } // setupUi

    void retranslateUi(QWidget *VerificationDialog)
    {
        label_4->setText(tr2i18n("Verifying:", nullptr));
        progressBar->setFormat(tr2i18n("%p%", nullptr));
#if QT_CONFIG(tooltip)
        verify->setToolTip(tr2i18n("Verify the finished download with the selected checksum.", nullptr));
#endif // QT_CONFIG(tooltip)
        verify->setText(tr2i18n("&Verify", nullptr));
        closeButton->setText(tr2i18n("Close", nullptr));
        (void)VerificationDialog;
    } // retranslateUi

};

namespace Ui {
    class VerificationDialog: public Ui_VerificationDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VERIFICATIONDIALOG_H

