/********************************************************************************
** Form generated from reading UI file 'importlinkdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTLINKDIALOG_H
#define UI_IMPORTLINKDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"
#include "kseparator.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ImportLinkDialog
{
public:
    QVBoxLayout *verticalLayout;
    QWidget *importWidget;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label;
    KUrlRequester *urlRequester;
    QPushButton *importLinks;
    KSeparator *kseparator_2;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_2;
    QComboBox *showCombo;
    QCheckBox *showWebContent;
    QSpacerItem *horizontalSpacer;
    KLineEdit *textFilter;
    KComboBox *filterMode;
    QTreeView *treeView;
    QProgressBar *progressBar;
    QFrame *line;
    QHBoxLayout *horizontalLayout;
    QPushButton *selectAll;
    QPushButton *deselectAll;
    QPushButton *invertSelection;
    QDialogButtonBox *dialogButtonBox;

    void setupUi(QWidget *ImportLinkDialog)
    {
        if (ImportLinkDialog->objectName().isEmpty())
            ImportLinkDialog->setObjectName("ImportLinkDialog");
        ImportLinkDialog->resize(750, 407);
        verticalLayout = new QVBoxLayout(ImportLinkDialog);
        verticalLayout->setObjectName("verticalLayout");
        importWidget = new QWidget(ImportLinkDialog);
        importWidget->setObjectName("importWidget");
        verticalLayout_2 = new QVBoxLayout(importWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label = new QLabel(importWidget);
        label->setObjectName("label");

        horizontalLayout_3->addWidget(label);

        urlRequester = new KUrlRequester(importWidget);
        urlRequester->setObjectName("urlRequester");

        horizontalLayout_3->addWidget(urlRequester);

        importLinks = new QPushButton(importWidget);
        importLinks->setObjectName("importLinks");
        importLinks->setEnabled(false);

        horizontalLayout_3->addWidget(importLinks);


        verticalLayout_2->addLayout(horizontalLayout_3);

        kseparator_2 = new KSeparator(importWidget);
        kseparator_2->setObjectName("kseparator_2");

        verticalLayout_2->addWidget(kseparator_2);


        verticalLayout->addWidget(importWidget);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_2 = new QLabel(ImportLinkDialog);
        label_2->setObjectName("label_2");

        horizontalLayout_4->addWidget(label_2);

        showCombo = new QComboBox(ImportLinkDialog);
        showCombo->setObjectName("showCombo");

        horizontalLayout_4->addWidget(showCombo);

        showWebContent = new QCheckBox(ImportLinkDialog);
        showWebContent->setObjectName("showWebContent");
        showWebContent->setChecked(true);

        horizontalLayout_4->addWidget(showWebContent);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);

        textFilter = new KLineEdit(ImportLinkDialog);
        textFilter->setObjectName("textFilter");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textFilter->sizePolicy().hasHeightForWidth());
        textFilter->setSizePolicy(sizePolicy);
        textFilter->setMinimumSize(QSize(25, 0));
        textFilter->setProperty("showClearButton", QVariant(true));

        horizontalLayout_4->addWidget(textFilter);

        filterMode = new KComboBox(ImportLinkDialog);
        filterMode->setObjectName("filterMode");

        horizontalLayout_4->addWidget(filterMode);


        verticalLayout->addLayout(horizontalLayout_4);

        treeView = new QTreeView(ImportLinkDialog);
        treeView->setObjectName("treeView");
        treeView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        treeView->setAlternatingRowColors(true);
        treeView->setSelectionMode(QAbstractItemView::ExtendedSelection);
        treeView->setRootIsDecorated(false);
        treeView->setSortingEnabled(true);
        treeView->setAllColumnsShowFocus(true);
        treeView->setWordWrap(false);

        verticalLayout->addWidget(treeView);

        progressBar = new QProgressBar(ImportLinkDialog);
        progressBar->setObjectName("progressBar");
        progressBar->setEnabled(true);
        progressBar->setValue(0);
        progressBar->setTextVisible(true);

        verticalLayout->addWidget(progressBar);

        line = new QFrame(ImportLinkDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        selectAll = new QPushButton(ImportLinkDialog);
        selectAll->setObjectName("selectAll");
        selectAll->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(selectAll->sizePolicy().hasHeightForWidth());
        selectAll->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(selectAll);

        deselectAll = new QPushButton(ImportLinkDialog);
        deselectAll->setObjectName("deselectAll");
        deselectAll->setEnabled(false);
        sizePolicy1.setHeightForWidth(deselectAll->sizePolicy().hasHeightForWidth());
        deselectAll->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(deselectAll);

        invertSelection = new QPushButton(ImportLinkDialog);
        invertSelection->setObjectName("invertSelection");
        invertSelection->setEnabled(false);
        sizePolicy1.setHeightForWidth(invertSelection->sizePolicy().hasHeightForWidth());
        invertSelection->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(invertSelection);

        dialogButtonBox = new QDialogButtonBox(ImportLinkDialog);
        dialogButtonBox->setObjectName("dialogButtonBox");
        dialogButtonBox->setStandardButtons(QDialogButtonBox::Cancel);

        horizontalLayout->addWidget(dialogButtonBox);


        verticalLayout->addLayout(horizontalLayout);

#if QT_CONFIG(shortcut)
        label->setBuddy(urlRequester);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(urlRequester, importLinks);
        QWidget::setTabOrder(importLinks, textFilter);
        QWidget::setTabOrder(textFilter, filterMode);
        QWidget::setTabOrder(filterMode, deselectAll);
        QWidget::setTabOrder(deselectAll, invertSelection);
        QWidget::setTabOrder(invertSelection, treeView);

        retranslateUi(ImportLinkDialog);

        QMetaObject::connectSlotsByName(ImportLinkDialog);
    } // setupUi

    void retranslateUi(QWidget *ImportLinkDialog)
    {
        label->setText(tr2i18n("File with &links to import:", nullptr));
        importLinks->setText(tr2i18n("&Import Links", nullptr));
        label_2->setText(tr2i18n("Show:", nullptr));
        showWebContent->setText(tr2i18n("Show &web content", nullptr));
#if QT_CONFIG(tooltip)
        textFilter->setToolTip(tr2i18n("You can use wildcards for filtering.", nullptr));
#endif // QT_CONFIG(tooltip)
        textFilter->setPlaceholderText(tr2i18n("Filter files here....", nullptr));
        progressBar->setFormat(tr2i18n("%p%", nullptr));
        selectAll->setText(tr2i18n("&Select All", nullptr));
        deselectAll->setText(tr2i18n("D&eselect All", nullptr));
        invertSelection->setText(tr2i18n("Inver&t Selection", nullptr));
        (void)ImportLinkDialog;
    } // retranslateUi

};

namespace Ui {
    class ImportLinkDialog: public Ui_ImportLinkDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTLINKDIALOG_H

