/****************************************************************************
** Meta object code from reading C++ file 'transfermultisegkio.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kget-26.08.0/transfer-plugins/multisegmentkio/transfermultisegkio.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transfermultisegkio.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19TransferMultiSegKioE_t {};
} // unnamed namespace

template <> constexpr inline auto TransferMultiSegKio::qt_create_metaobjectdata<qt_meta_tag_ZN19TransferMultiSegKioE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransferMultiSegKio",
        "setNewDestination",
        "",
        "QUrl",
        "newDestination",
        "start",
        "stop",
        "save",
        "QDomElement",
        "element",
        "load",
        "const QDomElement*",
        "e",
        "slotChecksumFound",
        "type",
        "checksum",
        "slotDataSourceFactoryChange",
        "Transfer::ChangesFlags",
        "change",
        "slotUpdateCapabilities",
        "slotSearchUrls",
        "QList<QUrl>",
        "urls",
        "slotRename",
        "oldUrl",
        "newUrl",
        "slotVerified",
        "isVerified",
        "slotStatResult",
        "KJob*",
        "kioJob"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setNewDestination'
        QtMocHelpers::SlotData<bool(const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void(const QDomElement &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void(const QDomElement *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'slotChecksumFound'
        QtMocHelpers::SlotData<void(QString, QString)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'slotDataSourceFactoryChange'
        QtMocHelpers::SlotData<void(Transfer::ChangesFlags)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'slotUpdateCapabilities'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSearchUrls'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'slotRename'
        QtMocHelpers::SlotData<void(const QUrl &, const QUrl &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 24 }, { 0x80000000 | 3, 25 },
        }}),
        // Slot 'slotVerified'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'slotStatResult'
        QtMocHelpers::SlotData<void(KJob *)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransferMultiSegKio, qt_meta_tag_ZN19TransferMultiSegKioE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransferMultiSegKio::staticMetaObject = { {
    QMetaObject::SuperData::link<Transfer::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TransferMultiSegKioE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TransferMultiSegKioE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19TransferMultiSegKioE_t>.metaTypes,
    nullptr
} };

void TransferMultiSegKio::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransferMultiSegKio *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->setNewDestination((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->start(); break;
        case 2: _t->stop(); break;
        case 3: _t->save((*reinterpret_cast<std::add_pointer_t<QDomElement>>(_a[1]))); break;
        case 4: _t->load((*reinterpret_cast<std::add_pointer_t<const QDomElement*>>(_a[1]))); break;
        case 5: _t->slotChecksumFound((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->slotDataSourceFactoryChange((*reinterpret_cast<std::add_pointer_t<Transfer::ChangesFlags>>(_a[1]))); break;
        case 7: _t->slotUpdateCapabilities(); break;
        case 8: _t->slotSearchUrls((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 9: _t->slotRename((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 10: _t->slotVerified((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->slotStatResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *TransferMultiSegKio::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransferMultiSegKio::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TransferMultiSegKioE_t>.strings))
        return static_cast<void*>(this);
    return Transfer::qt_metacast(_clname);
}

int TransferMultiSegKio::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Transfer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
