/********************************************************************************
** Form generated from reading UI file 'dlgmetalink.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DLGMETALINK_H
#define UI_DLGMETALINK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DlgMetalink
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label;
    QSpinBox *numSimultaneousFiles;
    QLabel *label_2;
    QSpinBox *kcfg_MirrorsPerFile;
    QLabel *label_3;
    QSpinBox *kcfg_ConnectionsPerUrl;

    void setupUi(QWidget *DlgMetalink)
    {
        if (DlgMetalink->objectName().isEmpty())
            DlgMetalink->setObjectName("DlgMetalink");
        DlgMetalink->resize(430, 139);
        verticalLayout = new QVBoxLayout(DlgMetalink);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(DlgMetalink);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        numSimultaneousFiles = new QSpinBox(DlgMetalink);
        numSimultaneousFiles->setObjectName("numSimultaneousFiles");
        numSimultaneousFiles->setMinimum(1);
        numSimultaneousFiles->setMaximum(10);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, numSimultaneousFiles);

        label_2 = new QLabel(DlgMetalink);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_MirrorsPerFile = new QSpinBox(DlgMetalink);
        kcfg_MirrorsPerFile->setObjectName("kcfg_MirrorsPerFile");
        kcfg_MirrorsPerFile->setMinimum(1);
        kcfg_MirrorsPerFile->setMaximum(10);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_MirrorsPerFile);

        label_3 = new QLabel(DlgMetalink);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_ConnectionsPerUrl = new QSpinBox(DlgMetalink);
        kcfg_ConnectionsPerUrl->setObjectName("kcfg_ConnectionsPerUrl");
        kcfg_ConnectionsPerUrl->setMinimum(1);
        kcfg_ConnectionsPerUrl->setMaximum(10);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_ConnectionsPerUrl);


        verticalLayout->addLayout(formLayout);


        retranslateUi(DlgMetalink);

        QMetaObject::connectSlotsByName(DlgMetalink);
    } // setupUi

    void retranslateUi(QWidget *DlgMetalink)
    {
        label->setText(tr2i18n("Number of simultaneous file downloads:", nullptr));
        label_2->setText(tr2i18n("Number of mirrors per file:", nullptr));
        label_3->setText(tr2i18n("Number of connections per URL:", nullptr));
        (void)DlgMetalink;
    } // retranslateUi

};

namespace Ui {
    class DlgMetalink: public Ui_DlgMetalink {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DLGMETALINK_H

