/********************************************************************************
** Form generated from reading UI file 'transfersettingsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRANSFERSETTINGSDIALOG_H
#define UI_TRANSFERSETTINGSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktitlewidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_TransferSettingsDialog
{
public:
    QVBoxLayout *verticalLayout_3;
    KTitleWidget *ktitlewidget;
    QFormLayout *formLayout;
    QLabel *label;
    KUrlRequester *destination;
    QSpinBox *uploadSpin;
    QSpinBox *downloadSpin;
    QDoubleSpinBox *ratioSpin;
    QLabel *labelUpload;
    QLabel *labelDownload;
    QLabel *labelShareRatio;
    QHBoxLayout *horizontalLayout;
    QTreeView *treeView;
    QVBoxLayout *verticalLayout_2;
    QPushButton *mirrors;
    QPushButton *rename;
    QPushButton *verification;
    QPushButton *signature;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *TransferSettingsDialog)
    {
        if (TransferSettingsDialog->objectName().isEmpty())
            TransferSettingsDialog->setObjectName("TransferSettingsDialog");
        TransferSettingsDialog->resize(626, 338);
        verticalLayout_3 = new QVBoxLayout(TransferSettingsDialog);
        verticalLayout_3->setObjectName("verticalLayout_3");
        ktitlewidget = new KTitleWidget(TransferSettingsDialog);
        ktitlewidget->setObjectName("ktitlewidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ktitlewidget->sizePolicy().hasHeightForWidth());
        ktitlewidget->setSizePolicy(sizePolicy);

        verticalLayout_3->addWidget(ktitlewidget);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(TransferSettingsDialog);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        destination = new KUrlRequester(TransferSettingsDialog);
        destination->setObjectName("destination");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, destination);

        uploadSpin = new QSpinBox(TransferSettingsDialog);
        uploadSpin->setObjectName("uploadSpin");
        uploadSpin->setEnabled(true);
        uploadSpin->setMaximum(100000);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, uploadSpin);

        downloadSpin = new QSpinBox(TransferSettingsDialog);
        downloadSpin->setObjectName("downloadSpin");
        downloadSpin->setEnabled(true);
        downloadSpin->setMaximum(100000);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, downloadSpin);

        ratioSpin = new QDoubleSpinBox(TransferSettingsDialog);
        ratioSpin->setObjectName("ratioSpin");
        ratioSpin->setEnabled(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, ratioSpin);

        labelUpload = new QLabel(TransferSettingsDialog);
        labelUpload->setObjectName("labelUpload");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, labelUpload);

        labelDownload = new QLabel(TransferSettingsDialog);
        labelDownload->setObjectName("labelDownload");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, labelDownload);

        labelShareRatio = new QLabel(TransferSettingsDialog);
        labelShareRatio->setObjectName("labelShareRatio");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, labelShareRatio);


        verticalLayout_3->addLayout(formLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        treeView = new QTreeView(TransferSettingsDialog);
        treeView->setObjectName("treeView");
        treeView->setSortingEnabled(true);
        treeView->header()->setDefaultSectionSize(70);

        horizontalLayout->addWidget(treeView);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        mirrors = new QPushButton(TransferSettingsDialog);
        mirrors->setObjectName("mirrors");
        mirrors->setEnabled(false);

        verticalLayout_2->addWidget(mirrors);

        rename = new QPushButton(TransferSettingsDialog);
        rename->setObjectName("rename");
        rename->setEnabled(false);

        verticalLayout_2->addWidget(rename);

        verification = new QPushButton(TransferSettingsDialog);
        verification->setObjectName("verification");
        verification->setEnabled(false);

        verticalLayout_2->addWidget(verification);

        signature = new QPushButton(TransferSettingsDialog);
        signature->setObjectName("signature");
        signature->setEnabled(false);

        verticalLayout_2->addWidget(signature);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout_2);


        verticalLayout_3->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(TransferSettingsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(destination);
        labelUpload->setBuddy(uploadSpin);
        labelDownload->setBuddy(downloadSpin);
        labelShareRatio->setBuddy(ratioSpin);
#endif // QT_CONFIG(shortcut)

        retranslateUi(TransferSettingsDialog);

        QMetaObject::connectSlotsByName(TransferSettingsDialog);
    } // setupUi

    void retranslateUi(QWidget *TransferSettingsDialog)
    {
        ktitlewidget->setProperty("text", QVariant(tr2i18n("Transfer Settings", nullptr)));
        label->setText(tr2i18n("Download des&tination:", nullptr));
        uploadSpin->setSpecialValueText(tr2i18n("Not set", "No value has been set"));
        uploadSpin->setSuffix(tr2i18n(" KiB/s", nullptr));
        downloadSpin->setSpecialValueText(tr2i18n("Not set", "No value has been set"));
        downloadSpin->setSuffix(tr2i18n(" KiB/s", nullptr));
        ratioSpin->setSpecialValueText(tr2i18n("Not set", "No value has been set"));
        labelUpload->setText(tr2i18n("&Upload limit:", nullptr));
        labelDownload->setText(tr2i18n("Download &limit:", nullptr));
        labelShareRatio->setText(tr2i18n("Ma&ximum share ratio:", nullptr));
#if QT_CONFIG(tooltip)
        mirrors->setToolTip(tr2i18n("Modify the mirrors used for downloading.", nullptr));
#endif // QT_CONFIG(tooltip)
        mirrors->setText(tr2i18n("Mirrors", "The available mirrors (servers) for downloading"));
        rename->setText(tr2i18n("Rename", nullptr));
        verification->setText(tr2i18n("Verification", "verification of the download (e.g. by using MD5)"));
        signature->setText(tr2i18n("Signature", nullptr));
        (void)TransferSettingsDialog;
    } // retranslateUi

};

namespace Ui {
    class TransferSettingsDialog: public Ui_TransferSettingsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TRANSFERSETTINGSDIALOG_H

