/********************************************************************************
** Form generated from reading UI file 'dlgmultisegkio.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DLGMULTISEGKIO_H
#define UI_DLGMULTISEGKIO_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DlgMultiSeg
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label;
    QSpinBox *numSegSpinBox;
    QCheckBox *enginesCheckBox;
    QCheckBox *verificationCheckBox;
    QSpacerItem *spacer;

    void setupUi(QWidget *DlgMultiSeg)
    {
        if (DlgMultiSeg->objectName().isEmpty())
            DlgMultiSeg->setObjectName("DlgMultiSeg");
        DlgMultiSeg->resize(414, 155);
        verticalLayout = new QVBoxLayout(DlgMultiSeg);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(DlgMultiSeg);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        numSegSpinBox = new QSpinBox(DlgMultiSeg);
        numSegSpinBox->setObjectName("numSegSpinBox");
        numSegSpinBox->setMinimum(1);
        numSegSpinBox->setMaximum(5);
        numSegSpinBox->setValue(5);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, numSegSpinBox);


        verticalLayout->addLayout(formLayout);

        enginesCheckBox = new QCheckBox(DlgMultiSeg);
        enginesCheckBox->setObjectName("enginesCheckBox");

        verticalLayout->addWidget(enginesCheckBox);

        verificationCheckBox = new QCheckBox(DlgMultiSeg);
        verificationCheckBox->setObjectName("verificationCheckBox");

        verticalLayout->addWidget(verificationCheckBox);

        spacer = new QSpacerItem(20, 39, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacer);


        retranslateUi(DlgMultiSeg);

        QMetaObject::connectSlotsByName(DlgMultiSeg);
    } // setupUi

    void retranslateUi(QWidget *DlgMultiSeg)
    {
        label->setText(tr2i18n("Number of connections per URL:", nullptr));
        enginesCheckBox->setText(tr2i18n("Use search engines", nullptr));
        verificationCheckBox->setText(tr2i18n("Search for verification information", nullptr));
        (void)DlgMultiSeg;
    } // retranslateUi

};

namespace Ui {
    class DlgMultiSeg: public Ui_DlgMultiSeg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DLGMULTISEGKIO_H

