/********************************************************************************
** Form generated from reading UI file 'dlgintegration.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DLGINTEGRATION_H
#define UI_DLGINTEGRATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"
#include "KLineEdit"

QT_BEGIN_NAMESPACE

class Ui_DlgIntegration
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_KonquerorIntegration;
    QGroupBox *kcfg_AutoPaste;
    QFormLayout *formLayout_2;
    QLabel *label_5;
    QCheckBox *kcfg_AutoPasteCaseSensitive;
    QHBoxLayout *horizontalLayout;
    KComboBox *type;
    KComboBox *patternSyntax;
    KLineEdit *pattern;
    QHBoxLayout *horizontalLayout_2;
    QTreeView *list;
    QVBoxLayout *verticalLayout_4;
    QPushButton *add;
    QPushButton *remove;
    QPushButton *increase;
    QPushButton *decrease;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *DlgIntegration)
    {
        if (DlgIntegration->objectName().isEmpty())
            DlgIntegration->setObjectName("DlgIntegration");
        DlgIntegration->resize(558, 324);
        verticalLayout = new QVBoxLayout(DlgIntegration);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_KonquerorIntegration = new QCheckBox(DlgIntegration);
        kcfg_KonquerorIntegration->setObjectName("kcfg_KonquerorIntegration");

        verticalLayout->addWidget(kcfg_KonquerorIntegration);

        kcfg_AutoPaste = new QGroupBox(DlgIntegration);
        kcfg_AutoPaste->setObjectName("kcfg_AutoPaste");
        kcfg_AutoPaste->setCheckable(true);
        kcfg_AutoPaste->setChecked(false);
        formLayout_2 = new QFormLayout(kcfg_AutoPaste);
        formLayout_2->setObjectName("formLayout_2");
        label_5 = new QLabel(kcfg_AutoPaste);
        label_5->setObjectName("label_5");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_5);

        kcfg_AutoPasteCaseSensitive = new QCheckBox(kcfg_AutoPaste);
        kcfg_AutoPasteCaseSensitive->setObjectName("kcfg_AutoPasteCaseSensitive");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_AutoPasteCaseSensitive);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        type = new KComboBox(kcfg_AutoPaste);
        type->setObjectName("type");

        horizontalLayout->addWidget(type);

        patternSyntax = new KComboBox(kcfg_AutoPaste);
        patternSyntax->setObjectName("patternSyntax");

        horizontalLayout->addWidget(patternSyntax);

        pattern = new KLineEdit(kcfg_AutoPaste);
        pattern->setObjectName("pattern");
        pattern->setProperty("trapEnterKeyEvent", QVariant(true));
        pattern->setProperty("showClearButton", QVariant(true));

        horizontalLayout->addWidget(pattern);


        formLayout_2->setLayout(1, QFormLayout::ItemRole::SpanningRole, horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        list = new QTreeView(kcfg_AutoPaste);
        list->setObjectName("list");
        list->setSelectionMode(QAbstractItemView::ExtendedSelection);
        list->setRootIsDecorated(false);
        list->setUniformRowHeights(true);

        horizontalLayout_2->addWidget(list);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        add = new QPushButton(kcfg_AutoPaste);
        add->setObjectName("add");

        verticalLayout_4->addWidget(add);

        remove = new QPushButton(kcfg_AutoPaste);
        remove->setObjectName("remove");

        verticalLayout_4->addWidget(remove);

        increase = new QPushButton(kcfg_AutoPaste);
        increase->setObjectName("increase");

        verticalLayout_4->addWidget(increase);

        decrease = new QPushButton(kcfg_AutoPaste);
        decrease->setObjectName("decrease");

        verticalLayout_4->addWidget(decrease);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);


        horizontalLayout_2->addLayout(verticalLayout_4);


        formLayout_2->setLayout(2, QFormLayout::ItemRole::SpanningRole, horizontalLayout_2);


        verticalLayout->addWidget(kcfg_AutoPaste);


        retranslateUi(DlgIntegration);

        QMetaObject::connectSlotsByName(DlgIntegration);
    } // setupUi

    void retranslateUi(QWidget *DlgIntegration)
    {
        kcfg_KonquerorIntegration->setText(tr2i18n("Use as download manager for Konqueror", nullptr));
        kcfg_AutoPaste->setTitle(tr2i18n("Monitor Clipboard for Files to Download", nullptr));
        label_5->setText(tr2i18n("Case sensitive:", nullptr));
        kcfg_AutoPasteCaseSensitive->setText(QString());
        increase->setText(tr2i18n("&Increase Priority", nullptr));
        decrease->setText(tr2i18n("&Decrease Priority", nullptr));
        (void)DlgIntegration;
    } // retranslateUi

};

namespace Ui {
    class DlgIntegration: public Ui_DlgIntegration {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DLGINTEGRATION_H

