/********************************************************************************
** Form generated from reading UI file 'dlgadvanced.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DLGADVANCED_H
#define UI_DLGADVANCED_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"

QT_BEGIN_NAMESPACE

class Ui_DlgAdvanced
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_AutomaticDeletionEnabled;
    KComboBox *kcfg_ExpiryTimeType;
    QLineEdit *kcfg_ExpiryTimeValue;
    QCheckBox *kcfg_EnableSystemTray;
    QFormLayout *formLayout_2;
    QCheckBox *kcfg_AfterFinishActionEnabled;
    KComboBox *kcfg_AfterFinishAction;
    QLabel *label_2;
    KComboBox *kcfg_StartupAction;
    KComboBox *kcfg_HistoryBackend;
    QLabel *label;
    QGroupBox *kcfg_EnableKUIServerIntegration;
    QVBoxLayout *vboxLayout;
    QRadioButton *kcfg_ExportSingleTransfer;
    QRadioButton *kcfg_ExportGlobalJob;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *kcfg_FilesAlwaysAsk;
    QRadioButton *kcfg_FilesAutomaticRename;
    QRadioButton *kcfg_FilesOverwrite;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *DlgAdvanced)
    {
        if (DlgAdvanced->objectName().isEmpty())
            DlgAdvanced->setObjectName("DlgAdvanced");
        DlgAdvanced->resize(585, 443);
        verticalLayout = new QVBoxLayout(DlgAdvanced);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_AutomaticDeletionEnabled = new QCheckBox(DlgAdvanced);
        kcfg_AutomaticDeletionEnabled->setObjectName("kcfg_AutomaticDeletionEnabled");

        horizontalLayout->addWidget(kcfg_AutomaticDeletionEnabled);

        kcfg_ExpiryTimeType = new KComboBox(DlgAdvanced);
        kcfg_ExpiryTimeType->setObjectName("kcfg_ExpiryTimeType");

        horizontalLayout->addWidget(kcfg_ExpiryTimeType);

        kcfg_ExpiryTimeValue = new QLineEdit(DlgAdvanced);
        kcfg_ExpiryTimeValue->setObjectName("kcfg_ExpiryTimeValue");

        horizontalLayout->addWidget(kcfg_ExpiryTimeValue);


        verticalLayout->addLayout(horizontalLayout);

        kcfg_EnableSystemTray = new QCheckBox(DlgAdvanced);
        kcfg_EnableSystemTray->setObjectName("kcfg_EnableSystemTray");

        verticalLayout->addWidget(kcfg_EnableSystemTray);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        kcfg_AfterFinishActionEnabled = new QCheckBox(DlgAdvanced);
        kcfg_AfterFinishActionEnabled->setObjectName("kcfg_AfterFinishActionEnabled");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, kcfg_AfterFinishActionEnabled);

        kcfg_AfterFinishAction = new KComboBox(DlgAdvanced);
        kcfg_AfterFinishAction->addItem(QString());
        kcfg_AfterFinishAction->setObjectName("kcfg_AfterFinishAction");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_AfterFinishAction);

        label_2 = new QLabel(DlgAdvanced);
        label_2->setObjectName("label_2");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_StartupAction = new KComboBox(DlgAdvanced);
        kcfg_StartupAction->addItem(QString());
        kcfg_StartupAction->addItem(QString());
        kcfg_StartupAction->addItem(QString());
        kcfg_StartupAction->setObjectName("kcfg_StartupAction");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_StartupAction);

        kcfg_HistoryBackend = new KComboBox(DlgAdvanced);
        kcfg_HistoryBackend->setObjectName("kcfg_HistoryBackend");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_HistoryBackend);

        label = new QLabel(DlgAdvanced);
        label->setObjectName("label");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label);


        verticalLayout->addLayout(formLayout_2);

        kcfg_EnableKUIServerIntegration = new QGroupBox(DlgAdvanced);
        kcfg_EnableKUIServerIntegration->setObjectName("kcfg_EnableKUIServerIntegration");
        kcfg_EnableKUIServerIntegration->setCheckable(true);
        kcfg_EnableKUIServerIntegration->setChecked(false);
        vboxLayout = new QVBoxLayout(kcfg_EnableKUIServerIntegration);
        vboxLayout->setObjectName("vboxLayout");
        kcfg_ExportSingleTransfer = new QRadioButton(kcfg_EnableKUIServerIntegration);
        kcfg_ExportSingleTransfer->setObjectName("kcfg_ExportSingleTransfer");

        vboxLayout->addWidget(kcfg_ExportSingleTransfer);

        kcfg_ExportGlobalJob = new QRadioButton(kcfg_EnableKUIServerIntegration);
        kcfg_ExportGlobalJob->setObjectName("kcfg_ExportGlobalJob");

        vboxLayout->addWidget(kcfg_ExportGlobalJob);


        verticalLayout->addWidget(kcfg_EnableKUIServerIntegration);

        groupBox_2 = new QGroupBox(DlgAdvanced);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_FilesAlwaysAsk = new QRadioButton(groupBox_2);
        kcfg_FilesAlwaysAsk->setObjectName("kcfg_FilesAlwaysAsk");

        verticalLayout_2->addWidget(kcfg_FilesAlwaysAsk);

        kcfg_FilesAutomaticRename = new QRadioButton(groupBox_2);
        kcfg_FilesAutomaticRename->setObjectName("kcfg_FilesAutomaticRename");

        verticalLayout_2->addWidget(kcfg_FilesAutomaticRename);

        kcfg_FilesOverwrite = new QRadioButton(groupBox_2);
        kcfg_FilesOverwrite->setObjectName("kcfg_FilesOverwrite");

        verticalLayout_2->addWidget(kcfg_FilesOverwrite);


        verticalLayout->addWidget(groupBox_2);

        spacerItem = new QSpacerItem(200, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);


        retranslateUi(DlgAdvanced);

        QMetaObject::connectSlotsByName(DlgAdvanced);
    } // setupUi

    void retranslateUi(QWidget *DlgAdvanced)
    {
        kcfg_AutomaticDeletionEnabled->setText(tr2i18n("Automatically delete all transfer history older than:", nullptr));
        kcfg_EnableSystemTray->setText(tr2i18n("Enable system tray icon", nullptr));
        kcfg_AfterFinishActionEnabled->setText(tr2i18n("Execute action after all downloads have been finished:", nullptr));
        kcfg_AfterFinishAction->setItemText(0, tr2i18n("Quit KGet", nullptr));

        label_2->setText(tr2i18n("At startup:", nullptr));
        kcfg_StartupAction->setItemText(0, tr2i18n("Restore Download State", nullptr));
        kcfg_StartupAction->setItemText(1, tr2i18n("Start All Downloads", nullptr));
        kcfg_StartupAction->setItemText(2, tr2i18n("Stop All Downloads", nullptr));

        label->setText(tr2i18n("History backend:", nullptr));
        kcfg_EnableKUIServerIntegration->setTitle(tr2i18n("Enable KDE Global Progress Tracking", nullptr));
        kcfg_ExportSingleTransfer->setText(tr2i18n("Show every single download ", nullptr));
        kcfg_ExportGlobalJob->setText(tr2i18n("Show overall progress", nullptr));
        groupBox_2->setTitle(tr2i18n("Handle existing Files/Transfers", nullptr));
        kcfg_FilesAlwaysAsk->setText(tr2i18n("Always ask", nullptr));
        kcfg_FilesAutomaticRename->setText(tr2i18n("Automatic rename", nullptr));
        kcfg_FilesOverwrite->setText(tr2i18n("Overwrite", nullptr));
        (void)DlgAdvanced;
    } // retranslateUi

};

namespace Ui {
    class DlgAdvanced: public Ui_DlgAdvanced {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DLGADVANCED_H

