/****************************************************************************
** Meta object code from reading C++ file 'kget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kget-26.08.0/core/kget.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15GenericObserverE_t {};
} // unnamed namespace

template <> constexpr inline auto GenericObserver::qt_create_metaobjectdata<qt_meta_tag_ZN15GenericObserverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GenericObserver",
        "groupAddedEvent",
        "",
        "TransferGroupHandler*",
        "handler",
        "groupRemovedEvent",
        "transfersAddedEvent",
        "QList<TransferHandler*>",
        "handlers",
        "transfersRemovedEvent",
        "transfersChangedEvent",
        "QMap<TransferHandler*,Transfer::ChangesFlags>",
        "transfers",
        "groupsChangedEvent",
        "QMap<TransferGroupHandler*,TransferGroup::ChangesFlags>",
        "groups",
        "transferMovedEvent",
        "TransferHandler*",
        "slotSave",
        "slotAfterFinishAction",
        "slotAbortAfterFinishAction",
        "slotResolveTransferError",
        "slotNotificationClosed",
        "slotNetworkStatusChanged",
        "QNetworkInformation::Reachability",
        "reachability"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'groupAddedEvent'
        QtMocHelpers::SlotData<void(TransferGroupHandler *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'groupRemovedEvent'
        QtMocHelpers::SlotData<void(TransferGroupHandler *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'transfersAddedEvent'
        QtMocHelpers::SlotData<void(const QList<TransferHandler*> &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'transfersRemovedEvent'
        QtMocHelpers::SlotData<void(const QList<TransferHandler*> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'transfersChangedEvent'
        QtMocHelpers::SlotData<void(QMap<TransferHandler*,Transfer::ChangesFlags>)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'groupsChangedEvent'
        QtMocHelpers::SlotData<void(QMap<TransferGroupHandler*,TransferGroup::ChangesFlags>)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'transferMovedEvent'
        QtMocHelpers::SlotData<void(TransferHandler *, TransferGroupHandler *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Slot 'slotSave'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAfterFinishAction'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAbortAfterFinishAction'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResolveTransferError'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNotificationClosed'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNetworkStatusChanged'
        QtMocHelpers::SlotData<void(QNetworkInformation::Reachability)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GenericObserver, qt_meta_tag_ZN15GenericObserverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GenericObserver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15GenericObserverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15GenericObserverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15GenericObserverE_t>.metaTypes,
    nullptr
} };

void GenericObserver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GenericObserver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->groupAddedEvent((*reinterpret_cast<std::add_pointer_t<TransferGroupHandler*>>(_a[1]))); break;
        case 1: _t->groupRemovedEvent((*reinterpret_cast<std::add_pointer_t<TransferGroupHandler*>>(_a[1]))); break;
        case 2: _t->transfersAddedEvent((*reinterpret_cast<std::add_pointer_t<QList<TransferHandler*>>>(_a[1]))); break;
        case 3: _t->transfersRemovedEvent((*reinterpret_cast<std::add_pointer_t<QList<TransferHandler*>>>(_a[1]))); break;
        case 4: _t->transfersChangedEvent((*reinterpret_cast<std::add_pointer_t<QMap<TransferHandler*,Transfer::ChangesFlags>>>(_a[1]))); break;
        case 5: _t->groupsChangedEvent((*reinterpret_cast<std::add_pointer_t<QMap<TransferGroupHandler*,TransferGroup::ChangesFlags>>>(_a[1]))); break;
        case 6: _t->transferMovedEvent((*reinterpret_cast<std::add_pointer_t<TransferHandler*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TransferGroupHandler*>>(_a[2]))); break;
        case 7: _t->slotSave(); break;
        case 8: _t->slotAfterFinishAction(); break;
        case 9: _t->slotAbortAfterFinishAction(); break;
        case 10: _t->slotResolveTransferError(); break;
        case 11: _t->slotNotificationClosed(); break;
        case 12: _t->slotNetworkStatusChanged((*reinterpret_cast<std::add_pointer_t<QNetworkInformation::Reachability>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferGroupHandler* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferGroupHandler* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<TransferHandler*> >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<TransferHandler*> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferGroupHandler* >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferHandler* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *GenericObserver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GenericObserver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15GenericObserverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GenericObserver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
