/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kget.verifier.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "verifieradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class VerifierAdaptor
 */

VerifierAdaptor::VerifierAdaptor(DBusVerifierWrapper *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

VerifierAdaptor::~VerifierAdaptor()
{
    // destructor
}

void VerifierAdaptor::addChecksum(const QString &type, const QString &hash)
{
    // handle method call org.kde.kget.verifier.addChecksum
    parent()->addChecksum(type, hash);
}

void VerifierAdaptor::addPartialChecksums(const QString &type, qulonglong size, const QStringList &checksums)
{
    // handle method call org.kde.kget.verifier.addPartialChecksums
    parent()->addPartialChecksums(type, size, checksums);
}

void VerifierAdaptor::brokenPieces()
{
    // handle method call org.kde.kget.verifier.brokenPieces
    parent()->brokenPieces();
}

QString VerifierAdaptor::destination()
{
    // handle method call org.kde.kget.verifier.destination
    return parent()->destination();
}

bool VerifierAdaptor::isVerifyable()
{
    // handle method call org.kde.kget.verifier.isVerifyable
    return parent()->isVerifyable();
}

void VerifierAdaptor::verify()
{
    // handle method call org.kde.kget.verifier.verify
    parent()->verify();
}


#include "moc_verifieradaptor.cpp"
