/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kget.transfer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef TRANSFERADAPTOR_H
#define TRANSFERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "../dbus/dbustransferwrapper.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kget.transfer
 */
class TransferAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kget.transfer")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kget.transfer\">\n"
"    <method name=\"capabilities\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"start\"/>\n"
"    <method name=\"stop\"/>\n"
"    <method name=\"status\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"elapsedTime\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"remainingTime\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"groupName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"source\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"dest\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"totalSize\">\n"
"      <arg direction=\"out\" type=\"t\"/>\n"
"    </method>\n"
"    <method name=\"downloadedSize\">\n"
"      <arg direction=\"out\" type=\"t\"/>\n"
"    </method>\n"
"    <method name=\"uploadedSize\">\n"
"      <arg direction=\"out\" type=\"t\"/>\n"
"    </method>\n"
"    <method name=\"percent\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"downloadSpeed\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"uploadSpeed\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setUploadLimit\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"ulLimit\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"limit\"/>\n"
"    </method>\n"
"    <method name=\"setDownloadLimit\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"dlLimit\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"limit\"/>\n"
"    </method>\n"
"    <method name=\"uploadLimit\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"limit\"/>\n"
"    </method>\n"
"    <method name=\"downloadLimit\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"limit\"/>\n"
"    </method>\n"
"    <method name=\"setMaximumShareRatio\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"ratio\"/>\n"
"    </method>\n"
"    <method name=\"maximumShareRatio\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"    </method>\n"
"    <method name=\"statusText\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"statusPixmap\">\n"
"      <arg direction=\"out\" type=\"v\"/>\n"
"    </method>\n"
"    <method name=\"verifier\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"    </method>\n"
"    <method name=\"repair\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"    </method>\n"
"    <method name=\"setDirectory\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"newDirectory\"/>\n"
"    </method>\n"
"    <signal name=\"transferChangedEvent\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"changeFlags\"/>\n"
"    </signal>\n"
"    <signal name=\"capabilitiesChanged\"/>\n"
"  </interface>\n"
        "")
public:
    TransferAdaptor(DBusTransferWrapper *parent);
    ~TransferAdaptor() override;

    inline DBusTransferWrapper *parent() const
    { return static_cast<DBusTransferWrapper *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    int capabilities();
    QString dest();
    int downloadLimit(int limit);
    int downloadSpeed();
    qulonglong downloadedSize();
    int elapsedTime();
    QString groupName();
    double maximumShareRatio();
    int percent();
    int remainingTime();
    bool repair(const QString &file);
    bool setDirectory(const QString &newDirectory);
    void setDownloadLimit(int dlLimit, int limit);
    void setMaximumShareRatio(double ratio);
    void setUploadLimit(int ulLimit, int limit);
    QString source();
    void start();
    int status();
    QDBusVariant statusPixmap();
    QString statusText();
    void stop();
    qulonglong totalSize();
    int uploadLimit(int limit);
    int uploadSpeed();
    qulonglong uploadedSize();
    QString verifier(const QString &file);
Q_SIGNALS: // SIGNALS
    void capabilitiesChanged();
    void transferChangedEvent(int changeFlags);
};

#endif
