/********************************************************************************
** Form generated from reading UI file 'urlwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_URLWIDGET_H
#define UI_URLWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_UrlWidget
{
public:
    QGridLayout *gridLayout;
    QTreeView *used_mirrors;
    QPushButton *add_mirror;
    QPushButton *remove_mirror;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *UrlWidget)
    {
        if (UrlWidget->objectName().isEmpty())
            UrlWidget->setObjectName("UrlWidget");
        UrlWidget->resize(435, 517);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(UrlWidget->sizePolicy().hasHeightForWidth());
        UrlWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(UrlWidget);
        gridLayout->setObjectName("gridLayout");
        used_mirrors = new QTreeView(UrlWidget);
        used_mirrors->setObjectName("used_mirrors");
        used_mirrors->setSelectionMode(QAbstractItemView::ExtendedSelection);
        used_mirrors->setRootIsDecorated(false);
        used_mirrors->setUniformRowHeights(true);
        used_mirrors->setSortingEnabled(true);

        gridLayout->addWidget(used_mirrors, 0, 0, 3, 1);

        add_mirror = new QPushButton(UrlWidget);
        add_mirror->setObjectName("add_mirror");

        gridLayout->addWidget(add_mirror, 0, 1, 1, 1);

        remove_mirror = new QPushButton(UrlWidget);
        remove_mirror->setObjectName("remove_mirror");

        gridLayout->addWidget(remove_mirror, 1, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 442, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 1, 1, 1);


        retranslateUi(UrlWidget);

        QMetaObject::connectSlotsByName(UrlWidget);
    } // setupUi

    void retranslateUi(QWidget *UrlWidget)
    {
        (void)UrlWidget;
    } // retranslateUi

};

namespace Ui {
    class UrlWidget: public Ui_UrlWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // URLWIDGET_H

