/********************************************************************************
** Form generated from reading UI file 'files.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILES_H
#define UI_FILES_H

#include <KMessageWidget>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Files
{
public:
    QGridLayout *gridLayout;
    QListView *files;
    QVBoxLayout *verticalLayout;
    QPushButton *add_local_file;
    QPushButton *add_file;
    QPushButton *properties_file;
    QPushButton *remove_file;
    QSpacerItem *verticalSpacer;
    QWidget *dragDrop;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_3;
    QProgressBar *progressBar;
    KMessageWidget *infoWidget;

    void setupUi(QWidget *Files)
    {
        if (Files->objectName().isEmpty())
            Files->setObjectName("Files");
        Files->resize(576, 376);
        gridLayout = new QGridLayout(Files);
        gridLayout->setObjectName("gridLayout");
        files = new QListView(Files);
        files->setObjectName("files");
        files->setSelectionMode(QAbstractItemView::ExtendedSelection);

        gridLayout->addWidget(files, 2, 0, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        add_local_file = new QPushButton(Files);
        add_local_file->setObjectName("add_local_file");

        verticalLayout->addWidget(add_local_file);

        add_file = new QPushButton(Files);
        add_file->setObjectName("add_file");

        verticalLayout->addWidget(add_file);

        properties_file = new QPushButton(Files);
        properties_file->setObjectName("properties_file");

        verticalLayout->addWidget(properties_file);

        remove_file = new QPushButton(Files);
        remove_file->setObjectName("remove_file");

        verticalLayout->addWidget(remove_file);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        gridLayout->addLayout(verticalLayout, 2, 1, 1, 1);

        dragDrop = new QWidget(Files);
        dragDrop->setObjectName("dragDrop");
        verticalLayout_2 = new QVBoxLayout(dragDrop);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        label_3 = new QLabel(dragDrop);
        label_3->setObjectName("label_3");

        verticalLayout_2->addWidget(label_3);

        progressBar = new QProgressBar(dragDrop);
        progressBar->setObjectName("progressBar");
        progressBar->setValue(1);

        verticalLayout_2->addWidget(progressBar);


        gridLayout->addWidget(dragDrop, 3, 0, 1, 1);

        infoWidget = new KMessageWidget(Files);
        infoWidget->setObjectName("infoWidget");

        gridLayout->addWidget(infoWidget, 0, 0, 1, 2);


        retranslateUi(Files);

        QMetaObject::connectSlotsByName(Files);
    } // setupUi

    void retranslateUi(QWidget *Files)
    {
#if QT_CONFIG(tooltip)
        add_local_file->setToolTip(tr2i18n("Adds local files adding a lot information automatically.", nullptr));
#endif // QT_CONFIG(tooltip)
        add_local_file->setText(tr2i18n("Add local files", nullptr));
        label_3->setText(tr2i18n("Adding local files...", nullptr));
        progressBar->setFormat(tr2i18n("%p%", nullptr));
        (void)Files;
    } // retranslateUi

};

namespace Ui {
    class Files: public Ui_Files {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILES_H

