/****************************************************************************
** Meta object code from reading C++ file 'transferadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "transferadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transferadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15TransferAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto TransferAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN15TransferAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransferAdaptor",
        "D-Bus Interface",
        "org.kde.kget.transfer",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kget.transfer\">\n    <method name=\"c"
        "apabilities\">\n      <arg direction=\"out\" type=\"i\"/>\n    </m"
        "ethod>\n    <method name=\"start\"/>\n    <method name=\"stop\"/>\n"
        "    <method name=\"status\">\n      <arg direction=\"out\" type=\""
        "i\"/>\n    </method>\n    <method name=\"elapsedTime\">\n      <ar"
        "g direction=\"out\" type=\"i\"/>\n    </method>\n    <method name="
        "\"remainingTime\">\n      <arg direction=\"out\" type=\"i\"/>\n   "
        " </method>\n    <method name=\"groupName\">\n      <arg direction="
        "\"out\" type=\"s\"/>\n    </method>\n    <method name=\"source\">\n"
        "      <arg direction=\"out\" type=\"s\"/>\n    </method>\n    <met"
        "hod name=\"dest\">\n      <arg direction=\"out\" type=\"s\"/>\n   "
        " </method>\n    <method name=\"totalSize\">\n      <arg direction="
        "\"out\" type=\"t\"/>\n    </method>\n    <method name=\"downloaded"
        "Size\">\n      <arg direction=\"out\" type=\"t\"/>\n    </method>\n"
        "    <method name=\"uploadedSize\">\n      <arg direction=\"out\" t"
        "ype=\"t\"/>\n    </method>\n    <method name=\"percent\">\n      <"
        "arg direction=\"out\" type=\"i\"/>\n    </method>\n    <method nam"
        "e=\"downloadSpeed\">\n      <arg direction=\"out\" type=\"i\"/>\n "
        "   </method>\n    <method name=\"uploadSpeed\">\n      <arg direct"
        "ion=\"out\" type=\"i\"/>\n    </method>\n    <method name=\"setUpl"
        "oadLimit\">\n      <arg direction=\"in\" type=\"i\" name=\"ulLimit"
        "\"/>\n      <arg direction=\"in\" type=\"i\" name=\"limit\"/>\n   "
        " </method>\n    <method name=\"setDownloadLimit\">\n      <arg dir"
        "ection=\"in\" type=\"i\" name=\"dlLimit\"/>\n      <arg direction="
        "\"in\" type=\"i\" name=\"limit\"/>\n    </method>\n    <method nam"
        "e=\"uploadLimit\">\n      <arg direction=\"out\" type=\"i\"/>\n   "
        "   <arg direction=\"in\" type=\"i\" name=\"limit\"/>\n    </method"
        ">\n    <method name=\"downloadLimit\">\n      <arg direction=\"out"
        "\" type=\"i\"/>\n      <arg direction=\"in\" type=\"i\" name=\"lim"
        "it\"/>\n    </method>\n    <method name=\"setMaximumShareRatio\">\n"
        "      <arg direction=\"in\" type=\"d\" name=\"ratio\"/>\n    </met"
        "hod>\n    <method name=\"maximumShareRatio\">\n      <arg directio"
        "n=\"out\" type=\"d\"/>\n    </method>\n    <method name=\"statusTe"
        "xt\">\n      <arg direction=\"out\" type=\"s\"/>\n    </method>\n "
        "   <method name=\"statusPixmap\">\n      <arg direction=\"out\" ty"
        "pe=\"v\"/>\n    </method>\n    <method name=\"verifier\">\n      <"
        "arg direction=\"out\" type=\"s\"/>\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"file\"/>\n    </method>\n    <method name=\"repair"
        "\">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg directi"
        "on=\"in\" type=\"s\" name=\"file\"/>\n    </method>\n    <method n"
        "ame=\"setDirectory\">\n      <arg direction=\"out\" type=\"b\"/>\n"
        "      <arg direction=\"in\" type=\"s\" name=\"newDirectory\"/>\n  "
        "  </method>\n    <signal name=\"transferChangedEvent\">\n      <ar"
        "g direction=\"out\" type=\"i\" name=\"changeFlags\"/>\n    </signa"
        "l>\n    <signal name=\"capabilitiesChanged\"/>\n  </interface>\n",
        "capabilitiesChanged",
        "",
        "transferChangedEvent",
        "changeFlags",
        "capabilities",
        "dest",
        "downloadLimit",
        "limit",
        "downloadSpeed",
        "downloadedSize",
        "elapsedTime",
        "groupName",
        "maximumShareRatio",
        "percent",
        "remainingTime",
        "repair",
        "file",
        "setDirectory",
        "newDirectory",
        "setDownloadLimit",
        "dlLimit",
        "setMaximumShareRatio",
        "ratio",
        "setUploadLimit",
        "ulLimit",
        "source",
        "start",
        "status",
        "statusPixmap",
        "QDBusVariant",
        "statusText",
        "stop",
        "totalSize",
        "uploadLimit",
        "uploadSpeed",
        "uploadedSize",
        "verifier"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'capabilitiesChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transferChangedEvent'
        QtMocHelpers::SignalData<void(int)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'capabilities'
        QtMocHelpers::SlotData<int()>(9, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'dest'
        QtMocHelpers::SlotData<QString()>(10, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'downloadLimit'
        QtMocHelpers::SlotData<int(int)>(11, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'downloadSpeed'
        QtMocHelpers::SlotData<int()>(13, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'downloadedSize'
        QtMocHelpers::SlotData<qulonglong()>(14, 6, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'elapsedTime'
        QtMocHelpers::SlotData<int()>(15, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'groupName'
        QtMocHelpers::SlotData<QString()>(16, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'maximumShareRatio'
        QtMocHelpers::SlotData<double()>(17, 6, QMC::AccessPublic, QMetaType::Double),
        // Slot 'percent'
        QtMocHelpers::SlotData<int()>(18, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'remainingTime'
        QtMocHelpers::SlotData<int()>(19, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'repair'
        QtMocHelpers::SlotData<bool(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setDirectory'
        QtMocHelpers::SlotData<bool(const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'setDownloadLimit'
        QtMocHelpers::SlotData<void(int, int)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 25 }, { QMetaType::Int, 12 },
        }}),
        // Slot 'setMaximumShareRatio'
        QtMocHelpers::SlotData<void(double)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 27 },
        }}),
        // Slot 'setUploadLimit'
        QtMocHelpers::SlotData<void(int, int)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::Int, 12 },
        }}),
        // Slot 'source'
        QtMocHelpers::SlotData<QString()>(30, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'status'
        QtMocHelpers::SlotData<int()>(32, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'statusPixmap'
        QtMocHelpers::SlotData<QDBusVariant()>(33, 6, QMC::AccessPublic, 0x80000000 | 34),
        // Slot 'statusText'
        QtMocHelpers::SlotData<QString()>(35, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'totalSize'
        QtMocHelpers::SlotData<qulonglong()>(37, 6, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'uploadLimit'
        QtMocHelpers::SlotData<int(int)>(38, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'uploadSpeed'
        QtMocHelpers::SlotData<int()>(39, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'uploadedSize'
        QtMocHelpers::SlotData<qulonglong()>(40, 6, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'verifier'
        QtMocHelpers::SlotData<QString(const QString &)>(41, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<TransferAdaptor, qt_meta_tag_ZN15TransferAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TransferAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TransferAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TransferAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15TransferAdaptorE_t>.metaTypes,
    nullptr
} };

void TransferAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransferAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->capabilitiesChanged(); break;
        case 1: _t->transferChangedEvent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: { int _r = _t->capabilities();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->dest();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->downloadLimit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->downloadSpeed();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: { qulonglong _r = _t->downloadedSize();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->elapsedTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->groupName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { double _r = _t->maximumShareRatio();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->percent();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: { int _r = _t->remainingTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->repair((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->setDirectory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->setDownloadLimit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->setMaximumShareRatio((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 16: _t->setUploadLimit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 17: { QString _r = _t->source();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->start(); break;
        case 19: { int _r = _t->status();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusVariant _r = _t->statusPixmap();
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        case 21: { QString _r = _t->statusText();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->stop(); break;
        case 23: { qulonglong _r = _t->totalSize();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 24: { int _r = _t->uploadLimit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 25: { int _r = _t->uploadSpeed();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 26: { qulonglong _r = _t->uploadedSize();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 27: { QString _r = _t->verifier((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransferAdaptor::*)()>(_a, &TransferAdaptor::capabilitiesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferAdaptor::*)(int )>(_a, &TransferAdaptor::transferChangedEvent, 1))
            return;
    }
}

const QMetaObject *TransferAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransferAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TransferAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int TransferAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void TransferAdaptor::capabilitiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TransferAdaptor::transferChangedEvent(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
