/********************************************************************************
** Form generated from reading UI file 'transferhistory.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRANSFERHISTORY_H
#define UI_TRANSFERHISTORY_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_TransferHistory
{
public:
    QAction *actionDelete_Selected;
    QAction *actionDownload;
    QVBoxLayout *vboxLayout;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QPushButton *clearButton;
    QSpacerItem *spacerItem;
    QLabel *label;
    QPushButton *bt_iconview;
    QPushButton *bt_listview;
    QLabel *label_2;
    KComboBox *rangeType;
    KLineEdit *searchBar;

    void setupUi(QWidget *TransferHistory)
    {
        if (TransferHistory->objectName().isEmpty())
            TransferHistory->setObjectName("TransferHistory");
        TransferHistory->resize(708, 41);
        actionDelete_Selected = new QAction(TransferHistory);
        actionDelete_Selected->setObjectName("actionDelete_Selected");
        actionDownload = new QAction(TransferHistory);
        actionDownload->setObjectName("actionDownload");
        vboxLayout = new QVBoxLayout(TransferHistory);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(-1, 0, 0, -1);
        clearButton = new QPushButton(TransferHistory);
        clearButton->setObjectName("clearButton");

        hboxLayout->addWidget(clearButton);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        label = new QLabel(TransferHistory);
        label->setObjectName("label");

        hboxLayout->addWidget(label);

        bt_iconview = new QPushButton(TransferHistory);
        bt_iconview->setObjectName("bt_iconview");
        bt_iconview->setCheckable(true);
        bt_iconview->setChecked(true);
        bt_iconview->setAutoExclusive(true);

        hboxLayout->addWidget(bt_iconview);

        bt_listview = new QPushButton(TransferHistory);
        bt_listview->setObjectName("bt_listview");
        bt_listview->setCheckable(true);
        bt_listview->setAutoExclusive(true);

        hboxLayout->addWidget(bt_listview);

        label_2 = new QLabel(TransferHistory);
        label_2->setObjectName("label_2");

        hboxLayout->addWidget(label_2);

        rangeType = new KComboBox(TransferHistory);
        rangeType->addItem(QString());
        rangeType->addItem(QString());
        rangeType->addItem(QString());
        rangeType->setObjectName("rangeType");

        hboxLayout->addWidget(rangeType);

        searchBar = new KLineEdit(TransferHistory);
        searchBar->setObjectName("searchBar");
        searchBar->setProperty("showClearButton", QVariant(true));

        hboxLayout->addWidget(searchBar);


        vboxLayout1->addLayout(hboxLayout);


        vboxLayout->addLayout(vboxLayout1);


        retranslateUi(TransferHistory);

        QMetaObject::connectSlotsByName(TransferHistory);
    } // setupUi

    void retranslateUi(QWidget *TransferHistory)
    {
        actionDelete_Selected->setText(tr2i18n("Delete Selected", "delete selected transfer"));
        actionDownload->setText(tr2i18n("Download", nullptr));
        clearButton->setText(tr2i18n("Clear History", nullptr));
        label->setText(tr2i18n("View Modes:", nullptr));
        label_2->setText(tr2i18n("Select Ranges:", nullptr));
        rangeType->setItemText(0, tr2i18n("Date", nullptr));
        rangeType->setItemText(1, tr2i18n("Size", nullptr));
        rangeType->setItemText(2, tr2i18n("Host", nullptr));

        searchBar->setInputMask(QString());
        searchBar->setPlaceholderText(tr2i18n("Filter history", nullptr));
        (void)TransferHistory;
    } // retranslateUi

};

namespace Ui {
    class TransferHistory: public Ui_TransferHistory {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TRANSFERHISTORY_H

