/********************************************************************************
** Form generated from reading UI file 'dlgmms.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DLGMMS_H
#define UI_DLGMMS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DlgMms
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label;
    QSpinBox *numThreadSpinBox;
    QSpacerItem *spacer;

    void setupUi(QWidget *DlgMms)
    {
        if (DlgMms->objectName().isEmpty())
            DlgMms->setObjectName("DlgMms");
        DlgMms->resize(270, 49);
        verticalLayout = new QVBoxLayout(DlgMms);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(DlgMms);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        numThreadSpinBox = new QSpinBox(DlgMms);
        numThreadSpinBox->setObjectName("numThreadSpinBox");
        numThreadSpinBox->setMinimum(1);
        numThreadSpinBox->setMaximum(100);
        numThreadSpinBox->setValue(5);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, numThreadSpinBox);


        verticalLayout->addLayout(formLayout);

        spacer = new QSpacerItem(20, 39, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacer);


        retranslateUi(DlgMms);

        QMetaObject::connectSlotsByName(DlgMms);
    } // setupUi

    void retranslateUi(QWidget *DlgMms)
    {
        label->setText(tr2i18n("Number of connections per URL:", nullptr));
        (void)DlgMms;
    } // retranslateUi

};

namespace Ui {
    class DlgMms: public Ui_DlgMms {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DLGMMS_H

