/********************************************************************************
** Form generated from reading UI file 'filedlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILEDLG_H
#define UI_FILEDLG_H

#include <KMessageWidget>
#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_FileDlg
{
public:
    QVBoxLayout *verticalLayout;
    KMessageWidget *infoWidget;
    QTabWidget *tabWidget;
    QWidget *tab_3;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    QFormLayout *formLayout;
    QLabel *label_10;
    KLineEdit *name;
    QSpacerItem *verticalSpacer;
    QVBoxLayout *urlLayout;
    QLabel *label_9;
    QWidget *tab_4;
    QGridLayout *gridLayout_2;
    QFormLayout *formLayout_3;
    QLabel *label_11;
    QLineEdit *size;
    QSpacerItem *verticalSpacer_5;
    QLabel *label_2;
    QTreeView *used_hashes;
    QVBoxLayout *verticalLayout_2;
    QPushButton *add_hash;
    QPushButton *remove_hash;
    QSpacerItem *verticalSpacer_2;
    QWidget *Seite;
    QVBoxLayout *verticalLayout_3;
    QVBoxLayout *dataLayout;
    QSpacerItem *verticalSpacer_8;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *FileDlg)
    {
        if (FileDlg->objectName().isEmpty())
            FileDlg->setObjectName("FileDlg");
        FileDlg->resize(518, 596);
        verticalLayout = new QVBoxLayout(FileDlg);
        verticalLayout->setObjectName("verticalLayout");
        infoWidget = new KMessageWidget(FileDlg);
        infoWidget->setObjectName("infoWidget");

        verticalLayout->addWidget(infoWidget);

        tabWidget = new QTabWidget(FileDlg);
        tabWidget->setObjectName("tabWidget");
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout = new QGridLayout(tab_3);
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 0, 1, 1);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label_10 = new QLabel(tab_3);
        label_10->setObjectName("label_10");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_10->sizePolicy().hasHeightForWidth());
        label_10->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_10);

        name = new KLineEdit(tab_3);
        name->setObjectName("name");
        name->setProperty("showClearButton", QVariant(true));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, name);


        gridLayout->addLayout(formLayout, 0, 1, 1, 1);

        verticalSpacer = new QSpacerItem(40, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);

        urlLayout = new QVBoxLayout();
        urlLayout->setObjectName("urlLayout");

        gridLayout->addLayout(urlLayout, 3, 1, 1, 2);

        label_9 = new QLabel(tab_3);
        label_9->setObjectName("label_9");
        QFont font;
        font.setBold(true);
        label_9->setFont(font);

        gridLayout->addWidget(label_9, 2, 0, 1, 2);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        gridLayout_2 = new QGridLayout(tab_4);
        gridLayout_2->setObjectName("gridLayout_2");
        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName("formLayout_3");
        label_11 = new QLabel(tab_4);
        label_11->setObjectName("label_11");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_11);

        size = new QLineEdit(tab_4);
        size->setObjectName("size");
        size->setProperty("showClearButton", QVariant(true));

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, size);


        gridLayout_2->addLayout(formLayout_3, 0, 1, 1, 1);

        verticalSpacer_5 = new QSpacerItem(40, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_5, 1, 0, 1, 1);

        label_2 = new QLabel(tab_4);
        label_2->setObjectName("label_2");
        label_2->setFont(font);

        gridLayout_2->addWidget(label_2, 2, 0, 1, 2);

        used_hashes = new QTreeView(tab_4);
        used_hashes->setObjectName("used_hashes");
        used_hashes->setSelectionMode(QAbstractItemView::ExtendedSelection);
        used_hashes->setRootIsDecorated(false);
        used_hashes->setUniformRowHeights(true);
        used_hashes->setSortingEnabled(true);

        gridLayout_2->addWidget(used_hashes, 3, 1, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        add_hash = new QPushButton(tab_4);
        add_hash->setObjectName("add_hash");

        verticalLayout_2->addWidget(add_hash);

        remove_hash = new QPushButton(tab_4);
        remove_hash->setObjectName("remove_hash");

        verticalLayout_2->addWidget(remove_hash);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);


        gridLayout_2->addLayout(verticalLayout_2, 3, 2, 1, 1);

        tabWidget->addTab(tab_4, QString());
        Seite = new QWidget();
        Seite->setObjectName("Seite");
        verticalLayout_3 = new QVBoxLayout(Seite);
        verticalLayout_3->setObjectName("verticalLayout_3");
        dataLayout = new QVBoxLayout();
        dataLayout->setObjectName("dataLayout");

        verticalLayout_3->addLayout(dataLayout);

        verticalSpacer_8 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_8);

        tabWidget->addTab(Seite, QString());

        verticalLayout->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(FileDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(name, size);
        QWidget::setTabOrder(size, add_hash);
        QWidget::setTabOrder(add_hash, remove_hash);
        QWidget::setTabOrder(remove_hash, used_hashes);

        retranslateUi(FileDlg);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(FileDlg);
    } // setupUi

    void retranslateUi(QWidget *FileDlg)
    {
        label_10->setText(tr2i18n("Filename:", nullptr));
        label_9->setText(tr2i18n("Used Mirrors:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Required", nullptr));
        label_11->setText(tr2i18n("File size (in bytes):", nullptr));
        label_2->setText(tr2i18n("Verification:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), tr2i18n("Recommended", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(Seite), tr2i18n("Optional", nullptr));
        (void)FileDlg;
    } // retranslateUi

};

namespace Ui {
    class FileDlg: public Ui_FileDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILEDLG_H

