/****************************************************************************
** Meta object code from reading C++ file 'multisegkiodatasource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kget-26.08.0/transfer-plugins/multisegmentkio/multisegkiodatasource.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multisegkiodatasource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21MultiSegKioDataSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto MultiSegKioDataSource::qt_create_metaobjectdata<qt_meta_tag_ZN21MultiSegKioDataSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MultiSegKioDataSource",
        "slotSpeed",
        "",
        "speed",
        "slotFinishedSegment",
        "Segment*",
        "segment",
        "segmentNum",
        "connectionFinished",
        "slotRestartBrokenSegment",
        "slotError",
        "errorText",
        "Transfer::LogLevel",
        "logLevel",
        "slotTotalSize",
        "KIO::filesize_t",
        "size",
        "std::pair<int,int>",
        "range",
        "slotCanResume",
        "slotFinishedDownload",
        "slotUrlChanged",
        "QUrl",
        "url"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotSpeed'
        QtMocHelpers::SlotData<void(ulong)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULong, 3 },
        }}),
        // Slot 'slotFinishedSegment'
        QtMocHelpers::SlotData<void(Segment *, int, bool)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Int, 7 }, { QMetaType::Bool, 8 },
        }}),
        // Slot 'slotRestartBrokenSegment'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotError'
        QtMocHelpers::SlotData<void(Segment *, const QString &, Transfer::LogLevel)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'slotTotalSize'
        QtMocHelpers::SlotData<void(KIO::filesize_t, const QPair<int,int> &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'slotTotalSize'
        QtMocHelpers::SlotData<void(KIO::filesize_t)>(14, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotCanResume'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFinishedDownload'
        QtMocHelpers::SlotData<void(KIO::filesize_t)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotUrlChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MultiSegKioDataSource, qt_meta_tag_ZN21MultiSegKioDataSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MultiSegKioDataSource::staticMetaObject = { {
    QMetaObject::SuperData::link<TransferDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21MultiSegKioDataSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21MultiSegKioDataSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21MultiSegKioDataSourceE_t>.metaTypes,
    nullptr
} };

void MultiSegKioDataSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MultiSegKioDataSource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotSpeed((*reinterpret_cast<std::add_pointer_t<ulong>>(_a[1]))); break;
        case 1: _t->slotFinishedSegment((*reinterpret_cast<std::add_pointer_t<Segment*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 2: _t->slotRestartBrokenSegment(); break;
        case 3: _t->slotError((*reinterpret_cast<std::add_pointer_t<Segment*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Transfer::LogLevel>>(_a[3]))); break;
        case 4: _t->slotTotalSize((*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[2]))); break;
        case 5: _t->slotTotalSize((*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[1]))); break;
        case 6: _t->slotCanResume(); break;
        case 7: _t->slotFinishedDownload((*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[1]))); break;
        case 8: _t->slotUrlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *MultiSegKioDataSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MultiSegKioDataSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21MultiSegKioDataSourceE_t>.strings))
        return static_cast<void*>(this);
    return TransferDataSource::qt_metacast(_clname);
}

int MultiSegKioDataSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TransferDataSource::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
