/****************************************************************************
** Meta object code from reading C++ file 'abstractmetalink.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kget-26.08.0/transfer-plugins/metalink/abstractmetalink.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractmetalink.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16AbstractMetalinkE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractMetalink::qt_create_metaobjectdata<qt_meta_tag_ZN16AbstractMetalinkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractMetalink",
        "start",
        "",
        "stop",
        "deinit",
        "Transfer::DeleteOptions",
        "options",
        "fileDlgFinished",
        "result",
        "filesSelected",
        "slotUpdateCapabilities",
        "slotDataSourceFactoryChange",
        "Transfer::ChangesFlags",
        "change",
        "slotRename",
        "QUrl",
        "oldUrl",
        "newUrl",
        "slotVerified",
        "isVerified",
        "slotSignatureVerified"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deinit'
        QtMocHelpers::SlotData<void(Transfer::DeleteOptions)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'fileDlgFinished'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'filesSelected'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotUpdateCapabilities'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDataSourceFactoryChange'
        QtMocHelpers::SlotData<void(Transfer::ChangesFlags)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'slotRename'
        QtMocHelpers::SlotData<void(const QUrl &, const QUrl &)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 15, 17 },
        }}),
        // Slot 'slotVerified'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'slotSignatureVerified'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractMetalink, qt_meta_tag_ZN16AbstractMetalinkE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractMetalink::staticMetaObject = { {
    QMetaObject::SuperData::link<Transfer::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AbstractMetalinkE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AbstractMetalinkE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16AbstractMetalinkE_t>.metaTypes,
    nullptr
} };

void AbstractMetalink::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractMetalink *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->start(); break;
        case 1: _t->stop(); break;
        case 2: _t->deinit((*reinterpret_cast<std::add_pointer_t<Transfer::DeleteOptions>>(_a[1]))); break;
        case 3: _t->fileDlgFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->filesSelected(); break;
        case 5: _t->slotUpdateCapabilities(); break;
        case 6: _t->slotDataSourceFactoryChange((*reinterpret_cast<std::add_pointer_t<Transfer::ChangesFlags>>(_a[1]))); break;
        case 7: _t->slotRename((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 8: _t->slotVerified((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->slotSignatureVerified(); break;
        default: ;
        }
    }
}

const QMetaObject *AbstractMetalink::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractMetalink::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AbstractMetalinkE_t>.strings))
        return static_cast<void*>(this);
    return Transfer::qt_metacast(_clname);
}

int AbstractMetalink::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Transfer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
