/********************************************************************************
** Form generated from reading UI file 'newtransferwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWTRANSFERWIDGET_H
#define UI_NEWTRANSFERWIDGET_H

#include <KMessageWidget>
#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_NewTransferWidget
{
public:
    QVBoxLayout *verticalLayout;
    KMessageWidget *errorWidget;
    QGridLayout *gridLayout;
    QLabel *urlLabel;
    QLabel *label_2;
    KUrlComboRequester *destRequester;
    QLabel *groupLabel;
    KComboBox *groupComboBox;
    QVBoxLayout *verticalLayout_2;
    KLineEdit *urlRequester;
    QListWidget *listWidget;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *NewTransferWidget)
    {
        if (NewTransferWidget->objectName().isEmpty())
            NewTransferWidget->setObjectName("NewTransferWidget");
        NewTransferWidget->resize(400, 246);
        verticalLayout = new QVBoxLayout(NewTransferWidget);
        verticalLayout->setObjectName("verticalLayout");
        errorWidget = new KMessageWidget(NewTransferWidget);
        errorWidget->setObjectName("errorWidget");

        verticalLayout->addWidget(errorWidget);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        urlLabel = new QLabel(NewTransferWidget);
        urlLabel->setObjectName("urlLabel");

        gridLayout->addWidget(urlLabel, 0, 0, 1, 1);

        label_2 = new QLabel(NewTransferWidget);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        destRequester = new KUrlComboRequester(NewTransferWidget);
        destRequester->setObjectName("destRequester");

        gridLayout->addWidget(destRequester, 1, 1, 1, 1);

        groupLabel = new QLabel(NewTransferWidget);
        groupLabel->setObjectName("groupLabel");

        gridLayout->addWidget(groupLabel, 2, 0, 1, 1);

        groupComboBox = new KComboBox(NewTransferWidget);
        groupComboBox->setObjectName("groupComboBox");

        gridLayout->addWidget(groupComboBox, 2, 1, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        urlRequester = new KLineEdit(NewTransferWidget);
        urlRequester->setObjectName("urlRequester");
        urlRequester->setProperty("showClearButton", QVariant(true));

        verticalLayout_2->addWidget(urlRequester);

        listWidget = new QListWidget(NewTransferWidget);
        listWidget->setObjectName("listWidget");

        verticalLayout_2->addWidget(listWidget);


        gridLayout->addLayout(verticalLayout_2, 0, 1, 1, 1);

        verticalSpacer = new QSpacerItem(247, 42, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        buttonBox = new QDialogButtonBox(NewTransferWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(NewTransferWidget);

        QMetaObject::connectSlotsByName(NewTransferWidget);
    } // setupUi

    void retranslateUi(QWidget *NewTransferWidget)
    {
        urlLabel->setText(tr2i18n("URL:", nullptr));
        label_2->setText(tr2i18n("Destination:", nullptr));
        groupLabel->setText(tr2i18n("Transfer group:", nullptr));
        (void)NewTransferWidget;
    } // retranslateUi

};

namespace Ui {
    class NewTransferWidget: public Ui_NewTransferWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWTRANSFERWIDGET_H

