/********************************************************************************
** Form generated from reading UI file 'introduction.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INTRODUCTION_H
#define UI_INTRODUCTION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_Introduction
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    QSpacerItem *verticalSpacer_2;
    QFormLayout *formLayout;
    QLabel *label;
    KUrlRequester *save;
    QSpacerItem *verticalSpacer;
    QRadioButton *createButton;
    QRadioButton *loadButton;
    KUrlRequester *load;
    QSpacerItem *verticalSpacer_3;

    void setupUi(QWidget *Introduction)
    {
        if (Introduction->objectName().isEmpty())
            Introduction->setObjectName("Introduction");
        Introduction->resize(588, 209);
        verticalLayout = new QVBoxLayout(Introduction);
        verticalLayout->setObjectName("verticalLayout");
        label_2 = new QLabel(Introduction);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        verticalLayout->addWidget(label_2);

        verticalSpacer_2 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(Introduction);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        save = new KUrlRequester(Introduction);
        save->setObjectName("save");
        save->setMode(KFile::File|KFile::LocalOnly);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, save);

        verticalSpacer = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(1, QFormLayout::ItemRole::LabelRole, verticalSpacer);

        createButton = new QRadioButton(Introduction);
        createButton->setObjectName("createButton");
        createButton->setChecked(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, createButton);

        loadButton = new QRadioButton(Introduction);
        loadButton->setObjectName("loadButton");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, loadButton);

        load = new KUrlRequester(Introduction);
        load->setObjectName("load");
        load->setEnabled(false);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, load);


        verticalLayout->addLayout(formLayout);

        verticalSpacer_3 = new QSpacerItem(20, 86, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_3);


        retranslateUi(Introduction);
        QObject::connect(loadButton, SIGNAL(toggled(bool)), load, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(Introduction);
    } // setupUi

    void retranslateUi(QWidget *Introduction)
    {
        label_2->setText(tr2i18n("This assistant allows you to create metalinks from scratch or base them on existing metalinks. A lot of the fields are optional or recommended, so enter them if desired. The minimum is a save location, at least one file and one URL.", nullptr));
        label->setText(tr2i18n("Save created Metalink at:", nullptr));
        createButton->setText(tr2i18n("Create new Metalink", nullptr));
        loadButton->setText(tr2i18n("Load existing Metalink:", nullptr));
        (void)Introduction;
    } // retranslateUi

};

namespace Ui {
    class Introduction: public Ui_Introduction {};
} // namespace Ui

QT_END_NAMESPACE

#endif // INTRODUCTION_H

