/****************************************************************************
** Meta object code from reading C++ file 'transferKioFactory.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kget-26.08.0/transfer-plugins/kio/transferKioFactory.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transferKioFactory.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18TransferKioFactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto TransferKioFactory::qt_create_metaobjectdata<qt_meta_tag_ZN18TransferKioFactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransferKioFactory",
        "createTransfer",
        "Transfer*",
        "",
        "QUrl",
        "srcUrl",
        "destUrl",
        "TransferGroup*",
        "parent",
        "Scheduler*",
        "scheduler",
        "const QDomElement*",
        "e",
        "displayName",
        "isSupported",
        "url",
        "addsProtocols"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'createTransfer'
        QtMocHelpers::SlotData<Transfer *(const QUrl &, const QUrl &, TransferGroup *, Scheduler *, const QDomElement *)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'createTransfer'
        QtMocHelpers::SlotData<Transfer *(const QUrl &, const QUrl &, TransferGroup *, Scheduler *)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'displayName'
        QtMocHelpers::SlotData<QString() const>(13, 3, QMC::AccessPublic, QMetaType::QString),
        // Slot 'isSupported'
        QtMocHelpers::SlotData<bool(const QUrl &) const>(14, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 15 },
        }}),
        // Slot 'addsProtocols'
        QtMocHelpers::SlotData<QStringList() const>(16, 3, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransferKioFactory, qt_meta_tag_ZN18TransferKioFactoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransferKioFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<TransferFactory::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TransferKioFactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TransferKioFactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18TransferKioFactoryE_t>.metaTypes,
    nullptr
} };

void TransferKioFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransferKioFactory *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { Transfer* _r = _t->createTransfer((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<TransferGroup*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Scheduler*>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<const QDomElement*>>(_a[5])));
            if (_a[0]) *reinterpret_cast<Transfer**>(_a[0]) = std::move(_r); }  break;
        case 1: { Transfer* _r = _t->createTransfer((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<TransferGroup*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Scheduler*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<Transfer**>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->displayName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->isSupported((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { QStringList _r = _t->addsProtocols();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Scheduler* >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferGroup* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Scheduler* >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferGroup* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *TransferKioFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransferKioFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TransferKioFactoryE_t>.strings))
        return static_cast<void*>(this);
    return TransferFactory::qt_metacast(_clname);
}

int TransferKioFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TransferFactory::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
