// This file is generated by kconfig_compiler_kf6 from kget.kcfg.
// All changes you do to this file will be lost.
#ifndef SETTINGS_H
#define SETTINGS_H

#include <kget_export.h>

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class KGET_EXPORT Settings : public KConfigSkeleton
{
  public:

    static Settings *self();
    ~Settings() override;

    /**
      Set HeaderState
    */
    static
    void setHeaderState( const QString & v )
    {
      if (!self()->isHeaderStateImmutable())
        self()->mHeaderState = v;
    }

    /**
      Get HeaderState
    */
    static
    QString headerState()
    {
      return self()->mHeaderState;
    }

    /**
      Is HeaderState Immutable
    */
    static
    bool isHeaderStateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "HeaderState" ) );
    }

    /**
      Set TransferSettingsHeaderState
    */
    static
    void setTransferSettingsHeaderState( const QString & v )
    {
      if (!self()->isTransferSettingsHeaderStateImmutable())
        self()->mTransferSettingsHeaderState = v;
    }

    /**
      Get TransferSettingsHeaderState
    */
    static
    QString transferSettingsHeaderState()
    {
      return self()->mTransferSettingsHeaderState;
    }

    /**
      Is TransferSettingsHeaderState Immutable
    */
    static
    bool isTransferSettingsHeaderStateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TransferSettingsHeaderState" ) );
    }

    /**
      Set VerificationHeaderState
    */
    static
    void setVerificationHeaderState( const QString & v )
    {
      if (!self()->isVerificationHeaderStateImmutable())
        self()->mVerificationHeaderState = v;
    }

    /**
      Get VerificationHeaderState
    */
    static
    QString verificationHeaderState()
    {
      return self()->mVerificationHeaderState;
    }

    /**
      Is VerificationHeaderState Immutable
    */
    static
    bool isVerificationHeaderStateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "VerificationHeaderState" ) );
    }

    /**
      Set AutoPasteHeaderState
    */
    static
    void setAutoPasteHeaderState( const QString & v )
    {
      if (!self()->isAutoPasteHeaderStateImmutable())
        self()->mAutoPasteHeaderState = v;
    }

    /**
      Get AutoPasteHeaderState
    */
    static
    QString autoPasteHeaderState()
    {
      return self()->mAutoPasteHeaderState;
    }

    /**
      Is AutoPasteHeaderState Immutable
    */
    static
    bool isAutoPasteHeaderStateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AutoPasteHeaderState" ) );
    }

    /**
      Set ShowMain
    */
    static
    void setShowMain( bool v )
    {
      if (!self()->isShowMainImmutable())
        self()->mShowMain = v;
    }

    /**
      Get ShowMain
    */
    static
    bool showMain()
    {
      return self()->mShowMain;
    }

    /**
      Is ShowMain Immutable
    */
    static
    bool isShowMainImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ShowMain" ) );
    }

    /**
      Set ShowIndividual
    */
    static
    void setShowIndividual( bool v )
    {
      if (!self()->isShowIndividualImmutable())
        self()->mShowIndividual = v;
    }

    /**
      Get ShowIndividual
    */
    static
    bool showIndividual()
    {
      return self()->mShowIndividual;
    }

    /**
      Is ShowIndividual Immutable
    */
    static
    bool isShowIndividualImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ShowIndividual" ) );
    }

    /**
      Set DockifyIndividual
    */
    static
    void setDockifyIndividual( bool v )
    {
      if (!self()->isDockifyIndividualImmutable())
        self()->mDockifyIndividual = v;
    }

    /**
      Get DockifyIndividual
    */
    static
    bool dockifyIndividual()
    {
      return self()->mDockifyIndividual;
    }

    /**
      Is DockifyIndividual Immutable
    */
    static
    bool isDockifyIndividualImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DockifyIndividual" ) );
    }

    /**
      Set ShowDropTarget
    */
    static
    void setShowDropTarget( bool v )
    {
      if (!self()->isShowDropTargetImmutable())
        self()->mShowDropTarget = v;
    }

    /**
      Get ShowDropTarget
    */
    static
    bool showDropTarget()
    {
      return self()->mShowDropTarget;
    }

    /**
      Is ShowDropTarget Immutable
    */
    static
    bool isShowDropTargetImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ShowDropTarget" ) );
    }

    /**
      Set AnimateDropTarget
    */
    static
    void setAnimateDropTarget( bool v )
    {
      if (!self()->isAnimateDropTargetImmutable())
        self()->mAnimateDropTarget = v;
    }

    /**
      Get AnimateDropTarget
    */
    static
    bool animateDropTarget()
    {
      return self()->mAnimateDropTarget;
    }

    /**
      Is AnimateDropTarget Immutable
    */
    static
    bool isAnimateDropTargetImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AnimateDropTarget" ) );
    }

    /**
      Set KonquerorIntegration
    */
    static
    void setKonquerorIntegration( bool v )
    {
      if (!self()->isKonquerorIntegrationImmutable())
        self()->mKonquerorIntegration = v;
    }

    /**
      Get KonquerorIntegration
    */
    static
    bool konquerorIntegration()
    {
      return self()->mKonquerorIntegration;
    }

    /**
      Is KonquerorIntegration Immutable
    */
    static
    bool isKonquerorIntegrationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "KonquerorIntegration" ) );
    }

    /**
      Set AutoPaste
    */
    static
    void setAutoPaste( bool v )
    {
      if (!self()->isAutoPasteImmutable())
        self()->mAutoPaste = v;
    }

    /**
      Get AutoPaste
    */
    static
    bool autoPaste()
    {
      return self()->mAutoPaste;
    }

    /**
      Is AutoPaste Immutable
    */
    static
    bool isAutoPasteImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AutoPaste" ) );
    }

    /**
      Set AutoPasteCaseSensitive
    */
    static
    void setAutoPasteCaseSensitive( bool v )
    {
      if (!self()->isAutoPasteCaseSensitiveImmutable())
        self()->mAutoPasteCaseSensitive = v;
    }

    /**
      Get AutoPasteCaseSensitive
    */
    static
    bool autoPasteCaseSensitive()
    {
      return self()->mAutoPasteCaseSensitive;
    }

    /**
      Is AutoPasteCaseSensitive Immutable
    */
    static
    bool isAutoPasteCaseSensitiveImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AutoPasteCaseSensitive" ) );
    }

    /**
      Set AutoPastePatterns
    */
    static
    void setAutoPastePatterns( const QStringList & v )
    {
      if (!self()->isAutoPastePatternsImmutable())
        self()->mAutoPastePatterns = v;
    }

    /**
      Get AutoPastePatterns
    */
    static
    QStringList autoPastePatterns()
    {
      return self()->mAutoPastePatterns;
    }

    /**
      Is AutoPastePatterns Immutable
    */
    static
    bool isAutoPastePatternsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AutoPastePatterns" ) );
    }

    /**
      Set AutoPasteTypes
    */
    static
    void setAutoPasteTypes( const QList<int> & v )
    {
      if (!self()->isAutoPasteTypesImmutable())
        self()->mAutoPasteTypes = v;
    }

    /**
      Get AutoPasteTypes
    */
    static
    QList<int> autoPasteTypes()
    {
      return self()->mAutoPasteTypes;
    }

    /**
      Is AutoPasteTypes Immutable
    */
    static
    bool isAutoPasteTypesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AutoPasteTypes" ) );
    }

    /**
      Set AutoPastePatternSyntaxes
    */
    static
    void setAutoPastePatternSyntaxes( const QList<int> & v )
    {
      if (!self()->isAutoPastePatternSyntaxesImmutable())
        self()->mAutoPastePatternSyntaxes = v;
    }

    /**
      Get AutoPastePatternSyntaxes
    */
    static
    QList<int> autoPastePatternSyntaxes()
    {
      return self()->mAutoPastePatternSyntaxes;
    }

    /**
      Is AutoPastePatternSyntaxes Immutable
    */
    static
    bool isAutoPastePatternSyntaxesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AutoPastePatternSyntaxes" ) );
    }

    /**
      Set TimedDownload
    */
    static
    void setTimedDownload( bool v )
    {
      if (!self()->isTimedDownloadImmutable())
        self()->mTimedDownload = v;
    }

    /**
      Get TimedDownload
    */
    static
    bool timedDownload()
    {
      return self()->mTimedDownload;
    }

    /**
      Is TimedDownload Immutable
    */
    static
    bool isTimedDownloadImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TimedDownload" ) );
    }

    /**
      Set TimedDownloadDateTime
    */
    static
    void setTimedDownloadDateTime( const QDateTime & v )
    {
      if (!self()->isTimedDownloadDateTimeImmutable())
        self()->mTimedDownloadDateTime = v;
    }

    /**
      Get TimedDownloadDateTime
    */
    static
    QDateTime timedDownloadDateTime()
    {
      return self()->mTimedDownloadDateTime;
    }

    /**
      Is TimedDownloadDateTime Immutable
    */
    static
    bool isTimedDownloadDateTimeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TimedDownloadDateTime" ) );
    }

    /**
      Set TimedDisconnect
    */
    static
    void setTimedDisconnect( bool v )
    {
      if (!self()->isTimedDisconnectImmutable())
        self()->mTimedDisconnect = v;
    }

    /**
      Get TimedDisconnect
    */
    static
    bool timedDisconnect()
    {
      return self()->mTimedDisconnect;
    }

    /**
      Is TimedDisconnect Immutable
    */
    static
    bool isTimedDisconnectImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TimedDisconnect" ) );
    }

    /**
      Set TimedDisconnectDateTime
    */
    static
    void setTimedDisconnectDateTime( const QDateTime & v )
    {
      if (!self()->isTimedDisconnectDateTimeImmutable())
        self()->mTimedDisconnectDateTime = v;
    }

    /**
      Get TimedDisconnectDateTime
    */
    static
    QDateTime timedDisconnectDateTime()
    {
      return self()->mTimedDisconnectDateTime;
    }

    /**
      Is TimedDisconnectDateTime Immutable
    */
    static
    bool isTimedDisconnectDateTimeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TimedDisconnectDateTime" ) );
    }

    /**
      Set AutomaticDeletionEnabled
    */
    static
    void setAutomaticDeletionEnabled( bool v )
    {
      if (!self()->isAutomaticDeletionEnabledImmutable())
        self()->mAutomaticDeletionEnabled = v;
    }

    /**
      Get AutomaticDeletionEnabled
    */
    static
    bool automaticDeletionEnabled()
    {
      return self()->mAutomaticDeletionEnabled;
    }

    /**
      Is AutomaticDeletionEnabled Immutable
    */
    static
    bool isAutomaticDeletionEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AutomaticDeletionEnabled" ) );
    }

    /**
      Set ExpiryTimeType
    */
    static
    void setExpiryTimeType( int v )
    {
      if (!self()->isExpiryTimeTypeImmutable())
        self()->mExpiryTimeType = v;
    }

    /**
      Get ExpiryTimeType
    */
    static
    int expiryTimeType()
    {
      return self()->mExpiryTimeType;
    }

    /**
      Is ExpiryTimeType Immutable
    */
    static
    bool isExpiryTimeTypeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ExpiryTimeType" ) );
    }

    /**
      Set ExpiryTimeValue
    */
    static
    void setExpiryTimeValue( int v )
    {
      if (!self()->isExpiryTimeValueImmutable())
        self()->mExpiryTimeValue = v;
    }

    /**
      Get ExpiryTimeValue
    */
    static
    int expiryTimeValue()
    {
      return self()->mExpiryTimeValue;
    }

    /**
      Is ExpiryTimeValue Immutable
    */
    static
    bool isExpiryTimeValueImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ExpiryTimeValue" ) );
    }

    /**
      Set EnableSystemTray
    */
    static
    void setEnableSystemTray( bool v )
    {
      if (!self()->isEnableSystemTrayImmutable())
        self()->mEnableSystemTray = v;
    }

    /**
      Get EnableSystemTray
    */
    static
    bool enableSystemTray()
    {
      return self()->mEnableSystemTray;
    }

    /**
      Is EnableSystemTray Immutable
    */
    static
    bool isEnableSystemTrayImmutable()
    {
      return self()->isImmutable( QStringLiteral( "EnableSystemTray" ) );
    }

    /**
      Set AfterFinishActionEnabled
    */
    static
    void setAfterFinishActionEnabled( bool v )
    {
      if (!self()->isAfterFinishActionEnabledImmutable())
        self()->mAfterFinishActionEnabled = v;
    }

    /**
      Get AfterFinishActionEnabled
    */
    static
    bool afterFinishActionEnabled()
    {
      return self()->mAfterFinishActionEnabled;
    }

    /**
      Is AfterFinishActionEnabled Immutable
    */
    static
    bool isAfterFinishActionEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AfterFinishActionEnabled" ) );
    }

    /**
      Set AfterFinishAction
    */
    static
    void setAfterFinishAction( int v )
    {
      if (!self()->isAfterFinishActionImmutable())
        self()->mAfterFinishAction = v;
    }

    /**
      Get AfterFinishAction
    */
    static
    int afterFinishAction()
    {
      return self()->mAfterFinishAction;
    }

    /**
      Is AfterFinishAction Immutable
    */
    static
    bool isAfterFinishActionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AfterFinishAction" ) );
    }

    /**
      Set EnableKUIServerIntegration
    */
    static
    void setEnableKUIServerIntegration( bool v )
    {
      if (!self()->isEnableKUIServerIntegrationImmutable())
        self()->mEnableKUIServerIntegration = v;
    }

    /**
      Get EnableKUIServerIntegration
    */
    static
    bool enableKUIServerIntegration()
    {
      return self()->mEnableKUIServerIntegration;
    }

    /**
      Is EnableKUIServerIntegration Immutable
    */
    static
    bool isEnableKUIServerIntegrationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "EnableKUIServerIntegration" ) );
    }

    /**
      Set ExportSingleTransfer
    */
    static
    void setExportSingleTransfer( bool v )
    {
      if (!self()->isExportSingleTransferImmutable())
        self()->mExportSingleTransfer = v;
    }

    /**
      Get ExportSingleTransfer
    */
    static
    bool exportSingleTransfer()
    {
      return self()->mExportSingleTransfer;
    }

    /**
      Is ExportSingleTransfer Immutable
    */
    static
    bool isExportSingleTransferImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ExportSingleTransfer" ) );
    }

    /**
      Set ExportGlobalJob
    */
    static
    void setExportGlobalJob( bool v )
    {
      if (!self()->isExportGlobalJobImmutable())
        self()->mExportGlobalJob = v;
    }

    /**
      Get ExportGlobalJob
    */
    static
    bool exportGlobalJob()
    {
      return self()->mExportGlobalJob;
    }

    /**
      Is ExportGlobalJob Immutable
    */
    static
    bool isExportGlobalJobImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ExportGlobalJob" ) );
    }

    /**
      Set HistoryBackend
    */
    static
    void setHistoryBackend( int v )
    {
      if (!self()->isHistoryBackendImmutable())
        self()->mHistoryBackend = v;
    }

    /**
      Get HistoryBackend
    */
    static
    int historyBackend()
    {
      return self()->mHistoryBackend;
    }

    /**
      Is HistoryBackend Immutable
    */
    static
    bool isHistoryBackendImmutable()
    {
      return self()->isImmutable( QStringLiteral( "HistoryBackend" ) );
    }

    /**
      Set StartupAction
    */
    static
    void setStartupAction( int v )
    {
      if (!self()->isStartupActionImmutable())
        self()->mStartupAction = v;
    }

    /**
      Get StartupAction
    */
    static
    int startupAction()
    {
      return self()->mStartupAction;
    }

    /**
      Is StartupAction Immutable
    */
    static
    bool isStartupActionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "StartupAction" ) );
    }

    /**
      Set FilesAlwaysAsk
    */
    static
    void setFilesAlwaysAsk( bool v )
    {
      if (!self()->isFilesAlwaysAskImmutable())
        self()->mFilesAlwaysAsk = v;
    }

    /**
      Get FilesAlwaysAsk
    */
    static
    bool filesAlwaysAsk()
    {
      return self()->mFilesAlwaysAsk;
    }

    /**
      Is FilesAlwaysAsk Immutable
    */
    static
    bool isFilesAlwaysAskImmutable()
    {
      return self()->isImmutable( QStringLiteral( "FilesAlwaysAsk" ) );
    }

    /**
      Set FilesAutomaticRename
    */
    static
    void setFilesAutomaticRename( bool v )
    {
      if (!self()->isFilesAutomaticRenameImmutable())
        self()->mFilesAutomaticRename = v;
    }

    /**
      Get FilesAutomaticRename
    */
    static
    bool filesAutomaticRename()
    {
      return self()->mFilesAutomaticRename;
    }

    /**
      Is FilesAutomaticRename Immutable
    */
    static
    bool isFilesAutomaticRenameImmutable()
    {
      return self()->isImmutable( QStringLiteral( "FilesAutomaticRename" ) );
    }

    /**
      Set FilesOverwrite
    */
    static
    void setFilesOverwrite( bool v )
    {
      if (!self()->isFilesOverwriteImmutable())
        self()->mFilesOverwrite = v;
    }

    /**
      Get FilesOverwrite
    */
    static
    bool filesOverwrite()
    {
      return self()->mFilesOverwrite;
    }

    /**
      Is FilesOverwrite Immutable
    */
    static
    bool isFilesOverwriteImmutable()
    {
      return self()->isImmutable( QStringLiteral( "FilesOverwrite" ) );
    }

    /**
      Set MaxConnections
    */
    static
    void setMaxConnections( int v )
    {
      if (!self()->isMaxConnectionsImmutable())
        self()->mMaxConnections = v;
    }

    /**
      Get MaxConnections
    */
    static
    int maxConnections()
    {
      return self()->mMaxConnections;
    }

    /**
      Is MaxConnections Immutable
    */
    static
    bool isMaxConnectionsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MaxConnections" ) );
    }

    /**
      Set SpeedLimit
    */
    static
    void setSpeedLimit( bool v )
    {
      if (!self()->isSpeedLimitImmutable())
        self()->mSpeedLimit = v;
    }

    /**
      Get SpeedLimit
    */
    static
    bool speedLimit()
    {
      return self()->mSpeedLimit;
    }

    /**
      Is SpeedLimit Immutable
    */
    static
    bool isSpeedLimitImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SpeedLimit" ) );
    }

    /**
      Set TransferSpeedLimit
    */
    static
    void setTransferSpeedLimit( int v )
    {
      if (!self()->isTransferSpeedLimitImmutable())
        self()->mTransferSpeedLimit = v;
    }

    /**
      Get TransferSpeedLimit
    */
    static
    int transferSpeedLimit()
    {
      return self()->mTransferSpeedLimit;
    }

    /**
      Is TransferSpeedLimit Immutable
    */
    static
    bool isTransferSpeedLimitImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TransferSpeedLimit" ) );
    }

    /**
      Set GlobalDownloadLimit
    */
    static
    void setGlobalDownloadLimit( int v )
    {
      if (!self()->isGlobalDownloadLimitImmutable())
        self()->mGlobalDownloadLimit = v;
    }

    /**
      Get GlobalDownloadLimit
    */
    static
    int globalDownloadLimit()
    {
      return self()->mGlobalDownloadLimit;
    }

    /**
      Is GlobalDownloadLimit Immutable
    */
    static
    bool isGlobalDownloadLimitImmutable()
    {
      return self()->isImmutable( QStringLiteral( "GlobalDownloadLimit" ) );
    }

    /**
      Set GlobalUploadLimit
    */
    static
    void setGlobalUploadLimit( int v )
    {
      if (!self()->isGlobalUploadLimitImmutable())
        self()->mGlobalUploadLimit = v;
    }

    /**
      Get GlobalUploadLimit
    */
    static
    int globalUploadLimit()
    {
      return self()->mGlobalUploadLimit;
    }

    /**
      Is GlobalUploadLimit Immutable
    */
    static
    bool isGlobalUploadLimitImmutable()
    {
      return self()->isImmutable( QStringLiteral( "GlobalUploadLimit" ) );
    }

    /**
      Set ReconnectOnBroken
    */
    static
    void setReconnectOnBroken( bool v )
    {
      if (!self()->isReconnectOnBrokenImmutable())
        self()->mReconnectOnBroken = v;
    }

    /**
      Get ReconnectOnBroken
    */
    static
    bool reconnectOnBroken()
    {
      return self()->mReconnectOnBroken;
    }

    /**
      Is ReconnectOnBroken Immutable
    */
    static
    bool isReconnectOnBrokenImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ReconnectOnBroken" ) );
    }

    /**
      Set ReconnectRetries
    */
    static
    void setReconnectRetries( int v )
    {
      if (!self()->isReconnectRetriesImmutable())
        self()->mReconnectRetries = v;
    }

    /**
      Get ReconnectRetries
    */
    static
    int reconnectRetries()
    {
      return self()->mReconnectRetries;
    }

    /**
      Is ReconnectRetries Immutable
    */
    static
    bool isReconnectRetriesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ReconnectRetries" ) );
    }

    /**
      Set ReconnectDelay
    */
    static
    void setReconnectDelay( int v )
    {
      if (!self()->isReconnectDelayImmutable())
        self()->mReconnectDelay = v;
    }

    /**
      Get ReconnectDelay
    */
    static
    int reconnectDelay()
    {
      return self()->mReconnectDelay;
    }

    /**
      Is ReconnectDelay Immutable
    */
    static
    bool isReconnectDelayImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ReconnectDelay" ) );
    }

    /**
      Set WebinterfaceEnabled
    */
    static
    void setWebinterfaceEnabled( bool v )
    {
      if (!self()->isWebinterfaceEnabledImmutable())
        self()->mWebinterfaceEnabled = v;
    }

    /**
      Get WebinterfaceEnabled
    */
    static
    bool webinterfaceEnabled()
    {
      return self()->mWebinterfaceEnabled;
    }

    /**
      Is WebinterfaceEnabled Immutable
    */
    static
    bool isWebinterfaceEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WebinterfaceEnabled" ) );
    }

    /**
      Set WebinterfacePort
    */
    static
    void setWebinterfacePort( int v )
    {
      if (!self()->isWebinterfacePortImmutable())
        self()->mWebinterfacePort = v;
    }

    /**
      Get WebinterfacePort
    */
    static
    int webinterfacePort()
    {
      return self()->mWebinterfacePort;
    }

    /**
      Is WebinterfacePort Immutable
    */
    static
    bool isWebinterfacePortImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WebinterfacePort" ) );
    }

    /**
      Set WebinterfaceUser
    */
    static
    void setWebinterfaceUser( const QString & v )
    {
      if (!self()->isWebinterfaceUserImmutable())
        self()->mWebinterfaceUser = v;
    }

    /**
      Get WebinterfaceUser
    */
    static
    QString webinterfaceUser()
    {
      return self()->mWebinterfaceUser;
    }

    /**
      Is WebinterfaceUser Immutable
    */
    static
    bool isWebinterfaceUserImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WebinterfaceUser" ) );
    }

    /**
      Set DirectoriesAsSuggestion
    */
    static
    void setDirectoriesAsSuggestion( bool v )
    {
      if (!self()->isDirectoriesAsSuggestionImmutable())
        self()->mDirectoriesAsSuggestion = v;
    }

    /**
      Get DirectoriesAsSuggestion
    */
    static
    bool directoriesAsSuggestion()
    {
      return self()->mDirectoriesAsSuggestion;
    }

    /**
      Is DirectoriesAsSuggestion Immutable
    */
    static
    bool isDirectoriesAsSuggestionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DirectoriesAsSuggestion" ) );
    }

    /**
      Set AskForDestination
    */
    static
    void setAskForDestination( bool v )
    {
      if (!self()->isAskForDestinationImmutable())
        self()->mAskForDestination = v;
    }

    /**
      Get AskForDestination
    */
    static
    bool askForDestination()
    {
      return self()->mAskForDestination;
    }

    /**
      Is AskForDestination Immutable
    */
    static
    bool isAskForDestinationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AskForDestination" ) );
    }

    /**
      Set MainPosition
    */
    static
    void setMainPosition( const QPoint & v )
    {
      if (!self()->isMainPositionImmutable())
        self()->mMainPosition = v;
    }

    /**
      Get MainPosition
    */
    static
    QPoint mainPosition()
    {
      return self()->mMainPosition;
    }

    /**
      Is MainPosition Immutable
    */
    static
    bool isMainPositionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MainPosition" ) );
    }

    /**
      Set MainState
    */
    static
    void setMainState( int v )
    {
      if (!self()->isMainStateImmutable())
        self()->mMainState = v;
    }

    /**
      Get MainState
    */
    static
    int mainState()
    {
      return self()->mMainState;
    }

    /**
      Is MainState Immutable
    */
    static
    bool isMainStateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MainState" ) );
    }

    /**
      Set DropPosition
    */
    static
    void setDropPosition( const QPoint & v )
    {
      if (!self()->isDropPositionImmutable())
        self()->mDropPosition = v;
    }

    /**
      Get DropPosition
    */
    static
    QPoint dropPosition()
    {
      return self()->mDropPosition;
    }

    /**
      Is DropPosition Immutable
    */
    static
    bool isDropPositionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DropPosition" ) );
    }

    /**
      Set DropSticky
    */
    static
    void setDropSticky( bool v )
    {
      if (!self()->isDropStickyImmutable())
        self()->mDropSticky = v;
    }

    /**
      Get DropSticky
    */
    static
    bool dropSticky()
    {
      return self()->mDropSticky;
    }

    /**
      Is DropSticky Immutable
    */
    static
    bool isDropStickyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DropSticky" ) );
    }

    /**
      Set FirstRun
    */
    static
    void setFirstRun( bool v )
    {
      if (!self()->isFirstRunImmutable())
        self()->mFirstRun = v;
    }

    /**
      Get FirstRun
    */
    static
    bool firstRun()
    {
      return self()->mFirstRun;
    }

    /**
      Is FirstRun Immutable
    */
    static
    bool isFirstRunImmutable()
    {
      return self()->isImmutable( QStringLiteral( "FirstRun" ) );
    }

    /**
      Set LastDirectory
    */
    static
    void setLastDirectory( const QString & v )
    {
      if (!self()->isLastDirectoryImmutable())
        self()->mLastDirectory = v;
    }

    /**
      Get LastDirectory
    */
    static
    QString lastDirectory()
    {
      return self()->mLastDirectory;
    }

    /**
      Is LastDirectory Immutable
    */
    static
    bool isLastDirectoryImmutable()
    {
      return self()->isImmutable( QStringLiteral( "LastDirectory" ) );
    }

    /**
      Set LastGroup
    */
    static
    void setLastGroup( const QString & v )
    {
      if (!self()->isLastGroupImmutable())
        self()->mLastGroup = v;
    }

    /**
      Get LastGroup
    */
    static
    QString lastGroup()
    {
      return self()->mLastGroup;
    }

    /**
      Is LastGroup Immutable
    */
    static
    bool isLastGroupImmutable()
    {
      return self()->isImmutable( QStringLiteral( "LastGroup" ) );
    }

    /**
      Set LinkViewFilterPatternSyntax
    */
    static
    void setLinkViewFilterPatternSyntax( int v )
    {
      if (!self()->isLinkViewFilterPatternSyntaxImmutable())
        self()->mLinkViewFilterPatternSyntax = v;
    }

    /**
      Get LinkViewFilterPatternSyntax
    */
    static
    int linkViewFilterPatternSyntax()
    {
      return self()->mLinkViewFilterPatternSyntax;
    }

    /**
      Is LinkViewFilterPatternSyntax Immutable
    */
    static
    bool isLinkViewFilterPatternSyntaxImmutable()
    {
      return self()->isImmutable( QStringLiteral( "LinkViewFilterPatternSyntax" ) );
    }

    /**
      Set The width of the columns in the history view
    */
    static
    void setHistoryColumnWidths( const QList<int> & v )
    {
      if (!self()->isHistoryColumnWidthsImmutable())
        self()->mHistoryColumnWidths = v;
    }

    /**
      Get The width of the columns in the history view
    */
    static
    QList<int> historyColumnWidths()
    {
      return self()->mHistoryColumnWidths;
    }

    /**
      Is The width of the columns in the history view Immutable
    */
    static
    bool isHistoryColumnWidthsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "HistoryColumnWidths" ) );
    }

    /**
      Set ChecksumAutomaticVerification
    */
    static
    void setChecksumAutomaticVerification( bool v )
    {
      if (!self()->isChecksumAutomaticVerificationImmutable())
        self()->mChecksumAutomaticVerification = v;
    }

    /**
      Get ChecksumAutomaticVerification
    */
    static
    bool checksumAutomaticVerification()
    {
      return self()->mChecksumAutomaticVerification;
    }

    /**
      Is ChecksumAutomaticVerification Immutable
    */
    static
    bool isChecksumAutomaticVerificationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ChecksumAutomaticVerification" ) );
    }

    /**
      Set ChecksumStrength
    */
    static
    void setChecksumStrength( int v )
    {
      if (!self()->isChecksumStrengthImmutable())
        self()->mChecksumStrength = v;
    }

    /**
      Get ChecksumStrength
    */
    static
    int checksumStrength()
    {
      return self()->mChecksumStrength;
    }

    /**
      Is ChecksumStrength Immutable
    */
    static
    bool isChecksumStrengthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ChecksumStrength" ) );
    }

    /**
      Set SignatureAutomaticVerification
    */
    static
    void setSignatureAutomaticVerification( bool v )
    {
      if (!self()->isSignatureAutomaticVerificationImmutable())
        self()->mSignatureAutomaticVerification = v;
    }

    /**
      Get SignatureAutomaticVerification
    */
    static
    bool signatureAutomaticVerification()
    {
      return self()->mSignatureAutomaticVerification;
    }

    /**
      Is SignatureAutomaticVerification Immutable
    */
    static
    bool isSignatureAutomaticVerificationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SignatureAutomaticVerification" ) );
    }

    /**
      Set SignatureAutomaticDownloading
    */
    static
    void setSignatureAutomaticDownloading( bool v )
    {
      if (!self()->isSignatureAutomaticDownloadingImmutable())
        self()->mSignatureAutomaticDownloading = v;
    }

    /**
      Get SignatureAutomaticDownloading
    */
    static
    bool signatureAutomaticDownloading()
    {
      return self()->mSignatureAutomaticDownloading;
    }

    /**
      Is SignatureAutomaticDownloading Immutable
    */
    static
    bool isSignatureAutomaticDownloadingImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SignatureAutomaticDownloading" ) );
    }

    /**
      Set SignatureKeyServers
    */
    static
    void setSignatureKeyServers( const QStringList & v )
    {
      if (!self()->isSignatureKeyServersImmutable())
        self()->mSignatureKeyServers = v;
    }

    /**
      Get SignatureKeyServers
    */
    static
    QStringList signatureKeyServers()
    {
      return self()->mSignatureKeyServers;
    }

    /**
      Is SignatureKeyServers Immutable
    */
    static
    bool isSignatureKeyServersImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SignatureKeyServers" ) );
    }

  protected:
    Settings();
    friend class SettingsHelper;


    // Appearance
    QString mHeaderState;
    QString mTransferSettingsHeaderState;
    QString mVerificationHeaderState;
    QString mAutoPasteHeaderState;
    bool mShowMain;
    bool mShowIndividual;
    bool mDockifyIndividual;
    bool mShowDropTarget;
    bool mAnimateDropTarget;

    // Advanced
    bool mKonquerorIntegration;
    bool mAutoPaste;
    bool mAutoPasteCaseSensitive;
    QStringList mAutoPastePatterns;
    QList<int> mAutoPasteTypes;
    QList<int> mAutoPastePatternSyntaxes;
    bool mTimedDownload;
    QDateTime mTimedDownloadDateTime;
    bool mTimedDisconnect;
    QDateTime mTimedDisconnectDateTime;
    bool mAutomaticDeletionEnabled;
    int mExpiryTimeType;
    int mExpiryTimeValue;
    bool mEnableSystemTray;
    bool mAfterFinishActionEnabled;
    int mAfterFinishAction;
    bool mEnableKUIServerIntegration;
    bool mExportSingleTransfer;
    bool mExportGlobalJob;
    int mHistoryBackend;
    int mStartupAction;
    bool mFilesAlwaysAsk;
    bool mFilesAutomaticRename;
    bool mFilesOverwrite;

    // Network
    int mMaxConnections;
    bool mSpeedLimit;
    int mTransferSpeedLimit;
    int mGlobalDownloadLimit;
    int mGlobalUploadLimit;
    bool mReconnectOnBroken;
    int mReconnectRetries;
    int mReconnectDelay;

    // Webinterface
    bool mWebinterfaceEnabled;
    int mWebinterfacePort;
    QString mWebinterfaceUser;

    // Groups
    bool mDirectoriesAsSuggestion;
    bool mAskForDestination;

    // Internal
    QPoint mMainPosition;
    int mMainState;
    QPoint mDropPosition;
    bool mDropSticky;
    bool mFirstRun;
    QString mLastDirectory;
    QString mLastGroup;
    int mLinkViewFilterPatternSyntax;

    // Geometry
    QList<int> mHistoryColumnWidths;

    // Verification
    bool mChecksumAutomaticVerification;
    int mChecksumStrength;
    bool mSignatureAutomaticVerification;
    bool mSignatureAutomaticDownloading;
    QStringList mSignatureKeyServers;
};

#endif

