/****************************************************************************
** Meta object code from reading C++ file 'mainadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "mainadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11MainAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto MainAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN11MainAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainAdaptor",
        "D-Bus Interface",
        "org.kde.kget.main",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kget.main\">\n    <method name=\"dropT"
        "argetVisible\">\n      <arg direction=\"out\" type=\"b\"/>\n    </"
        "method>\n    <method name=\"setDropTargetVisible\">\n      <arg di"
        "rection=\"in\" type=\"b\" name=\"visible\"/>\n    </method>\n    <"
        "method name=\"offlineMode\">\n      <arg direction=\"out\" type=\""
        "b\"/>\n    </method>\n    <method name=\"setOfflineMode\">\n      "
        "<arg direction=\"in\" type=\"b\"/>\n    </method>\n    <method nam"
        "e=\"addTransfer\">\n      <arg direction=\"in\" type=\"s\" name=\""
        "src\"/>\n      <arg direction=\"in\" type=\"s\" name=\"destDir\"/>"
        "\n      <arg direction=\"in\" type=\"b\" name=\"start\"/>\n      <"
        "arg direction=\"out\" type=\"as\"/>\n    </method>\n    <method na"
        "me=\"delTransfer\">\n      <arg direction=\"in\" type=\"s\" name=\""
        "dbusObjectPath\"/>\n      <arg direction=\"out\" type=\"b\"/>\n   "
        " </method>\n    <method name=\"showNewTransferDialog\">\n      <ar"
        "g direction=\"in\" type=\"as\" name=\"urls\"/>\n    </method>\n   "
        " <method name=\"transfers\">\n      <annotation value=\"QVariantMa"
        "p\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n      <arg di"
        "rection=\"out\" type=\"a{ss}\" name=\"out\"/>\n    </method>\n    "
        "<method name=\"transfersSpeed\">\n      <arg direction=\"out\" typ"
        "e=\"i\"/>\n    </method>\n    <method name=\"importLinks\">\n     "
        " <arg direction=\"in\" type=\"as\" name=\"links\"/>\n    </method>"
        "\n    <method name=\"isSupported\">\n      <arg direction=\"out\" "
        "type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\"url\"/"
        ">\n    </method>\n    <signal name=\"transfersAdded\">\n      <arg"
        " direction=\"out\" type=\"as\" name=\"urls\"/>\n      <arg directi"
        "on=\"out\" type=\"as\" name=\"dBusObjectPaths\"/>\n    </signal>\n"
        "    <signal name=\"transfersRemoved\">\n      <arg direction=\"out"
        "\" type=\"as\" name=\"urls\"/>\n      <arg direction=\"out\" type="
        "\"as\" name=\"dBusObjectPaths\"/>\n    </signal>\n  </interface>\n",
        "transfersAdded",
        "",
        "urls",
        "dBusObjectPaths",
        "transfersRemoved",
        "addTransfer",
        "src",
        "destDir",
        "start",
        "delTransfer",
        "dbusObjectPath",
        "dropTargetVisible",
        "importLinks",
        "links",
        "isSupported",
        "url",
        "offlineMode",
        "setDropTargetVisible",
        "visible",
        "setOfflineMode",
        "in0",
        "showNewTransferDialog",
        "transfers",
        "QVariantMap",
        "transfersSpeed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'transfersAdded'
        QtMocHelpers::SignalData<void(const QStringList &, const QStringList &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 }, { QMetaType::QStringList, 8 },
        }}),
        // Signal 'transfersRemoved'
        QtMocHelpers::SignalData<void(const QStringList &, const QStringList &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 }, { QMetaType::QStringList, 8 },
        }}),
        // Slot 'addTransfer'
        QtMocHelpers::SlotData<QStringList(const QString &, const QString &, bool)>(10, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'delTransfer'
        QtMocHelpers::SlotData<bool(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'dropTargetVisible'
        QtMocHelpers::SlotData<bool()>(16, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'importLinks'
        QtMocHelpers::SlotData<void(const QStringList &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 18 },
        }}),
        // Slot 'isSupported'
        QtMocHelpers::SlotData<bool(const QString &)>(19, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'offlineMode'
        QtMocHelpers::SlotData<bool()>(21, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setDropTargetVisible'
        QtMocHelpers::SlotData<void(bool)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'setOfflineMode'
        QtMocHelpers::SlotData<void(bool)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'showNewTransferDialog'
        QtMocHelpers::SlotData<void(const QStringList &)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Slot 'transfers'
        QtMocHelpers::SlotData<QVariantMap()>(27, 6, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'transfersSpeed'
        QtMocHelpers::SlotData<int()>(29, 6, QMC::AccessPublic, QMetaType::Int),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MainAdaptor, qt_meta_tag_ZN11MainAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MainAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MainAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MainAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MainAdaptorE_t>.metaTypes,
    nullptr
} };

void MainAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->transfersAdded((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 1: _t->transfersRemoved((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 2: { QStringList _r = _t->addTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->delTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->dropTargetVisible();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->importLinks((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 6: { bool _r = _t->isSupported((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->offlineMode();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setDropTargetVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->setOfflineMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->showNewTransferDialog((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 11: { QVariantMap _r = _t->transfers();
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 12: { int _r = _t->transfersSpeed();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainAdaptor::*)(const QStringList & , const QStringList & )>(_a, &MainAdaptor::transfersAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainAdaptor::*)(const QStringList & , const QStringList & )>(_a, &MainAdaptor::transfersRemoved, 1))
            return;
    }
}

const QMetaObject *MainAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MainAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int MainAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void MainAdaptor::transfersAdded(const QStringList & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void MainAdaptor::transfersRemoved(const QStringList & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
