/********************************************************************************
** Form generated from reading UI file 'dlgengineediting.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DLGENGINEEDITING_H
#define UI_DLGENGINEEDITING_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DlgEngineEditing
{
public:
    QFormLayout *formLayout;
    QLabel *engineNameLabel;
    QLineEdit *engineNameEdit;
    QLabel *urlLabel;
    QLineEdit *urlEdit;

    void setupUi(QWidget *DlgEngineEditing)
    {
        if (DlgEngineEditing->objectName().isEmpty())
            DlgEngineEditing->setObjectName("DlgEngineEditing");
        DlgEngineEditing->resize(419, 132);
        formLayout = new QFormLayout(DlgEngineEditing);
        formLayout->setObjectName("formLayout");
        engineNameLabel = new QLabel(DlgEngineEditing);
        engineNameLabel->setObjectName("engineNameLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, engineNameLabel);

        engineNameEdit = new QLineEdit(DlgEngineEditing);
        engineNameEdit->setObjectName("engineNameEdit");
        engineNameEdit->setProperty("showClearButton", QVariant(true));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, engineNameEdit);

        urlLabel = new QLabel(DlgEngineEditing);
        urlLabel->setObjectName("urlLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, urlLabel);

        urlEdit = new QLineEdit(DlgEngineEditing);
        urlEdit->setObjectName("urlEdit");
        urlEdit->setProperty("showClearButton", QVariant(true));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, urlEdit);


        retranslateUi(DlgEngineEditing);

        QMetaObject::connectSlotsByName(DlgEngineEditing);
    } // setupUi

    void retranslateUi(QWidget *DlgEngineEditing)
    {
        engineNameLabel->setText(tr2i18n("Engine name:", nullptr));
        urlLabel->setText(tr2i18n("URL:", nullptr));
        (void)DlgEngineEditing;
    } // retranslateUi

};

namespace Ui {
    class DlgEngineEditing: public Ui_DlgEngineEditing {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DLGENGINEEDITING_H

