/****************************************************************************
** Meta object code from reading C++ file 'transferhistorystore.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kget-26.08.0/core/transferhistorystore.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transferhistorystore.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20TransferHistoryStoreE_t {};
} // unnamed namespace

template <> constexpr inline auto TransferHistoryStore::qt_create_metaobjectdata<qt_meta_tag_ZN20TransferHistoryStoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransferHistoryStore",
        "elementLoaded",
        "",
        "number",
        "total",
        "TransferHistoryItem",
        "item",
        "loadFinished",
        "saveFinished",
        "deleteFinished",
        "load",
        "clear",
        "saveItem",
        "saveItems",
        "QList<TransferHistoryItem>",
        "items",
        "deleteItem"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'elementLoaded'
        QtMocHelpers::SignalData<void(int, int, const TransferHistoryItem &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'loadFinished'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'saveFinished'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deleteFinished'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveItem'
        QtMocHelpers::SlotData<void(const TransferHistoryItem &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'saveItems'
        QtMocHelpers::SlotData<void(const QList<TransferHistoryItem> &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'deleteItem'
        QtMocHelpers::SlotData<void(const TransferHistoryItem &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransferHistoryStore, qt_meta_tag_ZN20TransferHistoryStoreE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransferHistoryStore::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TransferHistoryStoreE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TransferHistoryStoreE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20TransferHistoryStoreE_t>.metaTypes,
    nullptr
} };

void TransferHistoryStore::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransferHistoryStore *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->elementLoaded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<TransferHistoryItem>>(_a[3]))); break;
        case 1: _t->loadFinished(); break;
        case 2: _t->saveFinished(); break;
        case 3: _t->deleteFinished(); break;
        case 4: _t->load(); break;
        case 5: _t->clear(); break;
        case 6: _t->saveItem((*reinterpret_cast<std::add_pointer_t<TransferHistoryItem>>(_a[1]))); break;
        case 7: _t->saveItems((*reinterpret_cast<std::add_pointer_t<QList<TransferHistoryItem>>>(_a[1]))); break;
        case 8: _t->deleteItem((*reinterpret_cast<std::add_pointer_t<TransferHistoryItem>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferHistoryItem >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferHistoryItem >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<TransferHistoryItem> >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferHistoryItem >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransferHistoryStore::*)(int , int , const TransferHistoryItem & )>(_a, &TransferHistoryStore::elementLoaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferHistoryStore::*)()>(_a, &TransferHistoryStore::loadFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferHistoryStore::*)()>(_a, &TransferHistoryStore::saveFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferHistoryStore::*)()>(_a, &TransferHistoryStore::deleteFinished, 3))
            return;
    }
}

const QMetaObject *TransferHistoryStore::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransferHistoryStore::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TransferHistoryStoreE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TransferHistoryStore::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void TransferHistoryStore::elementLoaded(int _t1, int _t2, const TransferHistoryItem & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void TransferHistoryStore::loadFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TransferHistoryStore::saveFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TransferHistoryStore::deleteFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
