// This file is generated by kconfig_compiler_kf6 from kget_checksumsearchfactory.kcfg.
// All changes you do to this file will be lost.
#ifndef CHECKSUMSEARCHSETTINGS_H
#define CHECKSUMSEARCHSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class ChecksumSearchSettings : public KConfigSkeleton
{
  public:

    static ChecksumSearchSettings *self();
    ~ChecksumSearchSettings() override;

    /**
      Set List of the available search engines
    */
    static
    void setSearchStrings( const QStringList & v )
    {
      if (!self()->isSearchStringsImmutable())
        self()->mSearchStrings = v;
    }

    /**
      Get List of the available search engines
    */
    static
    QStringList searchStrings()
    {
      return self()->mSearchStrings;
    }

    /**
      Is List of the available search engines Immutable
    */
    static
    bool isSearchStringsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SearchStrings" ) );
    }

    /**
      Set List of the available search engine URLs
    */
    static
    void setUrlChangeModeList( const QList<int> & v )
    {
      if (!self()->isUrlChangeModeListImmutable())
        self()->mUrlChangeModeList = v;
    }

    /**
      Get List of the available search engine URLs
    */
    static
    QList<int> urlChangeModeList()
    {
      return self()->mUrlChangeModeList;
    }

    /**
      Is List of the available search engine URLs Immutable
    */
    static
    bool isUrlChangeModeListImmutable()
    {
      return self()->isImmutable( QStringLiteral( "UrlChangeModeList" ) );
    }

    /**
      Set List of the available search engine URLs
    */
    static
    void setChecksumTypeList( const QStringList & v )
    {
      if (!self()->isChecksumTypeListImmutable())
        self()->mChecksumTypeList = v;
    }

    /**
      Get List of the available search engine URLs
    */
    static
    QStringList checksumTypeList()
    {
      return self()->mChecksumTypeList;
    }

    /**
      Is List of the available search engine URLs Immutable
    */
    static
    bool isChecksumTypeListImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ChecksumTypeList" ) );
    }

  protected:
    ChecksumSearchSettings();
    friend class ChecksumSearchSettingsHelper;


    // ChecksumSearch
    QStringList mSearchStrings;
    QList<int> mUrlChangeModeList;
    QStringList mChecksumTypeList;
};

#endif

