/****************************************************************************
** Meta object code from reading C++ file 'transferhistory.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kget-26.08.0/ui/history/transferhistory.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transferhistory.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15TransferHistoryE_t {};
} // unnamed namespace

template <> constexpr inline auto TransferHistory::qt_create_metaobjectdata<qt_meta_tag_ZN15TransferHistoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransferHistory",
        "slotDeleteTransfer",
        "",
        "url",
        "QModelIndex",
        "index",
        "slotAddTransfers",
        "slotClear",
        "slotWriteDefault",
        "slotDownload",
        "slotOpenFile",
        "contextMenuEvent",
        "QContextMenuEvent*",
        "event",
        "slotLoadRangeType",
        "type",
        "slotSetListMode",
        "slotSetIconMode",
        "slotElementLoaded",
        "number",
        "total",
        "TransferHistoryItem",
        "item",
        "slotLoadFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotDeleteTransfer'
        QtMocHelpers::SlotData<void(const QString &, const QModelIndex &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'slotDeleteTransfer'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'slotDeleteTransfer'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddTransfers'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClear'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotWriteDefault'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDownload'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpenFile'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'slotOpenFile'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'contextMenuEvent'
        QtMocHelpers::SlotData<void(QContextMenuEvent *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'slotLoadRangeType'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'slotSetListMode'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetIconMode'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotElementLoaded'
        QtMocHelpers::SlotData<void(int, int, const TransferHistoryItem &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'slotLoadFinished'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransferHistory, qt_meta_tag_ZN15TransferHistoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransferHistory::staticMetaObject = { {
    QMetaObject::SuperData::link<KGetSaveSizeDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TransferHistoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TransferHistoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15TransferHistoryE_t>.metaTypes,
    nullptr
} };

void TransferHistory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransferHistory *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotDeleteTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 1: _t->slotDeleteTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->slotDeleteTransfer(); break;
        case 3: _t->slotAddTransfers(); break;
        case 4: _t->slotClear(); break;
        case 5: _t->slotWriteDefault(); break;
        case 6: _t->slotDownload(); break;
        case 7: _t->slotOpenFile((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 8: _t->slotOpenFile(); break;
        case 9: _t->contextMenuEvent((*reinterpret_cast<std::add_pointer_t<QContextMenuEvent*>>(_a[1]))); break;
        case 10: _t->slotLoadRangeType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->slotSetListMode(); break;
        case 12: _t->slotSetIconMode(); break;
        case 13: _t->slotElementLoaded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<TransferHistoryItem>>(_a[3]))); break;
        case 14: _t->slotLoadFinished(); break;
        default: ;
        }
    }
}

const QMetaObject *TransferHistory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransferHistory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TransferHistoryE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::TransferHistory"))
        return static_cast< Ui::TransferHistory*>(this);
    return KGetSaveSizeDialog::qt_metacast(_clname);
}

int TransferHistory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KGetSaveSizeDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
