/****************************************************************************
** Meta object code from reading C++ file 'dbustransferwrapper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kget-26.08.0/dbus/dbustransferwrapper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbustransferwrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19DBusTransferWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusTransferWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN19DBusTransferWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusTransferWrapper",
        "transferChangedEvent",
        "",
        "transferChange",
        "capabilitiesChanged",
        "capabilities",
        "start",
        "stop",
        "status",
        "elapsedTime",
        "remainingTime",
        "groupName",
        "source",
        "dest",
        "setDirectory",
        "directory",
        "totalSize",
        "downloadedSize",
        "uploadedSize",
        "percent",
        "downloadSpeed",
        "uploadSpeed",
        "setUploadLimit",
        "ulLimit",
        "limit",
        "setDownloadLimit",
        "dlLimit",
        "uploadLimit",
        "downloadLimit",
        "setMaximumShareRatio",
        "ratio",
        "maximumShareRatio",
        "statusText",
        "statusPixmap",
        "QDBusVariant",
        "verifier",
        "file",
        "repair",
        "slotTransferChanged",
        "TransferHandler*",
        "transfer",
        "TransferHandler::ChangesFlags",
        "changeflags"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'transferChangedEvent'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'capabilitiesChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'capabilities'
        QtMocHelpers::SlotData<int() const>(5, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'status'
        QtMocHelpers::SlotData<int() const>(8, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'elapsedTime'
        QtMocHelpers::SlotData<int() const>(9, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'remainingTime'
        QtMocHelpers::SlotData<int() const>(10, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'groupName'
        QtMocHelpers::SlotData<QString() const>(11, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'source'
        QtMocHelpers::SlotData<QString() const>(12, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'dest'
        QtMocHelpers::SlotData<QString() const>(13, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setDirectory'
        QtMocHelpers::SlotData<bool(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'totalSize'
        QtMocHelpers::SlotData<qulonglong() const>(16, 2, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'downloadedSize'
        QtMocHelpers::SlotData<qulonglong() const>(17, 2, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'uploadedSize'
        QtMocHelpers::SlotData<qulonglong() const>(18, 2, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'percent'
        QtMocHelpers::SlotData<int() const>(19, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'downloadSpeed'
        QtMocHelpers::SlotData<int() const>(20, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'uploadSpeed'
        QtMocHelpers::SlotData<int() const>(21, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setUploadLimit'
        QtMocHelpers::SlotData<void(int, int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'setDownloadLimit'
        QtMocHelpers::SlotData<void(int, int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'uploadLimit'
        QtMocHelpers::SlotData<int(int) const>(27, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'downloadLimit'
        QtMocHelpers::SlotData<int(int) const>(28, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setMaximumShareRatio'
        QtMocHelpers::SlotData<void(double)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 30 },
        }}),
        // Slot 'maximumShareRatio'
        QtMocHelpers::SlotData<double()>(31, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'statusText'
        QtMocHelpers::SlotData<QString() const>(32, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'statusPixmap'
        QtMocHelpers::SlotData<QDBusVariant() const>(33, 2, QMC::AccessPublic, 0x80000000 | 34),
        // Slot 'verifier'
        QtMocHelpers::SlotData<QString(const QString &)>(35, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'repair'
        QtMocHelpers::SlotData<bool(const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'slotTransferChanged'
        QtMocHelpers::SlotData<void(TransferHandler *, TransferHandler::ChangesFlags)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 40 }, { 0x80000000 | 41, 42 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusTransferWrapper, qt_meta_tag_ZN19DBusTransferWrapperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusTransferWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DBusTransferWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DBusTransferWrapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19DBusTransferWrapperE_t>.metaTypes,
    nullptr
} };

void DBusTransferWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusTransferWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->transferChangedEvent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->capabilitiesChanged(); break;
        case 2: { int _r = _t->capabilities();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->start(); break;
        case 4: _t->stop(); break;
        case 5: { int _r = _t->status();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->elapsedTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->remainingTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->groupName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->source();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->dest();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->setDirectory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { qulonglong _r = _t->totalSize();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 13: { qulonglong _r = _t->downloadedSize();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 14: { qulonglong _r = _t->uploadedSize();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 15: { int _r = _t->percent();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 16: { int _r = _t->downloadSpeed();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 17: { int _r = _t->uploadSpeed();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->setUploadLimit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 19: _t->setDownloadLimit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 20: { int _r = _t->uploadLimit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 21: { int _r = _t->downloadLimit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->setMaximumShareRatio((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 23: { double _r = _t->maximumShareRatio();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 24: { QString _r = _t->statusText();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusVariant _r = _t->statusPixmap();
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        case 26: { QString _r = _t->verifier((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->repair((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->slotTransferChanged((*reinterpret_cast<std::add_pointer_t<TransferHandler*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TransferHandler::ChangesFlags>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TransferHandler* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusTransferWrapper::*)(int )>(_a, &DBusTransferWrapper::transferChangedEvent, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusTransferWrapper::*)()>(_a, &DBusTransferWrapper::capabilitiesChanged, 1))
            return;
    }
}

const QMetaObject *DBusTransferWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusTransferWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DBusTransferWrapperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DBusTransferWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void DBusTransferWrapper::transferChangedEvent(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DBusTransferWrapper::capabilitiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
