/********************************************************************************
** Form generated from reading UI file 'checksumsearch.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHECKSUMSEARCH_H
#define UI_CHECKSUMSEARCH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ChecksumSearch
{
public:
    QGridLayout *gridLayout;
    QTreeView *treeView;
    QPushButton *add;
    QPushButton *remove;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ChecksumSearch)
    {
        if (ChecksumSearch->objectName().isEmpty())
            ChecksumSearch->setObjectName("ChecksumSearch");
        ChecksumSearch->resize(400, 300);
        gridLayout = new QGridLayout(ChecksumSearch);
        gridLayout->setObjectName("gridLayout");
        treeView = new QTreeView(ChecksumSearch);
        treeView->setObjectName("treeView");
        treeView->setSelectionMode(QAbstractItemView::ExtendedSelection);
        treeView->setRootIsDecorated(false);
        treeView->setUniformRowHeights(true);
        treeView->setItemsExpandable(false);
        treeView->setSortingEnabled(true);

        gridLayout->addWidget(treeView, 0, 0, 3, 1);

        add = new QPushButton(ChecksumSearch);
        add->setObjectName("add");

        gridLayout->addWidget(add, 0, 1, 1, 1);

        remove = new QPushButton(ChecksumSearch);
        remove->setObjectName("remove");

        gridLayout->addWidget(remove, 1, 1, 1, 1);

        verticalSpacer = new QSpacerItem(84, 128, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 1, 1, 1);


        retranslateUi(ChecksumSearch);

        QMetaObject::connectSlotsByName(ChecksumSearch);
    } // setupUi

    void retranslateUi(QWidget *ChecksumSearch)
    {
        (void)ChecksumSearch;
    } // retranslateUi

};

namespace Ui {
    class ChecksumSearch: public Ui_ChecksumSearch {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHECKSUMSEARCH_H

