/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kget.main.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "mainadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class MainAdaptor
 */

MainAdaptor::MainAdaptor(DBusKGetWrapper *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

MainAdaptor::~MainAdaptor()
{
    // destructor
}

QStringList MainAdaptor::addTransfer(const QString &src, const QString &destDir, bool start)
{
    // handle method call org.kde.kget.main.addTransfer
    return parent()->addTransfer(src, destDir, start);
}

bool MainAdaptor::delTransfer(const QString &dbusObjectPath)
{
    // handle method call org.kde.kget.main.delTransfer
    return parent()->delTransfer(dbusObjectPath);
}

bool MainAdaptor::dropTargetVisible()
{
    // handle method call org.kde.kget.main.dropTargetVisible
    return parent()->dropTargetVisible();
}

void MainAdaptor::importLinks(const QStringList &links)
{
    // handle method call org.kde.kget.main.importLinks
    parent()->importLinks(links);
}

bool MainAdaptor::isSupported(const QString &url)
{
    // handle method call org.kde.kget.main.isSupported
    return parent()->isSupported(url);
}

bool MainAdaptor::offlineMode()
{
    // handle method call org.kde.kget.main.offlineMode
    return parent()->offlineMode();
}

void MainAdaptor::setDropTargetVisible(bool visible)
{
    // handle method call org.kde.kget.main.setDropTargetVisible
    parent()->setDropTargetVisible(visible);
}

void MainAdaptor::setOfflineMode(bool in0)
{
    // handle method call org.kde.kget.main.setOfflineMode
    parent()->setOfflineMode(in0);
}

void MainAdaptor::showNewTransferDialog(const QStringList &urls)
{
    // handle method call org.kde.kget.main.showNewTransferDialog
    parent()->showNewTransferDialog(urls);
}

QVariantMap MainAdaptor::transfers()
{
    // handle method call org.kde.kget.main.transfers
    return parent()->transfers();
}

int MainAdaptor::transfersSpeed()
{
    // handle method call org.kde.kget.main.transfersSpeed
    return parent()->transfersSpeed();
}


#include "moc_mainadaptor.cpp"
