/********************************************************************************
** Form generated from reading UI file 'trackerview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRACKERVIEW_H
#define UI_TRACKERVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_TrackerView
{
public:
    QHBoxLayout *horizontalLayout;
    QTreeView *m_tracker_list;
    QVBoxLayout *vboxLayout;
    QPushButton *m_add_tracker;
    QPushButton *m_remove_tracker;
    QPushButton *m_change_tracker;
    QPushButton *m_scrape;
    QSpacerItem *spacerItem;
    QPushButton *m_restore_defaults;

    void setupUi(QWidget *TrackerView)
    {
        if (TrackerView->objectName().isEmpty())
            TrackerView->setObjectName("TrackerView");
        TrackerView->resize(781, 201);
        horizontalLayout = new QHBoxLayout(TrackerView);
        horizontalLayout->setObjectName("horizontalLayout");
        m_tracker_list = new QTreeView(TrackerView);
        m_tracker_list->setObjectName("m_tracker_list");

        horizontalLayout->addWidget(m_tracker_list);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        m_add_tracker = new QPushButton(TrackerView);
        m_add_tracker->setObjectName("m_add_tracker");

        vboxLayout->addWidget(m_add_tracker);

        m_remove_tracker = new QPushButton(TrackerView);
        m_remove_tracker->setObjectName("m_remove_tracker");

        vboxLayout->addWidget(m_remove_tracker);

        m_change_tracker = new QPushButton(TrackerView);
        m_change_tracker->setObjectName("m_change_tracker");

        vboxLayout->addWidget(m_change_tracker);

        m_scrape = new QPushButton(TrackerView);
        m_scrape->setObjectName("m_scrape");

        vboxLayout->addWidget(m_scrape);

        spacerItem = new QSpacerItem(20, 81, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);

        m_restore_defaults = new QPushButton(TrackerView);
        m_restore_defaults->setObjectName("m_restore_defaults");

        vboxLayout->addWidget(m_restore_defaults);


        horizontalLayout->addLayout(vboxLayout);


        retranslateUi(TrackerView);

        QMetaObject::connectSlotsByName(TrackerView);
    } // setupUi

    void retranslateUi(QWidget *TrackerView)
    {
        m_add_tracker->setText(tr2i18n("Add Tracker", nullptr));
        m_remove_tracker->setText(tr2i18n("Remove Tracker", nullptr));
        m_change_tracker->setText(tr2i18n("Change Tracker", nullptr));
        m_scrape->setText(tr2i18n("Update Trackers", nullptr));
        m_restore_defaults->setText(tr2i18n("Restore Defaults", nullptr));
        (void)TrackerView;
    } // retranslateUi

};

namespace Ui {
    class TrackerView: public Ui_TrackerView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TRACKERVIEW_H

