/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // kgetui.rc
  0x0,0x0,0x1,0xd0,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x6a,0x5,0x35,0xe,0x0,0x96,0xd4,0x3e,0x1f,0x40,0x73,0x1e,
  0xf,0x49,0x22,0x6c,0x93,0xa9,0x9a,0xb5,0x8a,0x40,0x30,0xf3,0xb4,0x7c,0xc,0x6f,
  0x40,0x26,0x3a,0x83,0x87,0x5f,0xd6,0x79,0xa6,0x2b,0x30,0x1,0x3b,0x0,0x35,0x0,
  0x32,0x0,0x52,0x4b,0xc6,0x18,0x63,0x80,0xc8,0xdf,0xa2,0xca,0x95,0xc,0xed,0xb7,
  0xc2,0x34,0xc4,0x5e,0x4f,0x36,0xf8,0x70,0xf0,0xfe,0x26,0xa6,0x31,0xc9,0x41,0x4d,
  0x94,0x89,0x71,0xad,0x98,0x43,0x42,0xa1,0x18,0x91,0x46,0x0,0x2,0x44,0x89,0x46,
  0x18,0x14,0x1a,0x42,0x36,0x53,0x5f,0xd,0x8b,0x17,0x27,0x1,0x5,0xeb,0x16,0xce,
  0x52,0xdf,0xb,0x95,0xcf,0xdf,0xfb,0x9f,0xbf,0xb9,0x13,0xc5,0x48,0x8e,0xee,0xbd,
  0xe7,0xc5,0x4f,0x83,0xaf,0xa3,0xdc,0x34,0x74,0x9b,0x95,0xb2,0xf9,0x2d,0x8a,0x7,
  0xda,0xc8,0x8f,0xc3,0xbc,0x9e,0x20,0x7a,0xce,0x3e,0x14,0xb5,0x8d,0x7c,0x69,0x5b,
  0xf9,0x6,0x5e,0xb9,0x67,0xb8,0x6b,0x51,0x96,0x7c,0xd9,0xdf,0xb8,0xf0,0xea,0xff,
  0xae,0xd4,0xe6,0x3a,0xcf,0xde,0xec,0x73,0x36,0xdc,0xb7,0x6c,0x5c,0x1a,0xe3,0x73,
  0xef,0xef,0x29,0x6d,0x3c,0xd0,0x73,0xcd,0x38,0xd6,0x3a,0xde,0x4f,0xd9,0x72,0xef,
  0xf7,0x72,0xfb,0x2f,0x80,0x88,0x6b,0xf5,0x40,0xb3,0xab,0xdc,0x6b,0x25,0x47,0x46,
  0x31,0xc9,0x4f,0xf2,0x57,0x89,0xdd,0xef,0xda,0x56,0xeb,0x21,0x4f,0x62,0xac,0x17,
  0x16,0xbb,0x29,0x8,0x32,0xe3,0x5a,0x5b,0xf9,0x7b,0x37,0xdb,0xa1,0xdb,0xb4,0x35,
  0x55,0x92,0xff,0x97,0xce,0xda,0x1,0x52,0xa0,0xd1,0x9d,0x22,0x43,0x25,0x43,0x9b,
  0xb4,0xc6,0x66,0x20,0x44,0x40,0x94,0x83,0x63,0x1e,0x76,0x0,0x15,0x64,0x76,0x68,
  0x29,0x44,0xf8,0x8a,0x82,0x61,0x18,0x4,0x2a,0x20,0xb1,0xde,0xc6,0x16,0x2c,0x76,
  0xd9,0xa3,0x6e,0x22,0x8a,0x78,0x70,0xe3,0xf7,0x65,0x62,0x3e,0x14,0x13,0xa4,0x5b,
  0xd0,0xeb,0x0,0x69,0x52,0x9e,0x56,0xde,0xd3,0x54,0x66,0xa,0xa8,0xea,0x7,0x2e,
  0xe,0x31,0x4f,0x34,0x3b,0x6a,0xc2,0x65,0x75,0x47,0x52,0xcb,0x3c,0x84,0xf4,0x96,
  0x44,0x42,0xa6,0x4e,0x12,0xae,0x62,0xa9,0x61,0xb3,0x7e,0x16,0x62,0x76,0x94,0x7a,
  0xe2,0x78,0x9d,0x68,0x72,0xa9,0x3b,0xc0,0x40,0xc4,0xa0,0xbb,0xc5,0xbd,0x7a,0xbe,
  0x72,0xe4,0x97,0x27,0x5c,0x9,0x0,0x34,0xed,0x9d,0x78,0xb2,0x18,0xb3,0x42,0x48,
  0x69,0x3c,0xc5,0xa9,0x35,0x64,0x45,0xb1,0x25,0x1e,0x27,0x5d,0xbc,0xfb,0x4d,0x13,
  0x6e,0x7,0x97,0x48,0xf1,0xe6,0x45,0xb1,0x60,0xcd,0xd6,0x32,0xa0,0xda,0xe1,0x1f,
  0xce,0x73,0xf8,0x34,0x78,0x5b,0x27,0x20,0x4,0x4c,0x71,0xa,0xca,0xc9,0x94,0x6a,
  0x30,0x83,0x97,0x41,0xab,0x92,0xed,0xd7,0x4a,0x4,0x20,0xf,0x2,0x78,0x15,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // kget
  0x0,0x4,
  0x0,0x7,0x1d,0xc4,
  0x0,0x6b,
  0x0,0x67,0x0,0x65,0x0,0x74,
    // kgetui.rc
  0x0,0x9,
  0xc,0xbb,0x66,0x23,
  0x0,0x6b,
  0x0,0x67,0x0,0x65,0x0,0x74,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0xa0,0x1a,0xc9,0x77,0x30,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0xa0,0x1a,0xc9,0x77,0x30,
  // :/kxmlgui5/kget
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0xa0,0x1a,0xc9,0x77,0x30,
  // :/kxmlgui5/kget/kgetui.rc
  0x0,0x0,0x0,0x24,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0xa0,0x1a,0xc9,0x77,0x30,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kgetui)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kgetui)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kgetui)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kgetui)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kgetui)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kgetui)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
