/****************************************************************************
** Meta object code from reading C++ file 'metalinkhttp.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kget-26.08.0/transfer-plugins/metalink/metalinkhttp.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'metalinkhttp.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12MetalinkHttpE_t {};
} // unnamed namespace

template <> constexpr inline auto MetalinkHttp::qt_create_metaobjectdata<qt_meta_tag_ZN12MetalinkHttpE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MetalinkHttp",
        "start",
        "",
        "save",
        "QDomElement",
        "element",
        "load",
        "const QDomElement*",
        "deinit",
        "Transfer::DeleteOptions",
        "options",
        "slotSignatureVerified",
        "metalinkHttpInit",
        "setSignature",
        "QUrl&",
        "dest",
        "QByteArray&",
        "data",
        "DataSourceFactory*",
        "dataFactory",
        "setDigests",
        "setLinks"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void(const QDomElement &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void(const QDomElement *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 5 },
        }}),
        // Slot 'deinit'
        QtMocHelpers::SlotData<void(Transfer::DeleteOptions)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotSignatureVerified'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'metalinkHttpInit'
        QtMocHelpers::SlotData<bool()>(12, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'setSignature'
        QtMocHelpers::SlotData<void(QUrl &, QByteArray &, DataSourceFactory *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 16, 17 }, { 0x80000000 | 18, 19 },
        }}),
        // Slot 'setDigests'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLinks'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MetalinkHttp, qt_meta_tag_ZN12MetalinkHttpE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MetalinkHttp::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractMetalink::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MetalinkHttpE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MetalinkHttpE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12MetalinkHttpE_t>.metaTypes,
    nullptr
} };

void MetalinkHttp::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MetalinkHttp *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->start(); break;
        case 1: _t->save((*reinterpret_cast<std::add_pointer_t<QDomElement>>(_a[1]))); break;
        case 2: _t->load((*reinterpret_cast<std::add_pointer_t<const QDomElement*>>(_a[1]))); break;
        case 3: _t->deinit((*reinterpret_cast<std::add_pointer_t<Transfer::DeleteOptions>>(_a[1]))); break;
        case 4: _t->slotSignatureVerified(); break;
        case 5: { bool _r = _t->metalinkHttpInit();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->setSignature((*reinterpret_cast<std::add_pointer_t<QUrl&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<DataSourceFactory*>>(_a[3]))); break;
        case 7: _t->setDigests(); break;
        case 8: _t->setLinks(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataSourceFactory* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *MetalinkHttp::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MetalinkHttp::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MetalinkHttpE_t>.strings))
        return static_cast<void*>(this);
    return AbstractMetalink::qt_metacast(_clname);
}

int MetalinkHttp::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractMetalink::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
