/********************************************************************************
** Form generated from reading UI file 'checksumsearchadddlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHECKSUMSEARCHADDDLG_H
#define UI_CHECKSUMSEARCHADDDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ChecksumSearchAddDlg
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label_1;
    KLineEdit *change;
    QLabel *label_2;
    KComboBox *mode;
    QLabel *label_3;
    KComboBox *type;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_4;
    QLabel *label;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *ChecksumSearchAddDlg)
    {
        if (ChecksumSearchAddDlg->objectName().isEmpty())
            ChecksumSearchAddDlg->setObjectName("ChecksumSearchAddDlg");
        ChecksumSearchAddDlg->resize(356, 223);
        verticalLayout = new QVBoxLayout(ChecksumSearchAddDlg);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label_1 = new QLabel(ChecksumSearchAddDlg);
        label_1->setObjectName("label_1");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_1);

        change = new KLineEdit(ChecksumSearchAddDlg);
        change->setObjectName("change");
        change->setProperty("showClearButton", QVariant(true));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, change);

        label_2 = new QLabel(ChecksumSearchAddDlg);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        mode = new KComboBox(ChecksumSearchAddDlg);
        mode->setObjectName("mode");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, mode);

        label_3 = new QLabel(ChecksumSearchAddDlg);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        type = new KComboBox(ChecksumSearchAddDlg);
        type->setObjectName("type");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, type);


        verticalLayout->addLayout(formLayout);

        verticalSpacer_2 = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);

        label_4 = new QLabel(ChecksumSearchAddDlg);
        label_4->setObjectName("label_4");
        QFont font;
        font.setBold(true);
        label_4->setFont(font);

        verticalLayout->addWidget(label_4);

        label = new QLabel(ChecksumSearchAddDlg);
        label->setObjectName("label");
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(ChecksumSearchAddDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(ChecksumSearchAddDlg);

        QMetaObject::connectSlotsByName(ChecksumSearchAddDlg);
    } // setupUi

    void retranslateUi(QWidget *ChecksumSearchAddDlg)
    {
        label_1->setText(tr2i18n("Change string:", nullptr));
        label_2->setText(tr2i18n("Mode:", nullptr));
        label_3->setText(tr2i18n("Checksum type:", nullptr));
        label_4->setText(tr2i18n("Result:", nullptr));
        label->setText(tr2i18n("label", nullptr));
        (void)ChecksumSearchAddDlg;
    } // retranslateUi

};

namespace Ui {
    class ChecksumSearchAddDlg: public Ui_ChecksumSearchAddDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHECKSUMSEARCHADDDLG_H

