/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kget.transfer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "transferadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class TransferAdaptor
 */

TransferAdaptor::TransferAdaptor(DBusTransferWrapper *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

TransferAdaptor::~TransferAdaptor()
{
    // destructor
}

int TransferAdaptor::capabilities()
{
    // handle method call org.kde.kget.transfer.capabilities
    return parent()->capabilities();
}

QString TransferAdaptor::dest()
{
    // handle method call org.kde.kget.transfer.dest
    return parent()->dest();
}

int TransferAdaptor::downloadLimit(int limit)
{
    // handle method call org.kde.kget.transfer.downloadLimit
    return parent()->downloadLimit(limit);
}

int TransferAdaptor::downloadSpeed()
{
    // handle method call org.kde.kget.transfer.downloadSpeed
    return parent()->downloadSpeed();
}

qulonglong TransferAdaptor::downloadedSize()
{
    // handle method call org.kde.kget.transfer.downloadedSize
    return parent()->downloadedSize();
}

int TransferAdaptor::elapsedTime()
{
    // handle method call org.kde.kget.transfer.elapsedTime
    return parent()->elapsedTime();
}

QString TransferAdaptor::groupName()
{
    // handle method call org.kde.kget.transfer.groupName
    return parent()->groupName();
}

double TransferAdaptor::maximumShareRatio()
{
    // handle method call org.kde.kget.transfer.maximumShareRatio
    return parent()->maximumShareRatio();
}

int TransferAdaptor::percent()
{
    // handle method call org.kde.kget.transfer.percent
    return parent()->percent();
}

int TransferAdaptor::remainingTime()
{
    // handle method call org.kde.kget.transfer.remainingTime
    return parent()->remainingTime();
}

bool TransferAdaptor::repair(const QString &file)
{
    // handle method call org.kde.kget.transfer.repair
    return parent()->repair(file);
}

bool TransferAdaptor::setDirectory(const QString &newDirectory)
{
    // handle method call org.kde.kget.transfer.setDirectory
    return parent()->setDirectory(newDirectory);
}

void TransferAdaptor::setDownloadLimit(int dlLimit, int limit)
{
    // handle method call org.kde.kget.transfer.setDownloadLimit
    parent()->setDownloadLimit(dlLimit, limit);
}

void TransferAdaptor::setMaximumShareRatio(double ratio)
{
    // handle method call org.kde.kget.transfer.setMaximumShareRatio
    parent()->setMaximumShareRatio(ratio);
}

void TransferAdaptor::setUploadLimit(int ulLimit, int limit)
{
    // handle method call org.kde.kget.transfer.setUploadLimit
    parent()->setUploadLimit(ulLimit, limit);
}

QString TransferAdaptor::source()
{
    // handle method call org.kde.kget.transfer.source
    return parent()->source();
}

void TransferAdaptor::start()
{
    // handle method call org.kde.kget.transfer.start
    parent()->start();
}

int TransferAdaptor::status()
{
    // handle method call org.kde.kget.transfer.status
    return parent()->status();
}

QDBusVariant TransferAdaptor::statusPixmap()
{
    // handle method call org.kde.kget.transfer.statusPixmap
    return parent()->statusPixmap();
}

QString TransferAdaptor::statusText()
{
    // handle method call org.kde.kget.transfer.statusText
    return parent()->statusText();
}

void TransferAdaptor::stop()
{
    // handle method call org.kde.kget.transfer.stop
    parent()->stop();
}

qulonglong TransferAdaptor::totalSize()
{
    // handle method call org.kde.kget.transfer.totalSize
    return parent()->totalSize();
}

int TransferAdaptor::uploadLimit(int limit)
{
    // handle method call org.kde.kget.transfer.uploadLimit
    return parent()->uploadLimit(limit);
}

int TransferAdaptor::uploadSpeed()
{
    // handle method call org.kde.kget.transfer.uploadSpeed
    return parent()->uploadSpeed();
}

qulonglong TransferAdaptor::uploadedSize()
{
    // handle method call org.kde.kget.transfer.uploadedSize
    return parent()->uploadedSize();
}

QString TransferAdaptor::verifier(const QString &file)
{
    // handle method call org.kde.kget.transfer.verifier
    return parent()->verifier(file);
}


#include "moc_transferadaptor.cpp"
