/********************************************************************************
** Form generated from reading UI file 'dlggroups.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DLGGROUPS_H
#define UI_DLGGROUPS_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <kiconbutton.h>
#include <klocalizedstring.h>
#include "conf/transfersgrouptree.h"

QT_BEGIN_NAMESPACE

class Ui_DlgGroups
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_DirectoriesAsSuggestion;
    QCheckBox *kcfg_AskForDestination;
    TransfersGroupTree *treeView;
    QHBoxLayout *layout;
    QPushButton *add;
    QPushButton *rename;
    QPushButton *remove;
    KIconButton *selectIcon;
    QPushButton *configure;

    void setupUi(QWidget *DlgGroups)
    {
        if (DlgGroups->objectName().isEmpty())
            DlgGroups->setObjectName("DlgGroups");
        DlgGroups->resize(531, 322);
        verticalLayout = new QVBoxLayout(DlgGroups);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_DirectoriesAsSuggestion = new QCheckBox(DlgGroups);
        kcfg_DirectoriesAsSuggestion->setObjectName("kcfg_DirectoriesAsSuggestion");

        verticalLayout->addWidget(kcfg_DirectoriesAsSuggestion);

        kcfg_AskForDestination = new QCheckBox(DlgGroups);
        kcfg_AskForDestination->setObjectName("kcfg_AskForDestination");

        verticalLayout->addWidget(kcfg_AskForDestination);

        treeView = new TransfersGroupTree(DlgGroups);
        treeView->setObjectName("treeView");
        treeView->setAlternatingRowColors(true);
        treeView->setSelectionMode(QAbstractItemView::ExtendedSelection);
        treeView->setRootIsDecorated(false);
        treeView->setItemsExpandable(false);

        verticalLayout->addWidget(treeView);

        layout = new QHBoxLayout();
        layout->setObjectName("layout");
        add = new QPushButton(DlgGroups);
        add->setObjectName("add");

        layout->addWidget(add);

        rename = new QPushButton(DlgGroups);
        rename->setObjectName("rename");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("edit-rename")));
        rename->setIcon(icon);

        layout->addWidget(rename);

        remove = new QPushButton(DlgGroups);
        remove->setObjectName("remove");

        layout->addWidget(remove);

        selectIcon = new KIconButton(DlgGroups);
        selectIcon->setObjectName("selectIcon");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("preferences-desktop-icons")));
        selectIcon->setIcon(icon1);

        layout->addWidget(selectIcon);

        configure = new QPushButton(DlgGroups);
        configure->setObjectName("configure");

        layout->addWidget(configure);


        verticalLayout->addLayout(layout);


        retranslateUi(DlgGroups);

        QMetaObject::connectSlotsByName(DlgGroups);
    } // setupUi

    void retranslateUi(QWidget *DlgGroups)
    {
        kcfg_DirectoriesAsSuggestion->setText(tr2i18n("Use default folders for groups as suggestion", nullptr));
        kcfg_AskForDestination->setText(tr2i18n("Ask for destination if there are no default folders", nullptr));
        rename->setText(tr2i18n("Rename", nullptr));
        selectIcon->setText(tr2i18n("Select Icon...", nullptr));
        (void)DlgGroups;
    } // retranslateUi

};

namespace Ui {
    class DlgGroups: public Ui_DlgGroups {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DLGGROUPS_H

