/****************************************************************************
** Meta object code from reading C++ file 'kget_linkview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kget-26.08.0/ui/linkview/kget_linkview.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kget_linkview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KGetLinkViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KGetLinkView::qt_create_metaobjectdata<qt_meta_tag_ZN12KGetLinkViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGetLinkView",
        "leechUrls",
        "",
        "QList<QUrl>",
        "urls",
        "slotMimeTypeChanged",
        "index",
        "slotFilterModeChanged",
        "slotFilterColumn",
        "QAction*",
        "slotStartLeech",
        "selectionChanged",
        "setTextFilter",
        "text",
        "checkAll",
        "uncheckAll",
        "uncheckItem",
        "QModelIndex",
        "slotCheckSelected",
        "slotInvertSelection",
        "updateSelectionButtons",
        "contextMenuDisplayed",
        "QMenu*",
        "menu",
        "wildcardPatternToggled",
        "enabled",
        "slotStartImport",
        "slotImportProgress",
        "progress",
        "slotImportFinished",
        "updateImportButtonStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'leechUrls'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotMimeTypeChanged'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'slotFilterModeChanged'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'slotFilterColumn'
        QtMocHelpers::SlotData<void(QAction *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Slot 'slotStartLeech'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setTextFilter'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'setTextFilter'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'checkAll'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'uncheckAll'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'uncheckItem'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 6 },
        }}),
        // Slot 'slotCheckSelected'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotInvertSelection'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSelectionButtons'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contextMenuDisplayed'
        QtMocHelpers::SlotData<void(QMenu *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'wildcardPatternToggled'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'slotStartImport'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImportProgress'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'slotImportFinished'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateImportButtonStatus'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGetLinkView, qt_meta_tag_ZN12KGetLinkViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGetLinkView::staticMetaObject = { {
    QMetaObject::SuperData::link<KGetSaveSizeDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGetLinkViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGetLinkViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KGetLinkViewE_t>.metaTypes,
    nullptr
} };

void KGetLinkView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGetLinkView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->leechUrls((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 1: _t->slotMimeTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->slotFilterModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->slotFilterColumn((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 4: _t->slotStartLeech(); break;
        case 5: _t->selectionChanged(); break;
        case 6: _t->setTextFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->setTextFilter(); break;
        case 8: _t->checkAll(); break;
        case 9: _t->uncheckAll(); break;
        case 10: _t->uncheckItem((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 11: _t->slotCheckSelected(); break;
        case 12: _t->slotInvertSelection(); break;
        case 13: _t->updateSelectionButtons(); break;
        case 14: _t->contextMenuDisplayed((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 15: _t->wildcardPatternToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->slotStartImport(); break;
        case 17: _t->slotImportProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->slotImportFinished(); break;
        case 19: _t->updateImportButtonStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KGetLinkView::*)(const QList<QUrl> & )>(_a, &KGetLinkView::leechUrls, 0))
            return;
    }
}

const QMetaObject *KGetLinkView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGetLinkView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KGetLinkViewE_t>.strings))
        return static_cast<void*>(this);
    return KGetSaveSizeDialog::qt_metacast(_clname);
}

int KGetLinkView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KGetSaveSizeDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void KGetLinkView::leechUrls(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
