/********************************************************************************
** Form generated from reading UI file 'chunkdownloadview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHUNKDOWNLOADVIEW_H
#define UI_CHUNKDOWNLOADVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ChunkDownloadView
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel1;
    QLabel *m_total_chunks;
    QHBoxLayout *hboxLayout2;
    QLabel *textLabel5;
    QLabel *m_chunks_downloading;
    QHBoxLayout *hboxLayout3;
    QLabel *textLabel3;
    QLabel *m_chunks_downloaded;
    QHBoxLayout *hboxLayout4;
    QLabel *textLabel1_4;
    QLabel *m_excluded_chunks;
    QHBoxLayout *hboxLayout5;
    QLabel *textLabel1_4_2;
    QLabel *m_chunks_left;
    QHBoxLayout *hboxLayout6;
    QLabel *textLabel1_8;
    QLabel *m_size_chunks;
    QSpacerItem *spacerItem;
    QTreeView *m_chunk_view;

    void setupUi(QWidget *ChunkDownloadView)
    {
        if (ChunkDownloadView->objectName().isEmpty())
            ChunkDownloadView->setObjectName("ChunkDownloadView");
        ChunkDownloadView->resize(830, 203);
        vboxLayout = new QVBoxLayout(ChunkDownloadView);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        textLabel1 = new QLabel(ChunkDownloadView);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        hboxLayout1->addWidget(textLabel1);

        m_total_chunks = new QLabel(ChunkDownloadView);
        m_total_chunks->setObjectName("m_total_chunks");
        m_total_chunks->setMinimumSize(QSize(50, 0));
        m_total_chunks->setFrameShape(QFrame::Box);
        m_total_chunks->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_total_chunks->setWordWrap(false);

        hboxLayout1->addWidget(m_total_chunks);


        hboxLayout->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        textLabel5 = new QLabel(ChunkDownloadView);
        textLabel5->setObjectName("textLabel5");
        textLabel5->setWordWrap(false);

        hboxLayout2->addWidget(textLabel5);

        m_chunks_downloading = new QLabel(ChunkDownloadView);
        m_chunks_downloading->setObjectName("m_chunks_downloading");
        m_chunks_downloading->setMinimumSize(QSize(50, 0));
        m_chunks_downloading->setFrameShape(QFrame::Panel);
        m_chunks_downloading->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_chunks_downloading->setWordWrap(false);

        hboxLayout2->addWidget(m_chunks_downloading);


        hboxLayout->addLayout(hboxLayout2);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        textLabel3 = new QLabel(ChunkDownloadView);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setWordWrap(false);

        hboxLayout3->addWidget(textLabel3);

        m_chunks_downloaded = new QLabel(ChunkDownloadView);
        m_chunks_downloaded->setObjectName("m_chunks_downloaded");
        m_chunks_downloaded->setMinimumSize(QSize(50, 0));
        m_chunks_downloaded->setFrameShape(QFrame::Panel);
        m_chunks_downloaded->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_chunks_downloaded->setWordWrap(false);

        hboxLayout3->addWidget(m_chunks_downloaded);


        hboxLayout->addLayout(hboxLayout3);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setObjectName("hboxLayout4");
        textLabel1_4 = new QLabel(ChunkDownloadView);
        textLabel1_4->setObjectName("textLabel1_4");
        textLabel1_4->setWordWrap(false);

        hboxLayout4->addWidget(textLabel1_4);

        m_excluded_chunks = new QLabel(ChunkDownloadView);
        m_excluded_chunks->setObjectName("m_excluded_chunks");
        m_excluded_chunks->setMinimumSize(QSize(50, 0));
        m_excluded_chunks->setFrameShape(QFrame::Panel);
        m_excluded_chunks->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_excluded_chunks->setWordWrap(false);

        hboxLayout4->addWidget(m_excluded_chunks);


        hboxLayout->addLayout(hboxLayout4);

        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setObjectName("hboxLayout5");
        textLabel1_4_2 = new QLabel(ChunkDownloadView);
        textLabel1_4_2->setObjectName("textLabel1_4_2");
        textLabel1_4_2->setWordWrap(false);

        hboxLayout5->addWidget(textLabel1_4_2);

        m_chunks_left = new QLabel(ChunkDownloadView);
        m_chunks_left->setObjectName("m_chunks_left");
        m_chunks_left->setMinimumSize(QSize(50, 0));
        m_chunks_left->setFrameShape(QFrame::Panel);
        m_chunks_left->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_chunks_left->setWordWrap(false);

        hboxLayout5->addWidget(m_chunks_left);


        hboxLayout->addLayout(hboxLayout5);

        hboxLayout6 = new QHBoxLayout();
        hboxLayout6->setObjectName("hboxLayout6");
        textLabel1_8 = new QLabel(ChunkDownloadView);
        textLabel1_8->setObjectName("textLabel1_8");
        textLabel1_8->setWordWrap(false);

        hboxLayout6->addWidget(textLabel1_8);

        m_size_chunks = new QLabel(ChunkDownloadView);
        m_size_chunks->setObjectName("m_size_chunks");
        m_size_chunks->setMinimumSize(QSize(80, 0));
        m_size_chunks->setFrameShape(QFrame::Panel);
        m_size_chunks->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_size_chunks->setWordWrap(false);

        hboxLayout6->addWidget(m_size_chunks);


        hboxLayout->addLayout(hboxLayout6);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout);

        m_chunk_view = new QTreeView(ChunkDownloadView);
        m_chunk_view->setObjectName("m_chunk_view");
        m_chunk_view->setAlternatingRowColors(true);
        m_chunk_view->setRootIsDecorated(false);
        m_chunk_view->setSortingEnabled(true);

        vboxLayout->addWidget(m_chunk_view);


        retranslateUi(ChunkDownloadView);

        QMetaObject::connectSlotsByName(ChunkDownloadView);
    } // setupUi

    void retranslateUi(QWidget *ChunkDownloadView)
    {
        ChunkDownloadView->setWindowTitle(tr2i18n("Chunks", nullptr));
        textLabel1->setText(tr2i18n("Total:", nullptr));
        m_total_chunks->setText(QString());
        textLabel5->setText(tr2i18n("Currently downloading:", nullptr));
        m_chunks_downloading->setText(QString());
        textLabel3->setText(tr2i18n("Downloaded:", nullptr));
        m_chunks_downloaded->setText(QString());
        textLabel1_4->setText(tr2i18n("Excluded:", nullptr));
        m_excluded_chunks->setText(QString());
        textLabel1_4_2->setText(tr2i18n("Left:", nullptr));
        m_chunks_left->setText(QString());
        textLabel1_8->setText(tr2i18n("Size:", nullptr));
        m_size_chunks->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class ChunkDownloadView: public Ui_ChunkDownloadView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHUNKDOWNLOADVIEW_H

