// This file is generated by kconfig_compiler_kf6 from kget_mmsfactory.kcfg.
// All changes you do to this file will be lost.
#ifndef MMSSETTINGS_H
#define MMSSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class MmsSettings : public KConfigSkeleton
{
  public:

    static MmsSettings *self();
    ~MmsSettings() override;

    /**
      Set Threads
    */
    static
    void setThreads( int v )
    {
      if (!self()->isThreadsImmutable())
        self()->mThreads = v;
    }

    /**
      Get Threads
    */
    static
    int threads()
    {
      return self()->mThreads;
    }

    /**
      Is Threads Immutable
    */
    static
    bool isThreadsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Threads" ) );
    }

  protected:
    MmsSettings();
    friend class MmsSettingsHelper;


    // Threads
    int mThreads;
};

#endif

