/********************************************************************************
** Form generated from reading UI file 'mirrorsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MIRRORSETTINGS_H
#define UI_MIRRORSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MirrorSettings
{
public:
    QGridLayout *gridLayout;
    QPushButton *add;
    QPushButton *remove;
    QSpacerItem *verticalSpacer;
    QPushButton *closeButton;
    QTreeView *treeView;

    void setupUi(QWidget *MirrorSettings)
    {
        if (MirrorSettings->objectName().isEmpty())
            MirrorSettings->setObjectName("MirrorSettings");
        MirrorSettings->resize(508, 233);
        gridLayout = new QGridLayout(MirrorSettings);
        gridLayout->setObjectName("gridLayout");
        add = new QPushButton(MirrorSettings);
        add->setObjectName("add");

        gridLayout->addWidget(add, 0, 1, 1, 1);

        remove = new QPushButton(MirrorSettings);
        remove->setObjectName("remove");

        gridLayout->addWidget(remove, 1, 1, 1, 1);

        verticalSpacer = new QSpacerItem(65, 141, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 1, 1, 1);

        closeButton = new QPushButton(MirrorSettings);
        closeButton->setObjectName("closeButton");

        gridLayout->addWidget(closeButton, 3, 1, 1, 1);

        treeView = new QTreeView(MirrorSettings);
        treeView->setObjectName("treeView");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(treeView->sizePolicy().hasHeightForWidth());
        treeView->setSizePolicy(sizePolicy);
        treeView->setSelectionMode(QAbstractItemView::ExtendedSelection);
        treeView->setRootIsDecorated(false);
        treeView->setUniformRowHeights(true);
        treeView->setSortingEnabled(true);

        gridLayout->addWidget(treeView, 0, 0, 4, 1);


        retranslateUi(MirrorSettings);

        QMetaObject::connectSlotsByName(MirrorSettings);
    } // setupUi

    void retranslateUi(QWidget *MirrorSettings)
    {
        closeButton->setText(tr2i18n("PushButton", nullptr));
        (void)MirrorSettings;
    } // retranslateUi

};

namespace Ui {
    class MirrorSettings: public Ui_MirrorSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MIRRORSETTINGS_H

