/********************************************************************************
** Form generated from reading UI file 'dlgappearance.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DLGAPPEARANCE_H
#define UI_DLGAPPEARANCE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DlgAppearance
{
public:
    QGridLayout *gridLayout_4;
    QGroupBox *kcfg_ShowDropTarget;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_AnimateDropTarget;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *DlgAppearance)
    {
        if (DlgAppearance->objectName().isEmpty())
            DlgAppearance->setObjectName("DlgAppearance");
        DlgAppearance->resize(507, 381);
        gridLayout_4 = new QGridLayout(DlgAppearance);
        gridLayout_4->setObjectName("gridLayout_4");
        kcfg_ShowDropTarget = new QGroupBox(DlgAppearance);
        kcfg_ShowDropTarget->setObjectName("kcfg_ShowDropTarget");
        kcfg_ShowDropTarget->setCheckable(true);
        kcfg_ShowDropTarget->setChecked(false);
        gridLayout = new QGridLayout(kcfg_ShowDropTarget);
        gridLayout->setObjectName("gridLayout");
        kcfg_AnimateDropTarget = new QCheckBox(kcfg_ShowDropTarget);
        kcfg_AnimateDropTarget->setObjectName("kcfg_AnimateDropTarget");

        gridLayout->addWidget(kcfg_AnimateDropTarget, 0, 0, 1, 1);


        gridLayout_4->addWidget(kcfg_ShowDropTarget, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(349, 70, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(spacerItem, 1, 0, 1, 1);


        retranslateUi(DlgAppearance);

        QMetaObject::connectSlotsByName(DlgAppearance);
    } // setupUi

    void retranslateUi(QWidget *DlgAppearance)
    {
        kcfg_ShowDropTarget->setTitle(tr2i18n("Use Drop Target", nullptr));
        kcfg_AnimateDropTarget->setText(tr2i18n("Enable animations", nullptr));
        (void)DlgAppearance;
    } // retranslateUi

};

namespace Ui {
    class DlgAppearance: public Ui_DlgAppearance {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DLGAPPEARANCE_H

