/********************************************************************************
** Form generated from reading UI file 'dragdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DRAGDLG_H
#define UI_DRAGDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DragDlg
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *ktabwidget;
    QWidget *Seite;
    QGridLayout *gridLayout;
    QCheckBox *partialChecksums;
    QLabel *label;
    QSpacerItem *verticalSpacer;
    QVBoxLayout *urlLayout;
    QLabel *label_3;
    QSpacerItem *horizontalSpacer;
    QLabel *label_4;
    QGroupBox *groupBox;
    QLabel *label_2;
    QWidget *Seite_2;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_6;
    QSpacerItem *verticalSpacer_2;
    QVBoxLayout *dataLayout;
    QSpacerItem *verticalSpacer_3;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *DragDlg)
    {
        if (DragDlg->objectName().isEmpty())
            DragDlg->setObjectName("DragDlg");
        DragDlg->resize(512, 492);
        verticalLayout = new QVBoxLayout(DragDlg);
        verticalLayout->setObjectName("verticalLayout");
        ktabwidget = new QTabWidget(DragDlg);
        ktabwidget->setObjectName("ktabwidget");
        Seite = new QWidget();
        Seite->setObjectName("Seite");
        gridLayout = new QGridLayout(Seite);
        gridLayout->setObjectName("gridLayout");
        partialChecksums = new QCheckBox(Seite);
        partialChecksums->setObjectName("partialChecksums");

        gridLayout->addWidget(partialChecksums, 5, 1, 1, 1);

        label = new QLabel(Seite);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        gridLayout->addWidget(label, 0, 0, 1, 2);

        verticalSpacer = new QSpacerItem(40, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        urlLayout = new QVBoxLayout();
        urlLayout->setObjectName("urlLayout");

        gridLayout->addLayout(urlLayout, 2, 1, 1, 1);

        label_3 = new QLabel(Seite);
        label_3->setObjectName("label_3");
        label_3->setWordWrap(true);

        gridLayout->addWidget(label_3, 4, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 0, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 4, 0, 1, 1);

        label_4 = new QLabel(Seite);
        label_4->setObjectName("label_4");
        label_4->setWordWrap(true);

        gridLayout->addWidget(label_4, 1, 1, 1, 1);

        groupBox = new QGroupBox(Seite);
        groupBox->setObjectName("groupBox");

        gridLayout->addWidget(groupBox, 6, 1, 1, 1);

        label_2 = new QLabel(Seite);
        label_2->setObjectName("label_2");
        label_2->setFont(font);

        gridLayout->addWidget(label_2, 3, 0, 1, 2);

        ktabwidget->addTab(Seite, QString());
        Seite_2 = new QWidget();
        Seite_2->setObjectName("Seite_2");
        verticalLayout_2 = new QVBoxLayout(Seite_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_5 = new QLabel(Seite_2);
        label_5->setObjectName("label_5");
        label_5->setFont(font);

        verticalLayout_2->addWidget(label_5);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        label_6 = new QLabel(Seite_2);
        label_6->setObjectName("label_6");
        label_6->setWordWrap(true);

        horizontalLayout->addWidget(label_6);


        verticalLayout_2->addLayout(horizontalLayout);

        verticalSpacer_2 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_2);

        dataLayout = new QVBoxLayout();
        dataLayout->setObjectName("dataLayout");

        verticalLayout_2->addLayout(dataLayout);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_3);

        ktabwidget->addTab(Seite_2, QString());

        verticalLayout->addWidget(ktabwidget);

        buttonBox = new QDialogButtonBox(DragDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(DragDlg);

        ktabwidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DragDlg);
    } // setupUi

    void retranslateUi(QWidget *DragDlg)
    {
        partialChecksums->setText(tr2i18n("Create partial checksums", nullptr));
        label->setText(tr2i18n("General URL:", nullptr));
        label_3->setText(tr2i18n("Automatically create checksums for the selected types. Keep in mind that this might take a while.", nullptr));
        label_4->setText(tr2i18n("Enter URLs here if all the dropped files are on that server and in the same directory. For each dropped file the URL would consist of the entered part and the filename.", nullptr));
        groupBox->setTitle(tr2i18n("Types of the checksums:", nullptr));
        label_2->setText(tr2i18n("Create checksums:", nullptr));
        ktabwidget->setTabText(ktabwidget->indexOf(Seite), tr2i18n("General", "General options."));
        label_5->setText(tr2i18n("Optional data:", nullptr));
        label_6->setText(tr2i18n("Enter information that all chosen files share.", nullptr));
        ktabwidget->setTabText(ktabwidget->indexOf(Seite_2), tr2i18n("Optional", "These entries are optional."));
        (void)DragDlg;
    } // retranslateUi

};

namespace Ui {
    class DragDlg: public Ui_DragDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DRAGDLG_H

