/********************************************************************************
** Form generated from reading UI file 'transferdetailsfrm.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRANSFERDETAILSFRM_H
#define UI_TRANSFERDETAILSFRM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_TransferDetailsFrm
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    KLineEdit *destContentEdit;
    QLabel *destLabel;
    QLabel *sourceLabel;
    KLineEdit *sourceContentEdit;
    QSpacerItem *spacerItem;
    QProgressBar *progressBar;
    QHBoxLayout *hboxLayout;
    QLabel *completedContentLabel;
    QSpacerItem *spacerItem1;
    QLabel *statusLabel;
    QLabel *statusPixmapContentLabel;
    QLabel *statusTextContentLabel;
    QHBoxLayout *hboxLayout1;
    QLabel *speedContentLabel;
    QSpacerItem *spacerItem2;
    QLabel *label;
    QLabel *remainingTimeLabel;

    void setupUi(QWidget *TransferDetailsFrm)
    {
        if (TransferDetailsFrm->objectName().isEmpty())
            TransferDetailsFrm->setObjectName("TransferDetailsFrm");
        TransferDetailsFrm->resize(530, 211);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(TransferDetailsFrm->sizePolicy().hasHeightForWidth());
        TransferDetailsFrm->setSizePolicy(sizePolicy);
        vboxLayout = new QVBoxLayout(TransferDetailsFrm);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout->setObjectName("gridLayout");
        destContentEdit = new KLineEdit(TransferDetailsFrm);
        destContentEdit->setObjectName("destContentEdit");
        destContentEdit->setReadOnly(true);

        gridLayout->addWidget(destContentEdit, 1, 1, 1, 1);

        destLabel = new QLabel(TransferDetailsFrm);
        destLabel->setObjectName("destLabel");

        gridLayout->addWidget(destLabel, 1, 0, 1, 1);

        sourceLabel = new QLabel(TransferDetailsFrm);
        sourceLabel->setObjectName("sourceLabel");

        gridLayout->addWidget(sourceLabel, 0, 0, 1, 1);

        sourceContentEdit = new KLineEdit(TransferDetailsFrm);
        sourceContentEdit->setObjectName("sourceContentEdit");
        sourceContentEdit->setReadOnly(true);

        gridLayout->addWidget(sourceContentEdit, 0, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        spacerItem = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout->addItem(spacerItem);

        progressBar = new QProgressBar(TransferDetailsFrm);
        progressBar->setObjectName("progressBar");

        vboxLayout->addWidget(progressBar);

        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        completedContentLabel = new QLabel(TransferDetailsFrm);
        completedContentLabel->setObjectName("completedContentLabel");
        completedContentLabel->setText(QString::fromUtf8("<done> MiB of <todo> MiB"));

        hboxLayout->addWidget(completedContentLabel);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem1);

        statusLabel = new QLabel(TransferDetailsFrm);
        statusLabel->setObjectName("statusLabel");

        hboxLayout->addWidget(statusLabel);

        statusPixmapContentLabel = new QLabel(TransferDetailsFrm);
        statusPixmapContentLabel->setObjectName("statusPixmapContentLabel");
        statusPixmapContentLabel->setText(QString::fromUtf8("<icon>"));

        hboxLayout->addWidget(statusPixmapContentLabel);

        statusTextContentLabel = new QLabel(TransferDetailsFrm);
        statusTextContentLabel->setObjectName("statusTextContentLabel");
        statusTextContentLabel->setText(QString::fromUtf8("<status>"));

        hboxLayout->addWidget(statusTextContentLabel);


        vboxLayout->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        speedContentLabel = new QLabel(TransferDetailsFrm);
        speedContentLabel->setObjectName("speedContentLabel");
        speedContentLabel->setText(QString::fromUtf8("<speed>"));

        hboxLayout1->addWidget(speedContentLabel);

        spacerItem2 = new QSpacerItem(211, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem2);

        label = new QLabel(TransferDetailsFrm);
        label->setObjectName("label");

        hboxLayout1->addWidget(label);

        remainingTimeLabel = new QLabel(TransferDetailsFrm);
        remainingTimeLabel->setObjectName("remainingTimeLabel");
        remainingTimeLabel->setText(QString::fromUtf8("<remaining time>"));

        hboxLayout1->addWidget(remainingTimeLabel);


        vboxLayout->addLayout(hboxLayout1);


        retranslateUi(TransferDetailsFrm);

        QMetaObject::connectSlotsByName(TransferDetailsFrm);
    } // setupUi

    void retranslateUi(QWidget *TransferDetailsFrm)
    {
        destLabel->setText(tr2i18n("Saving to:", nullptr));
        sourceLabel->setText(tr2i18n("Source:", "@label transfer source"));
        progressBar->setFormat(tr2i18n("%p%", nullptr));
        statusLabel->setText(tr2i18n("Status:", nullptr));
        label->setText(tr2i18n("Remaining Time:", nullptr));
        (void)TransferDetailsFrm;
    } // retranslateUi

};

namespace Ui {
    class TransferDetailsFrm: public Ui_TransferDetailsFrm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TRANSFERDETAILSFRM_H

