/****************************************************************************
** Meta object code from reading C++ file 'mmsdownload.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kget-26.08.0/transfer-plugins/mmsthreads/mmsdownload.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mmsdownload.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11MmsDownloadE_t {};
} // unnamed namespace

template <> constexpr inline auto MmsDownload::qt_create_metaobjectdata<qt_meta_tag_ZN11MmsDownloadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MmsDownload",
        "signBrokenUrl",
        "",
        "signNotAllowMultiDownload",
        "signThreadFinish",
        "signDownloaded",
        "reading",
        "signTotalSize",
        "size",
        "signSpeed",
        "bytes_per_second",
        "signRestartDownload",
        "connections",
        "slotThreadFinish",
        "slotRead",
        "thread_end",
        "thead_ini",
        "slotSpeedChanged",
        "slotIsThreadConnected",
        "connected"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signBrokenUrl'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signNotAllowMultiDownload'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signThreadFinish'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signDownloaded'
        QtMocHelpers::SignalData<qulonglong(qulonglong)>(5, 2, QMC::AccessPublic, QMetaType::ULongLong, {{
            { QMetaType::ULongLong, 6 },
        }}),
        // Signal 'signTotalSize'
        QtMocHelpers::SignalData<qulonglong(qulonglong)>(7, 2, QMC::AccessPublic, QMetaType::ULongLong, {{
            { QMetaType::ULongLong, 8 },
        }}),
        // Signal 'signSpeed'
        QtMocHelpers::SignalData<unsigned long(unsigned long)>(9, 2, QMC::AccessPublic, QMetaType::ULong, {{
            { QMetaType::ULong, 10 },
        }}),
        // Signal 'signRestartDownload'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'slotThreadFinish'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRead'
        QtMocHelpers::SlotData<void(int, int, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'slotSpeedChanged'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotIsThreadConnected'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MmsDownload, qt_meta_tag_ZN11MmsDownloadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MmsDownload::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MmsDownloadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MmsDownloadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MmsDownloadE_t>.metaTypes,
    nullptr
} };

void MmsDownload::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MmsDownload *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signBrokenUrl(); break;
        case 1: _t->signNotAllowMultiDownload(); break;
        case 2: _t->signThreadFinish(); break;
        case 3: { qulonglong _r = _t->signDownloaded((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 4: { qulonglong _r = _t->signTotalSize((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 5: { ulong _r = _t->signSpeed((*reinterpret_cast<std::add_pointer_t<ulong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ulong*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->signRestartDownload((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->slotThreadFinish(); break;
        case 8: _t->slotRead((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 9: _t->slotSpeedChanged(); break;
        case 10: _t->slotIsThreadConnected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MmsDownload::*)()>(_a, &MmsDownload::signBrokenUrl, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MmsDownload::*)()>(_a, &MmsDownload::signNotAllowMultiDownload, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MmsDownload::*)()>(_a, &MmsDownload::signThreadFinish, 2))
            return;
        if (QtMocHelpers::indexOfMethod<qulonglong (MmsDownload::*)(qulonglong )>(_a, &MmsDownload::signDownloaded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<qulonglong (MmsDownload::*)(qulonglong )>(_a, &MmsDownload::signTotalSize, 4))
            return;
        if (QtMocHelpers::indexOfMethod<unsigned long (MmsDownload::*)(unsigned long )>(_a, &MmsDownload::signSpeed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MmsDownload::*)(int )>(_a, &MmsDownload::signRestartDownload, 6))
            return;
    }
}

const QMetaObject *MmsDownload::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MmsDownload::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MmsDownloadE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int MmsDownload::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void MmsDownload::signBrokenUrl()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MmsDownload::signNotAllowMultiDownload()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MmsDownload::signThreadFinish()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
qulonglong MmsDownload::signDownloaded(qulonglong _t1)
{
    qulonglong _t0{};
    QMetaObject::activate<qulonglong>(this, &staticMetaObject, 3, std::addressof(_t0), _t1);
    return _t0;
}

// SIGNAL 4
qulonglong MmsDownload::signTotalSize(qulonglong _t1)
{
    qulonglong _t0{};
    QMetaObject::activate<qulonglong>(this, &staticMetaObject, 4, std::addressof(_t0), _t1);
    return _t0;
}

// SIGNAL 5
unsigned long MmsDownload::signSpeed(unsigned long _t1)
{
    ulong _t0{};
    QMetaObject::activate<ulong>(this, &staticMetaObject, 5, std::addressof(_t0), _t1);
    return _t0;
}

// SIGNAL 6
void MmsDownload::signRestartDownload(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
