/****************************************************************************
** Meta object code from reading C++ file 'metalinkcreator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kget-26.08.0/ui/metalinkcreator/metalinkcreator.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'metalinkcreator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10FileWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto FileWidget::qt_create_metaobjectdata<qt_meta_tag_ZN10FileWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FileWidget",
        "urlsDropped",
        "",
        "QList<QUrl>",
        "files"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'urlsDropped'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileWidget, qt_meta_tag_ZN10FileWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FileWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10FileWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10FileWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10FileWidgetE_t>.metaTypes,
    nullptr
} };

void FileWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->urlsDropped((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileWidget::*)(const QList<QUrl> & )>(_a, &FileWidget::urlsDropped, 0))
            return;
    }
}

const QMetaObject *FileWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FileWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10FileWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int FileWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void FileWidget::urlsDropped(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN15MetalinkCreatorE_t {};
} // unnamed namespace

template <> constexpr inline auto MetalinkCreator::qt_create_metaobjectdata<qt_meta_tag_ZN15MetalinkCreatorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MetalinkCreator",
        "slotAddFile",
        "",
        "KGetMetalink::File",
        "file",
        "slotFileEdited",
        "oldFileName",
        "newFileName",
        "slotHandleDropped",
        "types",
        "createPartial",
        "slotDelayedCreation",
        "slotUpdateAssistantButtons",
        "KPageWidgetItem*",
        "to",
        "from",
        "slotUpdateIntroductionNextButton",
        "slotUpdateFilesButtons",
        "slotRemoveFile",
        "slotFileProperties",
        "slotAddLocalFilesClicked",
        "slotAddClicked",
        "slotSave",
        "slotThreadFinished",
        "slotOpenDragDlg"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotAddFile'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddFile'
        QtMocHelpers::SlotData<void(const KGetMetalink::File &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotFileEdited'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'slotHandleDropped'
        QtMocHelpers::SlotData<void(const QStringList &, bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'slotDelayedCreation'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateAssistantButtons'
        QtMocHelpers::SlotData<void(KPageWidgetItem *, KPageWidgetItem *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 15 },
        }}),
        // Slot 'slotUpdateAssistantButtons'
        QtMocHelpers::SlotData<void(KPageWidgetItem *)>(12, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'slotUpdateAssistantButtons'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotUpdateIntroductionNextButton'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateFilesButtons'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveFile'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFileProperties'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddLocalFilesClicked'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddClicked'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSave'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotThreadFinished'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpenDragDlg'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MetalinkCreator, qt_meta_tag_ZN15MetalinkCreatorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MetalinkCreator::staticMetaObject = { {
    QMetaObject::SuperData::link<KAssistantDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MetalinkCreatorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MetalinkCreatorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15MetalinkCreatorE_t>.metaTypes,
    nullptr
} };

void MetalinkCreator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MetalinkCreator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotAddFile(); break;
        case 1: _t->slotAddFile((*reinterpret_cast<std::add_pointer_t<KGetMetalink::File>>(_a[1]))); break;
        case 2: _t->slotFileEdited((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->slotHandleDropped((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->slotDelayedCreation(); break;
        case 5: _t->slotUpdateAssistantButtons((*reinterpret_cast<std::add_pointer_t<KPageWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KPageWidgetItem*>>(_a[2]))); break;
        case 6: _t->slotUpdateAssistantButtons((*reinterpret_cast<std::add_pointer_t<KPageWidgetItem*>>(_a[1]))); break;
        case 7: _t->slotUpdateAssistantButtons(); break;
        case 8: _t->slotUpdateIntroductionNextButton(); break;
        case 9: _t->slotUpdateFilesButtons(); break;
        case 10: _t->slotRemoveFile(); break;
        case 11: _t->slotFileProperties(); break;
        case 12: _t->slotAddLocalFilesClicked(); break;
        case 13: _t->slotAddClicked(); break;
        case 14: _t->slotSave(); break;
        case 15: _t->slotThreadFinished(); break;
        case 16: _t->slotOpenDragDlg(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPageWidgetItem* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPageWidgetItem* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *MetalinkCreator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MetalinkCreator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MetalinkCreatorE_t>.strings))
        return static_cast<void*>(this);
    return KAssistantDialog::qt_metacast(_clname);
}

int MetalinkCreator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KAssistantDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
