/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kget-26.08.0/mainwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindow",
        "slotQuit",
        "",
        "slotImportUrl",
        "url",
        "slotUpdateTitlePercent",
        "slotToggleDropTarget",
        "slotNewTransfer",
        "slotImportTransfers",
        "slotExportTransfers",
        "slotPreferences",
        "slotDeleteGroup",
        "slotRenameGroup",
        "slotSetIconGroup",
        "slotStartDownload",
        "slotStopDownload",
        "slotConfigureNotifications",
        "slotToggleAutoPaste",
        "slotTrayKonquerorIntegration",
        "slotKonquerorIntegration",
        "slotShowMenubar",
        "slotTransferGroupSettings",
        "slotTransferSettings",
        "slotCreateMetalink",
        "slotPriorityTop",
        "slotPriorityBottom",
        "slotPriorityUp",
        "slotPriorityDown",
        "slotDownloadFinishedActions",
        "slotStopAllDownload",
        "slotStopSelectedDownload",
        "slotStartAllDownload",
        "slotStartSelectedDownload",
        "slotDeleteSelected",
        "slotDeleteSelectedIncludingFiles",
        "slotRedownloadSelected",
        "slotTransfersOpenDest",
        "slotTransfersOpenFile",
        "slotTransfersShowDetails",
        "slotTransfersCopySourceUrl",
        "slotDeleteFinished",
        "slotSaveMyself",
        "slotNewToolbarConfig",
        "slotNewConfig",
        "slotCheckClipboard",
        "slotTransferHistory",
        "slotShowListLinks",
        "slotTransfersChanged",
        "QMap<TransferHandler*,Transfer::ChangesFlags>",
        "transfers",
        "slotGroupsChanged",
        "QMap<TransferGroupHandler*,TransferGroup::ChangesFlags>",
        "groups"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotQuit'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotImportUrl'
        QtMocHelpers::SlotData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'slotUpdateTitlePercent'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotToggleDropTarget'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewTransfer'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImportTransfers'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExportTransfers'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPreferences'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteGroup'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRenameGroup'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetIconGroup'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStartDownload'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStopDownload'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotConfigureNotifications'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleAutoPaste'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTrayKonquerorIntegration'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotKonquerorIntegration'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotShowMenubar'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTransferGroupSettings'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTransferSettings'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCreateMetalink'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPriorityTop'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPriorityBottom'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPriorityUp'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPriorityDown'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDownloadFinishedActions'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStopAllDownload'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStopSelectedDownload'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStartAllDownload'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStartSelectedDownload'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteSelected'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteSelectedIncludingFiles'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRedownloadSelected'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTransfersOpenDest'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTransfersOpenFile'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTransfersShowDetails'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTransfersCopySourceUrl'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteFinished'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSaveMyself'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewToolbarConfig'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewConfig'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCheckClipboard'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTransferHistory'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowListLinks'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTransfersChanged'
        QtMocHelpers::SlotData<void(QMap<TransferHandler*,Transfer::ChangesFlags>)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'slotGroupsChanged'
        QtMocHelpers::SlotData<void(QMap<TransferGroupHandler*,TransferGroup::ChangesFlags>)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MainWindowE_t>.metaTypes,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotQuit(); break;
        case 1: _t->slotImportUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->slotUpdateTitlePercent(); break;
        case 3: _t->slotToggleDropTarget(); break;
        case 4: _t->slotNewTransfer(); break;
        case 5: _t->slotImportTransfers(); break;
        case 6: _t->slotExportTransfers(); break;
        case 7: _t->slotPreferences(); break;
        case 8: _t->slotDeleteGroup(); break;
        case 9: _t->slotRenameGroup(); break;
        case 10: _t->slotSetIconGroup(); break;
        case 11: _t->slotStartDownload(); break;
        case 12: _t->slotStopDownload(); break;
        case 13: _t->slotConfigureNotifications(); break;
        case 14: _t->slotToggleAutoPaste(); break;
        case 15: _t->slotTrayKonquerorIntegration((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->slotKonquerorIntegration((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->slotShowMenubar(); break;
        case 18: _t->slotTransferGroupSettings(); break;
        case 19: _t->slotTransferSettings(); break;
        case 20: _t->slotCreateMetalink(); break;
        case 21: _t->slotPriorityTop(); break;
        case 22: _t->slotPriorityBottom(); break;
        case 23: _t->slotPriorityUp(); break;
        case 24: _t->slotPriorityDown(); break;
        case 25: _t->slotDownloadFinishedActions(); break;
        case 26: _t->slotStopAllDownload(); break;
        case 27: _t->slotStopSelectedDownload(); break;
        case 28: _t->slotStartAllDownload(); break;
        case 29: _t->slotStartSelectedDownload(); break;
        case 30: _t->slotDeleteSelected(); break;
        case 31: _t->slotDeleteSelectedIncludingFiles(); break;
        case 32: _t->slotRedownloadSelected(); break;
        case 33: _t->slotTransfersOpenDest(); break;
        case 34: _t->slotTransfersOpenFile(); break;
        case 35: _t->slotTransfersShowDetails(); break;
        case 36: _t->slotTransfersCopySourceUrl(); break;
        case 37: _t->slotDeleteFinished(); break;
        case 38: _t->slotSaveMyself(); break;
        case 39: _t->slotNewToolbarConfig(); break;
        case 40: _t->slotNewConfig(); break;
        case 41: _t->slotCheckClipboard(); break;
        case 42: _t->slotTransferHistory(); break;
        case 43: _t->slotShowListLinks(); break;
        case 44: _t->slotTransfersChanged((*reinterpret_cast<std::add_pointer_t<QMap<TransferHandler*,Transfer::ChangesFlags>>>(_a[1]))); break;
        case 45: _t->slotGroupsChanged((*reinterpret_cast<std::add_pointer_t<QMap<TransferGroupHandler*,TransferGroup::ChangesFlags>>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 46)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 46;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 46)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 46;
    }
    return _id;
}
QT_WARNING_POP
