/********************************************************************************
** Form generated from reading UI file 'dlgnetwork.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DLGNETWORK_H
#define UI_DLGNETWORK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DlgNetwork
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout_3;
    QLabel *lbl_maxnum;
    QSpinBox *kcfg_MaxConnections;
    QGroupBox *kcfg_SpeedLimit;
    QFormLayout *formLayout_2;
    QLabel *dllimitlb;
    QSpinBox *kcfg_GlobalDownloadLimit;
    QLabel *label_2;
    QSpinBox *kcfg_GlobalUploadLimit;
    QLabel *lb_per_transfer;
    QSpinBox *kcfg_TransferSpeedLimit;
    QGroupBox *kcfg_ReconnectOnBroken;
    QFormLayout *formLayout;
    QLabel *lb_retries_2;
    QSpinBox *kcfg_ReconnectRetries;
    QLabel *lb_after_2;
    QSpinBox *kcfg_ReconnectDelay;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *DlgNetwork)
    {
        if (DlgNetwork->objectName().isEmpty())
            DlgNetwork->setObjectName("DlgNetwork");
        DlgNetwork->resize(349, 437);
        verticalLayout = new QVBoxLayout(DlgNetwork);
        verticalLayout->setObjectName("verticalLayout");
        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName("formLayout_3");
        lbl_maxnum = new QLabel(DlgNetwork);
        lbl_maxnum->setObjectName("lbl_maxnum");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, lbl_maxnum);

        kcfg_MaxConnections = new QSpinBox(DlgNetwork);
        kcfg_MaxConnections->setObjectName("kcfg_MaxConnections");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_MaxConnections);


        verticalLayout->addLayout(formLayout_3);

        kcfg_SpeedLimit = new QGroupBox(DlgNetwork);
        kcfg_SpeedLimit->setObjectName("kcfg_SpeedLimit");
        kcfg_SpeedLimit->setCheckable(true);
        formLayout_2 = new QFormLayout(kcfg_SpeedLimit);
        formLayout_2->setObjectName("formLayout_2");
        dllimitlb = new QLabel(kcfg_SpeedLimit);
        dllimitlb->setObjectName("dllimitlb");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, dllimitlb);

        kcfg_GlobalDownloadLimit = new QSpinBox(kcfg_SpeedLimit);
        kcfg_GlobalDownloadLimit->setObjectName("kcfg_GlobalDownloadLimit");
        kcfg_GlobalDownloadLimit->setMaximum(1000000);
        kcfg_GlobalDownloadLimit->setSingleStep(5);
        kcfg_GlobalDownloadLimit->setValue(10);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_GlobalDownloadLimit);

        label_2 = new QLabel(kcfg_SpeedLimit);
        label_2->setObjectName("label_2");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_GlobalUploadLimit = new QSpinBox(kcfg_SpeedLimit);
        kcfg_GlobalUploadLimit->setObjectName("kcfg_GlobalUploadLimit");
        kcfg_GlobalUploadLimit->setMaximum(1000000);
        kcfg_GlobalUploadLimit->setSingleStep(5);
        kcfg_GlobalUploadLimit->setValue(10);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_GlobalUploadLimit);

        lb_per_transfer = new QLabel(kcfg_SpeedLimit);
        lb_per_transfer->setObjectName("lb_per_transfer");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, lb_per_transfer);

        kcfg_TransferSpeedLimit = new QSpinBox(kcfg_SpeedLimit);
        kcfg_TransferSpeedLimit->setObjectName("kcfg_TransferSpeedLimit");
        kcfg_TransferSpeedLimit->setMaximum(1000000);
        kcfg_TransferSpeedLimit->setSingleStep(5);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_TransferSpeedLimit);


        verticalLayout->addWidget(kcfg_SpeedLimit);

        kcfg_ReconnectOnBroken = new QGroupBox(DlgNetwork);
        kcfg_ReconnectOnBroken->setObjectName("kcfg_ReconnectOnBroken");
        kcfg_ReconnectOnBroken->setCheckable(true);
        formLayout = new QFormLayout(kcfg_ReconnectOnBroken);
        formLayout->setObjectName("formLayout");
        lb_retries_2 = new QLabel(kcfg_ReconnectOnBroken);
        lb_retries_2->setObjectName("lb_retries_2");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lb_retries_2);

        kcfg_ReconnectRetries = new QSpinBox(kcfg_ReconnectOnBroken);
        kcfg_ReconnectRetries->setObjectName("kcfg_ReconnectRetries");
        kcfg_ReconnectRetries->setEnabled(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_ReconnectRetries);

        lb_after_2 = new QLabel(kcfg_ReconnectOnBroken);
        lb_after_2->setObjectName("lb_after_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, lb_after_2);

        kcfg_ReconnectDelay = new QSpinBox(kcfg_ReconnectOnBroken);
        kcfg_ReconnectDelay->setObjectName("kcfg_ReconnectDelay");
        kcfg_ReconnectDelay->setMinimum(10);
        kcfg_ReconnectDelay->setMaximum(86400);
        kcfg_ReconnectDelay->setSingleStep(5);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_ReconnectDelay);


        verticalLayout->addWidget(kcfg_ReconnectOnBroken);

        spacerItem = new QSpacerItem(200, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        dllimitlb->setBuddy(kcfg_GlobalDownloadLimit);
        label_2->setBuddy(kcfg_GlobalUploadLimit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(DlgNetwork);

        QMetaObject::connectSlotsByName(DlgNetwork);
    } // setupUi

    void retranslateUi(QWidget *DlgNetwork)
    {
        lbl_maxnum->setText(tr2i18n("Maximum downloads per group:", nullptr));
        kcfg_MaxConnections->setSpecialValueText(tr2i18n("No limit", "no limit for maximum downloads has been set"));
        kcfg_SpeedLimit->setTitle(tr2i18n("Speed Limit", nullptr));
        dllimitlb->setText(tr2i18n("Global &download limit:", nullptr));
        kcfg_GlobalDownloadLimit->setSuffix(tr2i18n(" KiB/s", nullptr));
        label_2->setText(tr2i18n("Global &upload limit:", nullptr));
        kcfg_GlobalUploadLimit->setSuffix(tr2i18n(" KiB/s", nullptr));
        lb_per_transfer->setText(tr2i18n("Per transfer:", nullptr));
        kcfg_TransferSpeedLimit->setSuffix(tr2i18n(" KiB/s", nullptr));
        kcfg_ReconnectOnBroken->setTitle(tr2i18n("Reconnect on Broken Connection", nullptr));
        lb_retries_2->setText(tr2i18n("Number of retries:", nullptr));
        lb_after_2->setText(tr2i18n("Retry after:", nullptr));
        kcfg_ReconnectDelay->setSuffix(tr2i18n(" sec", nullptr));
        (void)DlgNetwork;
    } // retranslateUi

};

namespace Ui {
    class DlgNetwork: public Ui_DlgNetwork {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DLGNETWORK_H

