/********************************************************************************
** Form generated from reading UI file 'btdetailswidgetfrm.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BTDETAILSWIDGETFRM_H
#define UI_BTDETAILSWIDGETFRM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_BTDetailsWidgetFrm
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout1;
    QLabel *label_7;
    QLabel *seederLabel;
    QLabel *label_9;
    QLabel *dlSpeedLabel;
    QLabel *label_8;
    QLabel *leecherLabel;
    QLabel *label_10;
    QLabel *ulSpeedLabel;
    QGroupBox *groupBox;
    QGridLayout *gridLayout2;
    QLabel *label_3;
    QLabel *chunksDownloadedLabel;
    QLabel *label_5;
    QLabel *chunksLeftLabel;
    QLabel *label_4;
    QLabel *chunksAllLabel;
    QLabel *label_6;
    QLabel *chunksExcludedLabel;
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout3;
    KLineEdit *destEdit;
    KLineEdit *srcEdit;
    QLabel *label_11;
    QLabel *label_2;
    QProgressBar *progressBar;

    void setupUi(QWidget *BTDetailsWidgetFrm)
    {
        if (BTDetailsWidgetFrm->objectName().isEmpty())
            BTDetailsWidgetFrm->setObjectName("BTDetailsWidgetFrm");
        BTDetailsWidgetFrm->resize(606, 208);
        gridLayout = new QGridLayout(BTDetailsWidgetFrm);
        gridLayout->setObjectName("gridLayout");
        groupBox_3 = new QGroupBox(BTDetailsWidgetFrm);
        groupBox_3->setObjectName("groupBox_3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox_3->sizePolicy().hasHeightForWidth());
        groupBox_3->setSizePolicy(sizePolicy);
        QFont font;
        font.setBold(false);
        font.setItalic(false);
        groupBox_3->setFont(font);
        groupBox_3->setAlignment(Qt::AlignHCenter);
        groupBox_3->setFlat(false);
        gridLayout1 = new QGridLayout(groupBox_3);
        gridLayout1->setObjectName("gridLayout1");
        label_7 = new QLabel(groupBox_3);
        label_7->setObjectName("label_7");
        label_7->setFont(font);

        gridLayout1->addWidget(label_7, 0, 0, 1, 1);

        seederLabel = new QLabel(groupBox_3);
        seederLabel->setObjectName("seederLabel");
        seederLabel->setFont(font);

        gridLayout1->addWidget(seederLabel, 0, 1, 1, 1);

        label_9 = new QLabel(groupBox_3);
        label_9->setObjectName("label_9");
        label_9->setFont(font);

        gridLayout1->addWidget(label_9, 0, 3, 1, 1);

        dlSpeedLabel = new QLabel(groupBox_3);
        dlSpeedLabel->setObjectName("dlSpeedLabel");
        dlSpeedLabel->setFont(font);

        gridLayout1->addWidget(dlSpeedLabel, 0, 4, 1, 1);

        label_8 = new QLabel(groupBox_3);
        label_8->setObjectName("label_8");
        label_8->setFont(font);

        gridLayout1->addWidget(label_8, 1, 0, 1, 1);

        leecherLabel = new QLabel(groupBox_3);
        leecherLabel->setObjectName("leecherLabel");
        leecherLabel->setFont(font);

        gridLayout1->addWidget(leecherLabel, 1, 1, 1, 1);

        label_10 = new QLabel(groupBox_3);
        label_10->setObjectName("label_10");
        label_10->setFont(font);

        gridLayout1->addWidget(label_10, 1, 3, 1, 1);

        ulSpeedLabel = new QLabel(groupBox_3);
        ulSpeedLabel->setObjectName("ulSpeedLabel");
        ulSpeedLabel->setFont(font);

        gridLayout1->addWidget(ulSpeedLabel, 1, 4, 1, 1);


        gridLayout->addWidget(groupBox_3, 2, 0, 1, 1);

        groupBox = new QGroupBox(BTDetailsWidgetFrm);
        groupBox->setObjectName("groupBox");
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        groupBox->setAlignment(Qt::AlignHCenter);
        gridLayout2 = new QGridLayout(groupBox);
        gridLayout2->setObjectName("gridLayout2");
        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout2->addWidget(label_3, 0, 0, 1, 2);

        chunksDownloadedLabel = new QLabel(groupBox);
        chunksDownloadedLabel->setObjectName("chunksDownloadedLabel");

        gridLayout2->addWidget(chunksDownloadedLabel, 0, 2, 1, 1);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        gridLayout2->addWidget(label_5, 0, 3, 1, 1);

        chunksLeftLabel = new QLabel(groupBox);
        chunksLeftLabel->setObjectName("chunksLeftLabel");

        gridLayout2->addWidget(chunksLeftLabel, 0, 4, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout2->addWidget(label_4, 1, 0, 1, 1);

        chunksAllLabel = new QLabel(groupBox);
        chunksAllLabel->setObjectName("chunksAllLabel");

        gridLayout2->addWidget(chunksAllLabel, 1, 2, 1, 1);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        gridLayout2->addWidget(label_6, 1, 3, 1, 1);

        chunksExcludedLabel = new QLabel(groupBox);
        chunksExcludedLabel->setObjectName("chunksExcludedLabel");

        gridLayout2->addWidget(chunksExcludedLabel, 1, 4, 1, 1);


        gridLayout->addWidget(groupBox, 2, 1, 1, 1);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        gridLayout3 = new QGridLayout();
        gridLayout3->setObjectName("gridLayout3");
        destEdit = new KLineEdit(BTDetailsWidgetFrm);
        destEdit->setObjectName("destEdit");
        destEdit->setReadOnly(true);

        gridLayout3->addWidget(destEdit, 1, 1, 1, 1);

        srcEdit = new KLineEdit(BTDetailsWidgetFrm);
        srcEdit->setObjectName("srcEdit");
        srcEdit->setReadOnly(true);

        gridLayout3->addWidget(srcEdit, 0, 1, 1, 1);

        label_11 = new QLabel(BTDetailsWidgetFrm);
        label_11->setObjectName("label_11");

        gridLayout3->addWidget(label_11, 0, 0, 1, 1);

        label_2 = new QLabel(BTDetailsWidgetFrm);
        label_2->setObjectName("label_2");

        gridLayout3->addWidget(label_2, 1, 0, 1, 1);


        vboxLayout->addLayout(gridLayout3);

        progressBar = new QProgressBar(BTDetailsWidgetFrm);
        progressBar->setObjectName("progressBar");
        progressBar->setValue(24);

        vboxLayout->addWidget(progressBar);


        gridLayout->addLayout(vboxLayout, 0, 0, 2, 2);


        retranslateUi(BTDetailsWidgetFrm);

        QMetaObject::connectSlotsByName(BTDetailsWidgetFrm);
    } // setupUi

    void retranslateUi(QWidget *BTDetailsWidgetFrm)
    {
        groupBox_3->setTitle(tr2i18n("Stats", nullptr));
        label_7->setText(tr2i18n("Seeders:", nullptr));
        seederLabel->setText(tr2i18n("<n>", nullptr));
        label_9->setText(tr2i18n("Download speed:", nullptr));
        dlSpeedLabel->setText(tr2i18n("<n>", nullptr));
        label_8->setText(tr2i18n("Leechers:", nullptr));
        leecherLabel->setText(tr2i18n("<n>", nullptr));
        label_10->setText(tr2i18n("Upload speed:", nullptr));
        ulSpeedLabel->setText(tr2i18n("<n>", nullptr));
        groupBox->setTitle(tr2i18n("Chunks", nullptr));
        label_3->setText(tr2i18n("Downloaded:", nullptr));
        chunksDownloadedLabel->setText(tr2i18n("<n>", nullptr));
        label_5->setText(tr2i18n("Left:", "chunks left"));
        chunksLeftLabel->setText(tr2i18n("<n>", nullptr));
        label_4->setText(tr2i18n("All:", "all chunks"));
        chunksAllLabel->setText(tr2i18n("<n>", nullptr));
        label_6->setText(tr2i18n("Excluded:", nullptr));
        chunksExcludedLabel->setText(tr2i18n("<n>", nullptr));
        label_11->setText(tr2i18n("Source:", "source-file"));
        label_2->setText(tr2i18n("Saving to:", nullptr));
        progressBar->setFormat(tr2i18n("%p%", nullptr));
        (void)BTDetailsWidgetFrm;
    } // retranslateUi

};

namespace Ui {
    class BTDetailsWidgetFrm: public Ui_BTDetailsWidgetFrm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BTDETAILSWIDGETFRM_H

