// This file is generated by kconfig_compiler_kf6 from kget_multisegkiofactory.kcfg.
// All changes you do to this file will be lost.
#ifndef MULTISEGKIOSETTINGS_H
#define MULTISEGKIOSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class MultiSegKioSettings : public KConfigSkeleton
{
  public:

    static MultiSegKioSettings *self();
    ~MultiSegKioSettings() override;

    /**
      Set Segments
    */
    static
    void setSegments( int v )
    {
      if (!self()->isSegmentsImmutable())
        self()->mSegments = v;
    }

    /**
      Get Segments
    */
    static
    int segments()
    {
      return self()->mSegments;
    }

    /**
      Is Segments Immutable
    */
    static
    bool isSegmentsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Segments" ) );
    }

    /**
      Set SaveSegSize
    */
    static
    void setSaveSegSize( int v )
    {
      if (!self()->isSaveSegSizeImmutable())
        self()->mSaveSegSize = v;
    }

    /**
      Get SaveSegSize
    */
    static
    int saveSegSize()
    {
      return self()->mSaveSegSize;
    }

    /**
      Is SaveSegSize Immutable
    */
    static
    bool isSaveSegSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SaveSegSize" ) );
    }

    /**
      Set UseSearchEngines
    */
    static
    void setUseSearchEngines( bool v )
    {
      if (!self()->isUseSearchEnginesImmutable())
        self()->mUseSearchEngines = v;
    }

    /**
      Get UseSearchEngines
    */
    static
    bool useSearchEngines()
    {
      return self()->mUseSearchEngines;
    }

    /**
      Is UseSearchEngines Immutable
    */
    static
    bool isUseSearchEnginesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "UseSearchEngines" ) );
    }

    /**
      Set UseSearchVerification
    */
    static
    void setUseSearchVerification( bool v )
    {
      if (!self()->isUseSearchVerificationImmutable())
        self()->mUseSearchVerification = v;
    }

    /**
      Get UseSearchVerification
    */
    static
    bool useSearchVerification()
    {
      return self()->mUseSearchVerification;
    }

    /**
      Is UseSearchVerification Immutable
    */
    static
    bool isUseSearchVerificationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "UseSearchVerification" ) );
    }

  protected:
    MultiSegKioSettings();
    friend class MultiSegKioSettingsHelper;


    // Segments
    int mSegments;
    int mSaveSegSize;

    // SearchEngines
    bool mUseSearchEngines;

    // Verification
    bool mUseSearchVerification;
};

#endif

