/********************************************************************************
** Form generated from reading UI file 'dlgmirrorsearch.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DLGMIRRORSEARCH_H
#define UI_DLGMIRRORSEARCH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KTitleWidget"

QT_BEGIN_NAMESPACE

class Ui_DlgMirrorSearch
{
public:
    QVBoxLayout *verticalLayout;
    KTitleWidget *ktitlewidget;
    QTreeWidget *enginesTreeWidget;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *spacer;
    QPushButton *newEngineBt;
    QPushButton *removeEngineBt;

    void setupUi(QWidget *DlgMirrorSearch)
    {
        if (DlgMirrorSearch->objectName().isEmpty())
            DlgMirrorSearch->setObjectName("DlgMirrorSearch");
        DlgMirrorSearch->resize(403, 439);
        verticalLayout = new QVBoxLayout(DlgMirrorSearch);
        verticalLayout->setObjectName("verticalLayout");
        ktitlewidget = new KTitleWidget(DlgMirrorSearch);
        ktitlewidget->setObjectName("ktitlewidget");

        verticalLayout->addWidget(ktitlewidget);

        enginesTreeWidget = new QTreeWidget(DlgMirrorSearch);
        enginesTreeWidget->setObjectName("enginesTreeWidget");
        enginesTreeWidget->setRootIsDecorated(false);

        verticalLayout->addWidget(enginesTreeWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        spacer = new QSpacerItem(91, 32, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(spacer);

        newEngineBt = new QPushButton(DlgMirrorSearch);
        newEngineBt->setObjectName("newEngineBt");

        horizontalLayout->addWidget(newEngineBt);

        removeEngineBt = new QPushButton(DlgMirrorSearch);
        removeEngineBt->setObjectName("removeEngineBt");

        horizontalLayout->addWidget(removeEngineBt);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(DlgMirrorSearch);

        QMetaObject::connectSlotsByName(DlgMirrorSearch);
    } // setupUi

    void retranslateUi(QWidget *DlgMirrorSearch)
    {
        ktitlewidget->setText(tr2i18n("Search Engines", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = enginesTreeWidget->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("URL", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Engine Name", nullptr));
        newEngineBt->setText(tr2i18n("New Engine...", nullptr));
        removeEngineBt->setText(tr2i18n("Remove", nullptr));
        (void)DlgMirrorSearch;
    } // retranslateUi

};

namespace Ui {
    class DlgMirrorSearch: public Ui_DlgMirrorSearch {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DLGMIRRORSEARCH_H

