/********************************************************************************
** Form generated from reading UI file 'btsettingswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BTSETTINGSWIDGET_H
#define UI_BTSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_BTSettingsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *networkGroupBox;
    QFormLayout *formLayout;
    QLabel *portLabel;
    QSpinBox *portBox;
    QLabel *uploadLimitLabel;
    QSpinBox *uploadBox;
    QLabel *downloadLabel;
    QSpinBox *downloadBox;
    QCheckBox *utpBox;
    QGroupBox *folderGroupBox;
    QFormLayout *formLayout_2;
    QLabel *torrentFolderLabel;
    KUrlRequester *torrentEdit;
    QLabel *tempFolderLabel;
    KUrlRequester *tempEdit;
    QCheckBox *preallocBox;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *BTSettingsWidget)
    {
        if (BTSettingsWidget->objectName().isEmpty())
            BTSettingsWidget->setObjectName("BTSettingsWidget");
        BTSettingsWidget->resize(518, 363);
        verticalLayout = new QVBoxLayout(BTSettingsWidget);
        verticalLayout->setObjectName("verticalLayout");
        networkGroupBox = new QGroupBox(BTSettingsWidget);
        networkGroupBox->setObjectName("networkGroupBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(networkGroupBox->sizePolicy().hasHeightForWidth());
        networkGroupBox->setSizePolicy(sizePolicy);
        formLayout = new QFormLayout(networkGroupBox);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        portLabel = new QLabel(networkGroupBox);
        portLabel->setObjectName("portLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, portLabel);

        portBox = new QSpinBox(networkGroupBox);
        portBox->setObjectName("portBox");
        portBox->setMaximum(99000);
        portBox->setValue(6881);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, portBox);

        uploadLimitLabel = new QLabel(networkGroupBox);
        uploadLimitLabel->setObjectName("uploadLimitLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, uploadLimitLabel);

        uploadBox = new QSpinBox(networkGroupBox);
        uploadBox->setObjectName("uploadBox");
        uploadBox->setMaximum(10000);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, uploadBox);

        downloadLabel = new QLabel(networkGroupBox);
        downloadLabel->setObjectName("downloadLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, downloadLabel);

        downloadBox = new QSpinBox(networkGroupBox);
        downloadBox->setObjectName("downloadBox");
        downloadBox->setMaximum(100000);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, downloadBox);

        utpBox = new QCheckBox(networkGroupBox);
        utpBox->setObjectName("utpBox");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, utpBox);


        verticalLayout->addWidget(networkGroupBox);

        folderGroupBox = new QGroupBox(BTSettingsWidget);
        folderGroupBox->setObjectName("folderGroupBox");
        sizePolicy.setHeightForWidth(folderGroupBox->sizePolicy().hasHeightForWidth());
        folderGroupBox->setSizePolicy(sizePolicy);
        formLayout_2 = new QFormLayout(folderGroupBox);
        formLayout_2->setObjectName("formLayout_2");
        torrentFolderLabel = new QLabel(folderGroupBox);
        torrentFolderLabel->setObjectName("torrentFolderLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(torrentFolderLabel->sizePolicy().hasHeightForWidth());
        torrentFolderLabel->setSizePolicy(sizePolicy1);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, torrentFolderLabel);

        torrentEdit = new KUrlRequester(folderGroupBox);
        torrentEdit->setObjectName("torrentEdit");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(torrentEdit->sizePolicy().hasHeightForWidth());
        torrentEdit->setSizePolicy(sizePolicy2);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, torrentEdit);

        tempFolderLabel = new QLabel(folderGroupBox);
        tempFolderLabel->setObjectName("tempFolderLabel");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, tempFolderLabel);

        tempEdit = new KUrlRequester(folderGroupBox);
        tempEdit->setObjectName("tempEdit");
        sizePolicy2.setHeightForWidth(tempEdit->sizePolicy().hasHeightForWidth());
        tempEdit->setSizePolicy(sizePolicy2);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, tempEdit);

        preallocBox = new QCheckBox(folderGroupBox);
        preallocBox->setObjectName("preallocBox");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, preallocBox);


        verticalLayout->addWidget(folderGroupBox);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);


        retranslateUi(BTSettingsWidget);

        QMetaObject::connectSlotsByName(BTSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *BTSettingsWidget)
    {
        networkGroupBox->setTitle(tr2i18n("Network", nullptr));
        portLabel->setText(tr2i18n("Port:", nullptr));
        uploadLimitLabel->setText(tr2i18n("Upload limit per transfer:", nullptr));
        uploadBox->setSpecialValueText(tr2i18n("No Limit", nullptr));
        uploadBox->setSuffix(tr2i18n("KiB", nullptr));
        downloadLabel->setText(tr2i18n("Download limit per transfer:", nullptr));
        downloadBox->setSpecialValueText(tr2i18n("No Limit", nullptr));
        downloadBox->setSuffix(tr2i18n("KiB", nullptr));
        utpBox->setText(tr2i18n("Enable UTP protocol", nullptr));
        folderGroupBox->setTitle(tr2i18n("Folders", nullptr));
        torrentFolderLabel->setText(tr2i18n("Default torrent folder:", nullptr));
        tempFolderLabel->setText(tr2i18n("Default temporary folder:", nullptr));
        preallocBox->setText(tr2i18n("Pre-allocate disk space", nullptr));
        (void)BTSettingsWidget;
    } // retranslateUi

};

namespace Ui {
    class BTSettingsWidget: public Ui_BTSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BTSETTINGSWIDGET_H

