/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kget.verifier.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef VERIFIERADAPTOR_H
#define VERIFIERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "../dbus/dbusverifierwrapper.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kget.verifier
 */
class VerifierAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kget.verifier")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kget.verifier\">\n"
"    <method name=\"destination\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"addChecksum\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"type\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"hash\"/>\n"
"    </method>\n"
"    <method name=\"isVerifyable\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"verify\"/>\n"
"    <method name=\"brokenPieces\"/>\n"
"    <method name=\"addPartialChecksums\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"type\"/>\n"
"      <arg direction=\"in\" type=\"t\" name=\"size\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"checksums\"/>\n"
"    </method>\n"
"    <signal name=\"verified\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"verified\"/>\n"
"    </signal>\n"
"    <signal name=\"brokenPieces\">\n"
"      <arg direction=\"out\" type=\"as\" name=\"offsets\"/>\n"
"      <arg direction=\"out\" type=\"t\" name=\"length\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    VerifierAdaptor(DBusVerifierWrapper *parent);
    ~VerifierAdaptor() override;

    inline DBusVerifierWrapper *parent() const
    { return static_cast<DBusVerifierWrapper *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void addChecksum(const QString &type, const QString &hash);
    void addPartialChecksums(const QString &type, qulonglong size, const QStringList &checksums);
    void brokenPieces();
    QString destination();
    bool isVerifyable();
    void verify();
Q_SIGNALS: // SIGNALS
    void brokenPieces(const QStringList &offsets, qulonglong length);
    void verified(bool verified);
};

#endif
