/********************************************************************************
** Form generated from reading UI file 'renamefile.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RENAMEFILE_H
#define UI_RENAMEFILE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_RenameFile
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    KLineEdit *name;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *RenameFile)
    {
        if (RenameFile->objectName().isEmpty())
            RenameFile->setObjectName("RenameFile");
        RenameFile->resize(400, 103);
        verticalLayout = new QVBoxLayout(RenameFile);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(RenameFile);
        label->setObjectName("label");
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        name = new KLineEdit(RenameFile);
        name->setObjectName("name");

        verticalLayout->addWidget(name);

        buttonBox = new QDialogButtonBox(RenameFile);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
        buttonBox->setCenterButtons(false);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(RenameFile);

        QMetaObject::connectSlotsByName(RenameFile);
    } // setupUi

    void retranslateUi(QWidget *RenameFile)
    {
        label->setText(QString());
        (void)RenameFile;
    } // retranslateUi

};

namespace Ui {
    class RenameFile: public Ui_RenameFile {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RENAMEFILE_H

