/****************************************************************************
** Meta object code from reading C++ file 'transfertreemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kget-26.08.0/core/transfertreemodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transfertreemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ItemMimeDataE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemMimeData::qt_create_metaobjectdata<qt_meta_tag_ZN12ItemMimeDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemMimeData"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemMimeData, qt_meta_tag_ZN12ItemMimeDataE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemMimeData::staticMetaObject = { {
    QMetaObject::SuperData::link<QMimeData::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ItemMimeDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ItemMimeDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ItemMimeDataE_t>.metaTypes,
    nullptr
} };

void ItemMimeData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemMimeData *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ItemMimeData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemMimeData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ItemMimeDataE_t>.strings))
        return static_cast<void*>(this);
    return QMimeData::qt_metacast(_clname);
}

int ItemMimeData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMimeData::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN17TransferTreeModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TransferTreeModel::qt_create_metaobjectdata<qt_meta_tag_ZN17TransferTreeModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransferTreeModel",
        "groupAddedEvent",
        "",
        "TransferGroupHandler*",
        "groupRemovedEvent",
        "groupsChangedEvent",
        "QMap<TransferGroupHandler*,TransferGroup::ChangesFlags>",
        "transfersAddedEvent",
        "QList<TransferHandler*>",
        "transfers",
        "transfersAboutToBeRemovedEvent",
        "transfersRemovedEvent",
        "transferMovedEvent",
        "TransferHandler*",
        "transfersChangedEvent",
        "QMap<TransferHandler*,Transfer::ChangesFlags>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'groupAddedEvent'
        QtMocHelpers::SignalData<void(TransferGroupHandler *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'groupRemovedEvent'
        QtMocHelpers::SignalData<void(TransferGroupHandler *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'groupsChangedEvent'
        QtMocHelpers::SignalData<void(QMap<TransferGroupHandler*,TransferGroup::ChangesFlags>)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'transfersAddedEvent'
        QtMocHelpers::SignalData<void(QList<TransferHandler*>)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'transfersAboutToBeRemovedEvent'
        QtMocHelpers::SignalData<void(const QList<TransferHandler*> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'transfersRemovedEvent'
        QtMocHelpers::SignalData<void(const QList<TransferHandler*> &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'transferMovedEvent'
        QtMocHelpers::SignalData<void(TransferHandler *, TransferGroupHandler *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Signal 'transfersChangedEvent'
        QtMocHelpers::SignalData<void(QMap<TransferHandler*,Transfer::ChangesFlags>)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransferTreeModel, qt_meta_tag_ZN17TransferTreeModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransferTreeModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QStandardItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TransferTreeModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TransferTreeModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17TransferTreeModelE_t>.metaTypes,
    nullptr
} };

void TransferTreeModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransferTreeModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->groupAddedEvent((*reinterpret_cast<std::add_pointer_t<TransferGroupHandler*>>(_a[1]))); break;
        case 1: _t->groupRemovedEvent((*reinterpret_cast<std::add_pointer_t<TransferGroupHandler*>>(_a[1]))); break;
        case 2: _t->groupsChangedEvent((*reinterpret_cast<std::add_pointer_t<QMap<TransferGroupHandler*,TransferGroup::ChangesFlags>>>(_a[1]))); break;
        case 3: _t->transfersAddedEvent((*reinterpret_cast<std::add_pointer_t<QList<TransferHandler*>>>(_a[1]))); break;
        case 4: _t->transfersAboutToBeRemovedEvent((*reinterpret_cast<std::add_pointer_t<QList<TransferHandler*>>>(_a[1]))); break;
        case 5: _t->transfersRemovedEvent((*reinterpret_cast<std::add_pointer_t<QList<TransferHandler*>>>(_a[1]))); break;
        case 6: _t->transferMovedEvent((*reinterpret_cast<std::add_pointer_t<TransferHandler*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TransferGroupHandler*>>(_a[2]))); break;
        case 7: _t->transfersChangedEvent((*reinterpret_cast<std::add_pointer_t<QMap<TransferHandler*,Transfer::ChangesFlags>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransferTreeModel::*)(TransferGroupHandler * )>(_a, &TransferTreeModel::groupAddedEvent, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferTreeModel::*)(TransferGroupHandler * )>(_a, &TransferTreeModel::groupRemovedEvent, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferTreeModel::*)(QMap<TransferGroupHandler*,TransferGroup::ChangesFlags> )>(_a, &TransferTreeModel::groupsChangedEvent, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferTreeModel::*)(QList<TransferHandler*> )>(_a, &TransferTreeModel::transfersAddedEvent, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferTreeModel::*)(const QList<TransferHandler*> & )>(_a, &TransferTreeModel::transfersAboutToBeRemovedEvent, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferTreeModel::*)(const QList<TransferHandler*> & )>(_a, &TransferTreeModel::transfersRemovedEvent, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferTreeModel::*)(TransferHandler * , TransferGroupHandler * )>(_a, &TransferTreeModel::transferMovedEvent, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferTreeModel::*)(QMap<TransferHandler*,Transfer::ChangesFlags> )>(_a, &TransferTreeModel::transfersChangedEvent, 7))
            return;
    }
}

const QMetaObject *TransferTreeModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransferTreeModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TransferTreeModelE_t>.strings))
        return static_cast<void*>(this);
    return QStandardItemModel::qt_metacast(_clname);
}

int TransferTreeModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStandardItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void TransferTreeModel::groupAddedEvent(TransferGroupHandler * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TransferTreeModel::groupRemovedEvent(TransferGroupHandler * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TransferTreeModel::groupsChangedEvent(QMap<TransferGroupHandler*,TransferGroup::ChangesFlags> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TransferTreeModel::transfersAddedEvent(QList<TransferHandler*> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void TransferTreeModel::transfersAboutToBeRemovedEvent(const QList<TransferHandler*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void TransferTreeModel::transfersRemovedEvent(const QList<TransferHandler*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void TransferTreeModel::transferMovedEvent(TransferHandler * _t1, TransferGroupHandler * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void TransferTreeModel::transfersChangedEvent(QMap<TransferHandler*,Transfer::ChangesFlags> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
