/****************************************************************************
** Meta object code from reading C++ file 'verifieradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "verifieradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'verifieradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15VerifierAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto VerifierAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN15VerifierAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VerifierAdaptor",
        "D-Bus Interface",
        "org.kde.kget.verifier",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kget.verifier\">\n    <method name=\"d"
        "estination\">\n      <arg direction=\"out\" type=\"s\"/>\n    </me"
        "thod>\n    <method name=\"addChecksum\">\n      <arg direction=\"i"
        "n\" type=\"s\" name=\"type\"/>\n      <arg direction=\"in\" type=\""
        "s\" name=\"hash\"/>\n    </method>\n    <method name=\"isVerifyabl"
        "e\">\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n  "
        "  <method name=\"verify\"/>\n    <method name=\"brokenPieces\"/>\n"
        "    <method name=\"addPartialChecksums\">\n      <arg direction=\""
        "in\" type=\"s\" name=\"type\"/>\n      <arg direction=\"in\" type="
        "\"t\" name=\"size\"/>\n      <arg direction=\"in\" type=\"as\" nam"
        "e=\"checksums\"/>\n    </method>\n    <signal name=\"verified\">\n"
        "      <arg direction=\"out\" type=\"b\" name=\"verified\"/>\n    <"
        "/signal>\n    <signal name=\"brokenPieces\">\n      <arg direction"
        "=\"out\" type=\"as\" name=\"offsets\"/>\n      <arg direction=\"ou"
        "t\" type=\"t\" name=\"length\"/>\n    </signal>\n  </interface>\n",
        "brokenPieces",
        "",
        "offsets",
        "length",
        "verified",
        "addChecksum",
        "type",
        "hash",
        "addPartialChecksums",
        "size",
        "checksums",
        "destination",
        "isVerifyable",
        "verify"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'brokenPieces'
        QtMocHelpers::SignalData<void(const QStringList &, qulonglong)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 }, { QMetaType::ULongLong, 8 },
        }}),
        // Signal 'verified'
        QtMocHelpers::SignalData<void(bool)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'addChecksum'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'addPartialChecksums'
        QtMocHelpers::SlotData<void(const QString &, qulonglong, const QStringList &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::ULongLong, 14 }, { QMetaType::QStringList, 15 },
        }}),
        // Slot 'brokenPieces'
        QtMocHelpers::SlotData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'destination'
        QtMocHelpers::SlotData<QString()>(16, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'isVerifyable'
        QtMocHelpers::SlotData<bool()>(17, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'verify'
        QtMocHelpers::SlotData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<VerifierAdaptor, qt_meta_tag_ZN15VerifierAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject VerifierAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15VerifierAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15VerifierAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15VerifierAdaptorE_t>.metaTypes,
    nullptr
} };

void VerifierAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VerifierAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->brokenPieces((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 1: _t->verified((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->addChecksum((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->addPartialChecksums((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 4: _t->brokenPieces(); break;
        case 5: { QString _r = _t->destination();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->isVerifyable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->verify(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VerifierAdaptor::*)(const QStringList & , qulonglong )>(_a, &VerifierAdaptor::brokenPieces, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VerifierAdaptor::*)(bool )>(_a, &VerifierAdaptor::verified, 1))
            return;
    }
}

const QMetaObject *VerifierAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VerifierAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15VerifierAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int VerifierAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void VerifierAdaptor::brokenPieces(const QStringList & _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void VerifierAdaptor::verified(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
