/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kget.main.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef MAINADAPTOR_H
#define MAINADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "dbus/dbuskgetwrapper.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kget.main
 */
class MainAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kget.main")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kget.main\">\n"
"    <method name=\"dropTargetVisible\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setDropTargetVisible\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"visible\"/>\n"
"    </method>\n"
"    <method name=\"offlineMode\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setOfflineMode\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"addTransfer\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"src\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"destDir\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"start\"/>\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"delTransfer\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"dbusObjectPath\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"showNewTransferDialog\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"urls\"/>\n"
"    </method>\n"
"    <method name=\"transfers\">\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"a{ss}\" name=\"out\"/>\n"
"    </method>\n"
"    <method name=\"transfersSpeed\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"importLinks\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"links\"/>\n"
"    </method>\n"
"    <method name=\"isSupported\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"url\"/>\n"
"    </method>\n"
"    <signal name=\"transfersAdded\">\n"
"      <arg direction=\"out\" type=\"as\" name=\"urls\"/>\n"
"      <arg direction=\"out\" type=\"as\" name=\"dBusObjectPaths\"/>\n"
"    </signal>\n"
"    <signal name=\"transfersRemoved\">\n"
"      <arg direction=\"out\" type=\"as\" name=\"urls\"/>\n"
"      <arg direction=\"out\" type=\"as\" name=\"dBusObjectPaths\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    MainAdaptor(DBusKGetWrapper *parent);
    ~MainAdaptor() override;

    inline DBusKGetWrapper *parent() const
    { return static_cast<DBusKGetWrapper *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QStringList addTransfer(const QString &src, const QString &destDir, bool start);
    bool delTransfer(const QString &dbusObjectPath);
    bool dropTargetVisible();
    void importLinks(const QStringList &links);
    bool isSupported(const QString &url);
    bool offlineMode();
    void setDropTargetVisible(bool visible);
    void setOfflineMode(bool in0);
    void showNewTransferDialog(const QStringList &urls);
    QVariantMap transfers();
    int transfersSpeed();
Q_SIGNALS: // SIGNALS
    void transfersAdded(const QStringList &urls, const QStringList &dBusObjectPaths);
    void transfersRemoved(const QStringList &urls, const QStringList &dBusObjectPaths);
};

#endif
