/********************************************************************************
** Form generated from reading UI file 'generalwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALWIDGET_H
#define UI_GENERALWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_GeneralWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_5;
    QLabel *label_7;
    QSpacerItem *verticalSpacer_4;
    QFormLayout *formLayout;
    QLabel *label_2;
    KLineEdit *origin;
    QLabel *labelDynamic;
    QCheckBox *dynamic;
    QSpacerItem *verticalSpacer;
    QGroupBox *publishedGroupBox;
    QFormLayout *formLayout_2;
    QLabel *label_30;
    QDateTimeEdit *published;
    QCheckBox *use_publishedtimeoffset;
    QCheckBox *publishedNegative;
    QLabel *label;
    QTimeEdit *publishedoffset;
    QSpacerItem *verticalSpacer_3;
    QGroupBox *updatedGroupBox;
    QFormLayout *formLayout_3;
    QCheckBox *updatedNegative;
    QLabel *label_8;
    QCheckBox *use_updatedtimeoffset;
    QDateTimeEdit *updated;
    QLabel *label_29;
    QTimeEdit *updatedoffset;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *GeneralWidget)
    {
        if (GeneralWidget->objectName().isEmpty())
            GeneralWidget->setObjectName("GeneralWidget");
        GeneralWidget->resize(473, 412);
        verticalLayout = new QVBoxLayout(GeneralWidget);
        verticalLayout->setObjectName("verticalLayout");
        label_5 = new QLabel(GeneralWidget);
        label_5->setObjectName("label_5");
        QFont font;
        font.setBold(true);
        label_5->setFont(font);

        verticalLayout->addWidget(label_5);

        label_7 = new QLabel(GeneralWidget);
        label_7->setObjectName("label_7");
        label_7->setWordWrap(true);

        verticalLayout->addWidget(label_7);

        verticalSpacer_4 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_4);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_2 = new QLabel(GeneralWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        origin = new KLineEdit(GeneralWidget);
        origin->setObjectName("origin");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, origin);

        labelDynamic = new QLabel(GeneralWidget);
        labelDynamic->setObjectName("labelDynamic");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, labelDynamic);

        dynamic = new QCheckBox(GeneralWidget);
        dynamic->setObjectName("dynamic");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, dynamic);


        verticalLayout->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(40, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer);

        publishedGroupBox = new QGroupBox(GeneralWidget);
        publishedGroupBox->setObjectName("publishedGroupBox");
        publishedGroupBox->setCheckable(true);
        publishedGroupBox->setChecked(false);
        formLayout_2 = new QFormLayout(publishedGroupBox);
        formLayout_2->setObjectName("formLayout_2");
        label_30 = new QLabel(publishedGroupBox);
        label_30->setObjectName("label_30");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_30);

        published = new QDateTimeEdit(publishedGroupBox);
        published->setObjectName("published");
        published->setCalendarPopup(true);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, published);

        use_publishedtimeoffset = new QCheckBox(publishedGroupBox);
        use_publishedtimeoffset->setObjectName("use_publishedtimeoffset");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, use_publishedtimeoffset);

        publishedNegative = new QCheckBox(publishedGroupBox);
        publishedNegative->setObjectName("publishedNegative");
        publishedNegative->setEnabled(false);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, publishedNegative);

        label = new QLabel(publishedGroupBox);
        label->setObjectName("label");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label);

        publishedoffset = new QTimeEdit(publishedGroupBox);
        publishedoffset->setObjectName("publishedoffset");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, publishedoffset);


        verticalLayout->addWidget(publishedGroupBox);

        verticalSpacer_3 = new QSpacerItem(40, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_3);

        updatedGroupBox = new QGroupBox(GeneralWidget);
        updatedGroupBox->setObjectName("updatedGroupBox");
        updatedGroupBox->setFlat(false);
        updatedGroupBox->setCheckable(true);
        updatedGroupBox->setChecked(false);
        formLayout_3 = new QFormLayout(updatedGroupBox);
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        updatedNegative = new QCheckBox(updatedGroupBox);
        updatedNegative->setObjectName("updatedNegative");
        updatedNegative->setEnabled(false);

        formLayout_3->setWidget(2, QFormLayout::ItemRole::FieldRole, updatedNegative);

        label_8 = new QLabel(updatedGroupBox);
        label_8->setObjectName("label_8");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, label_8);

        use_updatedtimeoffset = new QCheckBox(updatedGroupBox);
        use_updatedtimeoffset->setObjectName("use_updatedtimeoffset");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, use_updatedtimeoffset);

        updated = new QDateTimeEdit(updatedGroupBox);
        updated->setObjectName("updated");
        updated->setCalendarPopup(true);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, updated);

        label_29 = new QLabel(updatedGroupBox);
        label_29->setObjectName("label_29");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_29);

        updatedoffset = new QTimeEdit(updatedGroupBox);
        updatedoffset->setObjectName("updatedoffset");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, updatedoffset);


        verticalLayout->addWidget(updatedGroupBox);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        retranslateUi(GeneralWidget);
        QObject::connect(use_publishedtimeoffset, &QCheckBox::toggled, publishedNegative, &QCheckBox::setEnabled);
        QObject::connect(use_updatedtimeoffset, &QCheckBox::toggled, updatedNegative, &QCheckBox::setEnabled);
        QObject::connect(use_updatedtimeoffset, &QCheckBox::toggled, label_8, &QLabel::setEnabled);
        QObject::connect(use_publishedtimeoffset, &QCheckBox::toggled, label, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(GeneralWidget);
    } // setupUi

    void retranslateUi(QWidget *GeneralWidget)
    {
        label_5->setText(tr2i18n("General information:", nullptr));
        label_7->setText(tr2i18n("Here you can enter optional general information on the metalink.", nullptr));
        label_2->setText(tr2i18n("Origin:", nullptr));
        origin->setPlaceholderText(tr2i18n("Web URL to the metalink", nullptr));
#if QT_CONFIG(tooltip)
        labelDynamic->setToolTip(tr2i18n("Dynamic means that updated metalinks can be found at \"Origin\".", nullptr));
#endif // QT_CONFIG(tooltip)
        labelDynamic->setText(tr2i18n("Dynamic:", nullptr));
        dynamic->setText(QString());
        publishedGroupBox->setTitle(tr2i18n("Metalink published", nullptr));
        label_30->setText(tr2i18n("Date and time:", nullptr));
        use_publishedtimeoffset->setText(tr2i18n("Timezone offset:", nullptr));
        publishedNegative->setText(QString());
        label->setText(tr2i18n("Negative offset:", nullptr));
        updatedGroupBox->setTitle(tr2i18n("Metalink updated", nullptr));
        updatedNegative->setText(QString());
        label_8->setText(tr2i18n("Negative offset:", nullptr));
        use_updatedtimeoffset->setText(tr2i18n("Timezone offset:", nullptr));
        label_29->setText(tr2i18n("Date and time:", nullptr));
        (void)GeneralWidget;
    } // retranslateUi

};

namespace Ui {
    class GeneralWidget: public Ui_GeneralWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALWIDGET_H

